// TREAT ALL FIELDS AS READ ONLY!!!  NEVER MODIFY ANY VALUE!!!

#ifndef _EZBMC_H
#define _EZBMC_H

#include <stdint.h>
#include <string.h>			// for inline memcmp below
#include <values.h>
#include <time.h>
#include <arpa/inet.h>			// For MPIP below

#ifdef __cplusplus
extern "C" {
#endif

#define	IANA_HP				11
#define IANA_PROLIANT_SDRR_HEADER	0x103C	// cuz it is, == 4156
#define IANA_DL145			3973	// Aelita ???

// There is some 32/64 bit sensitivity in the library, and in some projects
// that use it.  Different versions of gcc emit different base flags.
// Define a custom variant.

#if defined(_LP64) || defined(__LP64__)
#define EZBMC_LP64
#endif

// Cross-compiles and older distros (SLES8, RHAS 2.1) may use gcc 2.9x which
// does not support the anonymous unions used in SDR_entry (among others).  
// As of December 2008 this is no longer worth supporting.  Eliminating
// it will simplify E1 events and hpipmid work.  Keep the base macros
// for now as they get heavy use in ezbmc and hpbmc.  BTW, gcc 2.95
// cross-compilation for ATCA (circa 2005) did not emit __GNUC__.
// Bug 8522 cleanup: got rid of PFRUU in ezbmc.

#define PSDRU(xxx) pSDR->xxx	// No more variant for gcc 2.xx

// Which data should be loaded at BMC_open()?

#define EZBMC_FILL_BASIC	0x0001	// ID, firmware, etc.
#define EZBMC_FILL_SDR		0x0002	// Try from cache, then from BMC
#define EZBMC_FILL_SDR_FROM_BMC 0x0004	// Ignore cache
#define EZBMC_FILL_CELLINFO	0x0008	// Cellular systems only
#define EZBMC_FILL_NO_DEVICE	0x0010	// No BMC access, just other data
#define EZBMC_FILL_NO_DNS	0x0020  // No lookup of MP LAN IP address
#define EZBMC_FILL_NO_MPLAN	0x0040  // No lookup of MP LAN parms (SLOW)
#define EZBMC_FILL_NO_CHIF	0x0080  // No initialize CHIF interface

// If you know at BMC_open() you'll be doing event parsing, spend the time
// to load the dictionaries.  They can be loaded on demand.  IPMI dictionary
// cannot be used with EZBMC_FILL_NO_DEVICE

#define EZBMC_FILL_DICTIONARY_IPMI	0x0100	// That's 256 RecTypes
#define EZBMC_FILL_DICTIONARY_ALL	0x0F00	// Up to 3 more non-IPMI

// NOT FOR GENERAL USE - they're for the hpmgmtbase utility "hpbmc"
#define EZBMC_SDR_CACHE_CHECK	0x2000
#define EZBMC_SDR_CACHE_CREATE	0x4000
#define EZBMC_SDR_CACHE_DESTROY	0x8000

// NOT FOR GENERAL USE - only by a message queue daemon
#define EZBMC_FILL_MQ_MASTER	0x1000

// Result of BMC_SDR_status().  Unless BMC_open is being done in a 
// separate thread, these are a noop because the loads are serialized 
// behind BMC_open.
#define EZBMC_FILL_STATUS_EMPTY    0	// after a memset
#define EZBMC_FILL_STATUS_BUSY     1
#define EZBMC_FILL_STATUS_COMPLETE 2

// Device ID and Product ID are from the IPMI "Get Device ID" response. 
// Refer to the HP IPMI OEM extensions document v2.21.  ProLiants
// usually do NOT set the ProductID field, bummer.  Compared to a very old
// incantation of ezbmc, there is
// New macro EZBMC_IS_LEGACY_FOUNDATION to replace EZBMC_IS_FOUNDATION
// New macro EZBMC_IS_ZIRCON            for Tahiti and legacy with Zircon BMC
//					or RMP4 that preserves original OEM
//					tokens, with an IPMB between the two.
// New macro EZBMC_IS_INTEGRITY_BLADE   for Tahiti-class blades
// Plus all the newer boxes.  This section has "topmost" definitions
// of platforms, even though they cross the line into blade and cellular
// (more fine-grained macros are in ezbmc_cell_blade.h).

// Integrity first.

#define EZBMC_IS_HP(pbmc)	((pbmc)->Cap.IANA == IANA_HP)

// Skip Buccaneer for now (it's 0x40, BTW).
#define EZBMC_IS_INTEGRITY(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.DeviceID >= 0x30 && \
			(X)->Cap.DeviceID <= 0x33)

// Kauai and Sentosa only for now
#define EZBMC_IS_INTEGRITY_GROMIT(X) (EZBMC_IS_HP(X) && \
			(X)->Cap.DeviceID == 0x33)

// GSTL boxes:
// 26xx: xPeaks, Onyx, Badger, Pearl, Merlion
// 4640: Diablo
// 5670: Everest
// 3300: Ruby, 6600: Sapphire (collectively, RuSa)
#define EZBMC_IS_LEGACY_FOUNDATION(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.ProductID == 0x8201)

// Adds Tahiti and BoraBora to the mix, bl860c and blc870c
#define EZBMC_IS_ZIRCON(X)	(EZBMC_IS_HP(X) && ( \
			(X)->Cap.ProductID == 0x8201 || \
			(X)->Cap.ProductID == 0x1201 || \
			(X)->Cap.ProductID == 0x1202 ))

// Aka the "Gil" codebase, product is Mt. Horeb
#define EZBMC_IS_HPVM(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.ProductID == 0x8110)

// Tukwila-based cClass blades, the bl860/70c G6.  Once Windjammer was 8202.
#define EZBMC_IS_KAUAI(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.ProductID == 0x8202)

// Tukwila-based rackmount, the rx2800 class
#define EZBMC_IS_SENTOSA(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.ProductID == 0x8203)

// "Legacy" cellular, not Buccaneer (for now).  SX1000 and SX2000 chipset,
// aka Pinnacles and Arches.  Buccaneer is 1002, BTW.
#define EZBMC_IS_CELLULAR(X)	(EZBMC_IS_HP(X) && ( \
			(X)->Cap.ProductID == 0x1000 || \
			(X)->Cap.ProductID == 0x1001 ))

// Buccaneer, superdome generation 2
#define EZBMC_IS_BUCCANEER(X)	(EZBMC_IS_HP(X) && \
                        (X)->Cap.ProductID == 0x1002)

// DragonHawk Proto
#define EZBMC_IS_DRAGONHAWK(X)	(EZBMC_IS_HP(X) && \
                        (X)->Cap.ProductID == 0x1002)
//DH and HH
#define EZBMC_IS_CELLULAR_X86(X) (EZBMC_IS_DRAGONHAWK(X))

//////////////////////////////// Now ProLiant

// This skips the older generations of boxes whose IANA == 232 (Compaq).
#define EZBMC_IS_PROLIANT(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.DeviceID >= 0x11 && \
			(X)->Cap.DeviceID <= 0x13)

// The ML/DL 100 series is a white box with an ???? BMC
#define EZBMC_IS_PROLIANT_1XX(X)	(EZBMC_IS_HP(X) && \
			(X)->Cap.DeviceID == 0x12)

#define EZBMC_IS_PROLIANT_GROMIT(X)	(EZBMC_IS_HP(X) && ( \
			(X)->Cap.DeviceID == 0x11 || \
			(X)->Cap.DeviceID == 0x13 ))

#define EZBMC_IS_GROMIT_ANY(X)	(EZBMC_IS_PROLIANT_GROMIT(X) || \
			(X)->Cap.DeviceID == 0x33 )

//////////////////////////////// End of EZBMC_IS_xxxx

#define EZBMC_IPMB_GET_MYADDR	1	// Only with local BMCs (Open IPMI)
#define EZBMC_IPMB_SET_MYADDR	2

enum {
	EZBMC_WATCHDOG_ACTION_NONE = 0,
	EZBMC_WATCHDOG_ACTION_HARD_RESET,
	EZBMC_WATCHDOG_ACTION_POWER_DOWN,
	EZBMC_WATCHDOG_ACTION_POWER_CYCLE,
};

// TREAT ALL FIELDS AS READ ONLY!!!  NEVER MODIFY ANY VALUE!!!

// Each box has multiple FPU (Field Programmable Units), aka flashable
// firmware of different counts and types.  active and isBank are Booleans
// added for ER bug 6531 to simplify WBEM providers.

typedef struct {
	char Name[40];		// "BMC", 
	char Value[20];		// String translation
	uint8_t	raw[10];	// Raw data bytes from appropriate source 
	uint8_t active;		// 1 if currently booted
	uint8_t isBank;		// 1 if it's part of a redundant bank set
} FPU_t;

// This covers the useful "Get LAN Parameter" responses against the MP card.  
// Name lookup is done unless explicitly disabled by EZBMC_FILL_NO_DNS.

typedef	struct {
	struct in_addr IP;	// v4
	struct in_addr Netmask;
	struct in_addr Gateway;
	int DHCP;		// boolean, true == DHCP used
	uint8_t MAC[6];
	int type;		// 1 == other, 2 == ethernet
	int enabled;		// 1 == other, 2 == enabled, 3 == disabled
	int MTU;
	char FQDN[64];		// NULL if EZBMC_FILL_NO_DNS was set
	char hostname[32];	// Default is MP<MAC ADDRESS>
	char URL[64];		// Retrieved via OEM commands
} MPLANParms_t;

typedef struct {
	uint8_t	 DeviceID;	// Get Device ID, actual BMC type
	uint32_t IANA;		// Get Device ID, enterprise number
	uint8_t  DevSupport;	// Get Device ID, BMC functions/abilities
	uint8_t  IPMIVersion;	// Get Device ID
	uint16_t ProductID;	// Get Device ID, overall platform group
	time_t   CurrentTime;	// Get SEL time, but it's the "BMC clock"
	
	uint8_t  UUIDraw[16];	// Unprocessed form of UUID
	char	 UUID[64];	// Tokens on foundation, properties on cell
	char	 ManName[64];	// FRU 0, Product Info Area
	char	 ProductName[64];
	char	 ProductModelNum[64];
	char	 ProductVersion[64];
	char	 ProductSerialNum[64];
	char	 AssetTag[64];
	char	 FRUFileID;

	FPU_t	 **FPU;		// dynamic array
	int	 nFPUs;		// this many

	// Namespace for PlatformID is set by BMC's ProductID, which forms
	// the basis for EZBMC_IS_ZIRCON, IS_GROMIT, etc.  For example
	// BMC ERS section 8.3.5.1; subclass of GetDevID ProductID.  Old
	// NSD started this, document is at "...IPMI4HP.doc".
	// For cellular, SPPA PDC-PAT 2.6.2.  0 is valid (DomeLite).
	// 0xFFFF is "unknown".  PlatformID use must always be qualified
	// by the namespace of ProductID.

	uint32_t PlatformID; 
	uint16_t FamilyID;   // Proliants: ascii ML/DL/BL  or 0 Unknown
	uint8_t  GenerationID;  // ProLiants: # representing G4,G5 ...

	MPLANParms_t **MPLANParms;
	int nMPLANs;	// Optional on foundation; 2 on Orca; 1 everywhere else
} BMC_header_t;

// SEL/FPL record IDs are stored as 32 bit, but SEL needs only lower 16

#define EZBMC_LOG_FIRST_RECORD	(uint32_t)(0x00000000U)
#define EZBMC_LOG_LAST_RECORD	(uint32_t)(0xFFFFFFFFU)

// Data returned by a Get [SDR | SEL] Info, then Get Allocation Info.  
// The data returned is identical in form for both SDR and SEL.  FPL
// fields are simliar enough to justify using this struct.

typedef struct {
	uint8_t  IPMIVersion;
	uint32_t RecordsUsed;	// May 2009: support hpipmid cache sizes
	uint32_t BytesFree;	// ditto
	time_t   LastAddition,
		 LastDeletion,
		 LastScan;	// Used in SEL|FPL_entries_follow
	uint8_t	 OpSupport;
	uint32_t RecordsMax;	// FPL needs 32 bits
	uint16_t BytesPerRecord;
	uint32_t RecordsFree;	// May 2009: support hpipmid cache sizes
	uint32_t NewestRecord;	// FPL only, synonymous with LAST_RECORD
} BMC_log_header_t;

// physloc is an SPPA-defined packed variant record for physical location.
// Originally defined for error events, it really is of general use.
// cab is the "raw" instance number from the SDRR, not the "external" user
// number, ie, on a Superdome instance 2 is usually cabinet 8.

typedef struct __attribute__((packed, aligned(8))) {
    uint8_t detail:4;		// Lower 4 bits of LSB aka L8/b9
    uint8_t source:4;
    uint8_t subslot,		// loose definition
    	    slot,		// usually a physical socket
	    ext,		// extender
	    cell,		// usually for legacy cellular systems
	    ioc,		// or cardcage
	    bay,		// or backplane
	    cab;		// cab is MSB aka L1/b16
} physloc_t;

#define L1  cab
#define L2  bay
#define L3  ioc
#define L4  cell
#define L5  ext
#define L6  slot
#define L7  subslot

// Gromit supports OEM SDR extensions

typedef struct __attribute__((packed)) { 
        uint8_t Controller[5];
        uint8_t Monitor[5];
        uint8_t Detect[5];
        uint8_t Interrogate[5];
        uint8_t RedundantReaction[2];
        uint8_t NonRedundantReaction[2];
        uint8_t RedundancyDescriptor[2];
        uint8_t Leds[5];
        uint8_t Blowout[5];
        uint8_t Enable[5];
        uint8_t FeatureDescriptor[8];
        uint8_t Reserved[15];
} SDR_Extension_entry_t;

// SDR entries can have multiple definitions based on recType in header field.
// Field names closely resemble or match labels in the IPMI spec.

typedef struct {			// SDR entry
	uint16_t RecID;
	uint8_t  IPMIVersion;
	uint8_t  RecType,
		 RecLen;		// End of "header" fields: all types

	uint8_t  *raw;			// Copy of raw SDR body
	uint8_t	 EntityID, EntityInst;	// Common to all substructs
	char	 Name[64];		// 16-20 in SDR, < 64 in HP properties
	physloc_t physloc;		// where is this item in a complex
	char	 *extra;		// Knock yourself out

	union {
	    struct {			// Sensors, full & compact
		uint8_t	OwnerID,
			OwnerLUN,
			SensorNum,	// End of "key" fields
			SensorInit,
			SensorCap,
			SensorType,
			EvRdType;
		uint16_t AssertLowerMask,
			DeassertUpperMask,
			ReadSetMask;	
		uint8_t UnitsFlags,
			UnitsBase,
			UnitsMod;	// Last actual common field

		// Compact versus full fields: not worth a substructure

    		uint8_t ShareCount,	// if zero, next fields don't matter
			IDStrModType,	// LSB 2 bits
			EntityInstIncr,	// Boolean: true == incr EntityId too
			IDStrModOffset;	// number

		int	M,		// Full sensor stuff starts here
			B,		
			Bexp,
			Rexp;
		uint8_t LinEnum,
			AnalogFlags,
			Nominal,
			NormMax,
			NormMin,
			FullMax,
			FullMin,
			UpperNonRec,
			UpperCrit,
			UpperNonCrit,
			LowerNonRec,
			LowerCrit,
			LowerNonCrit,
			PosHyst,	// Possible in compact
			NegHyst,	// ditto
			OEM;
	    } s;

	    struct {	/* IPMI Entity Associations */
		uint8_t Flags,
			ID[4],
			Inst[4];
			char String[40];
	    } a;

	    struct {	/* FRU item */
		uint8_t	ControllerAddr,
			FRUID,
			IsLogical,
			LUN,
			BusID,	// behind the controller
			DevType,
			DevTypeMod,
			OEM;
	    } f;

	    struct {	/* Management Controller item */
		uint8_t SlaveAddr,
			PowerInit,
			Cap,
			OEM;
	    } m;
	    
	    struct {	// HP extensions for cellular systems: property.
	    		// IANA is 11.
		uint8_t OEMtype,
			OEMversion,
			SlaveAddr,
			Channel,
			Property,
			Flags,
			PropType;
	    } p;
	    
	    // ProLiant SDR Extension header, at EZBMC_LOG_FIRST_RECORD.
	    // Embedded Health Spec version 2.0 section 2.2.1.  The
	    // IANA is 0x103C, color me clueless.
	    struct {	
	    	uint16_t ExtVer,
			 SDRRVer;
		uint32_t SDRRSize;
		uint16_t Options;
		char     Desc[32];	// 31 max per spec
	    } PSX;

	}; // Simpler without a name here, but fails -pedantic.  Oh well
	SDR_Extension_entry_t *pSDRX;	// ProLiant SDR Extension
} SDR_entry_t;

// Sensor read support.  In general a single read returns multiple values.

typedef struct {
	uint8_t RawAnalog;	// from a full/threshold sensor
	float	Converted;	// analog value from Raw
	uint16_t RawStates;	// full: threshold; compact: bitfield
	uint16_t MaskedStates;	// RawStates after filters in an SDR
	uint8_t raw[4];		// Actual four bytes read
	time_t readtime;	// set to "time(NULL)" when read
	int errval;		// result of BMC_sensor_read
	uint16_t mask;		// MaskedStates = RawStates & mask
} IPMI_sensor_values_t;

//add for Dranghawk support OA_CLi_Command @2013.04.07
#define MAX_OA_CMD_SIZE	240
#define MAX_OA_ARG_SIZE	8000
#define MAX_OA_ENV_SIZE	256

typedef struct{ 
        char name[MAX_OA_CMD_SIZE];
        //The maximum size of arguments is 8K
        char arg[MAX_OA_ARG_SIZE];
        //The maximum size of environment is 256 bytes
        char env[MAX_OA_ENV_SIZE];
} cli_request;

typedef struct{
        int size;
        char *buffer;
} str_buf;
//end for Dranghawk support OA_CLi_Command @2013.04.07


#include "ezbmc_cell_blade.h"

#define CONST			// An experiment that hasn't quite worked

/********************** The Cornerstone Data Type *************************/
typedef struct {
    CONST BMC_header_t Cap;		// model name, firmware revisions, etc
	  CabInfo_t **CabInfo;		// map cab instance to a label
	  int nCabs;			// always >= 1
    CONST Partition_header_t *PartCap;	// HP Cellular systems only
    CONST Blade_header_t *BladeCap;	// HP cClass and ATCA systems only
    CONST BMC_log_header_t SELCap;	// SEL capabilities
    CONST BMC_log_header_t FPLCap;	// FPL capabilities
    CONST BMC_log_header_t SDRCap;	// SDR capabilities
          SDR_entry_t CONST **SDR;	// Array of size nSDRs
    CONST int nSDRs;			// Can be > SDRCap.RecordsUsed
          SDR_entry_t **Sensors;	// From SDR; "bulk" sensors expanded
    CONST int nSensors;			// Number of entries in Sensors[]
          void **Dictionaries;		// Array of event dictionaries
    CONST int nDictionaries;		// How many
    CONST char *version;		// EZBMC library version
    CONST struct MYOB_t *h;		// hidden magic: IO encapsulation
} BMC_t;

/********************** APIs to most common IPMI concepts *******************/

int BMC_open(BMC_t *bmc, char *device, uint16_t fill_flags);

int BMC_open_IPMB(BMC_t *bmc, char *device, uint16_t fill_flags, uint8_t IPMBaddr);

int BMC_open_CHIF(BMC_t *bmc);

void BMC_close(BMC_t *bmc);

void BMC_close_CHIF(BMC_t *bmc);

int BMC_CmdRsp(BMC_t *bmc, 
               void *cmd, int cmdlen,
	       void *rsp, int rsplen);

int BMC_CmdRsp_CHIF(BMC_t *bmc,
		    void *cmd, int cmdlen,
		    void *rsp, int rsplen);

int BMC_CmdRsp_IPMB(BMC_t *bmc,
		    void *cmd, int cmdlen,
		    void *rsp, int rsplen,
		    uint8_t BusAddr);

extern int OA_CLI_Exec(BMC_t *bmc, cli_request *command, uint8_t *status, str_buf *out, str_buf *err);

void BMC_EntityID2Desc(char Desc[], uint8_t EntityID);

int BMC_SDR_status(BMC_t *bmc);

SDR_entry_t *BMC_sensor_match(BMC_t *bmc, 
			      uint8_t EntityID,
			      uint8_t EntityInst,
			      uint8_t RecType,	   // EZBMC_SDR_TYPE_SENSOR_*
			      uint8_t EvRdType);   // EZBMC_EVRD_TYPE_*

int BMC_sensor_read(BMC_t *bmc, SDR_entry_t *pSDR, IPMI_sensor_values_t *pVal);

float BMC_sensor_convert_analog(uint8_t raw, SDR_entry_t *pSDR);

void BMC_sensor_units(char Desc[], 
		      IPMI_sensor_values_t *pVAL, 
		      SDR_entry_t *pSDR);

SDR_entry_t *BMC_container(BMC_t *bmc, SDR_entry_t *pSDR);

int BMC_IPMB_addr(BMC_t *bmc, unsigned int cmd, unsigned int *BusAddr);

int BMC_watchdog_set(BMC_t *bmc, unsigned int timeoutSecs, unsigned int action);

int BMC_watchdog_reset(BMC_t *bmc);

// SPPA definition of a "null" physical location.  It's currently used in
// all foundation entities as a flag to print nothing.  FYI, source and
// detail are 0, all other fields are 0xFF

extern const physloc_t BMC_physloc_NULL;

static inline int BMC_physloc_NULL_test(const physloc_t *PL) {
	return (!memcmp(PL, &BMC_physloc_NULL, sizeof(physloc_t)));
}

static inline int BMC_physloc_equal(const physloc_t *p1, const physloc_t *p2) {
        return (!memcmp(p1, p2, sizeof(physloc_t)));
}

#define PHYSLOC_STRING_LENGTH 24

typedef char physloc_str[PHYSLOC_STRING_LENGTH];

void BMC_physloc_to_str(const physloc_t *p, physloc_str str);
int BMC_str_to_physloc(const char *str, physloc_t *p);

#ifdef __cplusplus
}
#endif

#endif
