#ifndef _EZBMC_STRERROR_ERRNO_DOT_H
#define _EZBMC_STRERROR_ERRNO_DOT_H

#ifdef __cplusplus
extern "C" {
#endif

#define EZBMC_ERRNO_NONE		0	// in case you were wondering

/* Constants for standard IPMI errors and ezbmc-defined errors.  Any error
   code < 0 is the negative of a Linux error in <errno.h>.  One-byte errors
   are Completion Codes returned from the BMC (either stock IPMI errors or
   HP OEM extensions).  Errors > 0xFF are from the ezbmc library. */

/************************** HP OEM extensions, 0 < errno <= 0x7F */

#define EZBMC_ERRNO_NO_TARGET		0x01
#define EZBMC_ERRNO_TARGET_NOT_LOCKABLE	0x02
#define EZBMC_ERRNO_TARGET_NOT_LOCKED	0x03
#define EZBMC_ERRNO_ALREADY_LOCKED_BY_SMS 0x04
#define EZBMC_ERRNO_ALREADY_LOCKED_BY_BMC 0x05
#define EZBMC_ERRNO_LOCK_NOT_RELEASED	 0x06
#define EZBMC_ERRNO_LOCK_INVALID	 0x07
#define EZBMC_ERRNO_TARGET_BAD_COMMAND	 0x08
#define EZBMC_ERRNO_PROPERTY_SET_FAILED	 0x09

#define EZBMC_ERRNO_BAD_TOKEN_CHECKSUM	 0x70

/************************** IPMI 1.5 errors (chapter 6), 0x80 < errno <= 0xFF */

#define EZBMC_ERRNO_BUSY		0xC0
#define EZBMC_ERRNO_CMD_INVALID		0xC1
#define EZBMC_ERRNO_LUN_INVALID		0xC2
#define EZBMC_ERRNO_TIMEOUT		0xC3
#define EZBMC_ERRNO_NO_MEMORY		0xC4
#define EZBMC_ERRNO_RESERVATION_ID	0xC5
#define EZBMC_ERRNO_REQ_TRUNCATED	0xC6
#define EZBMC_ERRNO_REQ_LENGTH_INVALID	0xC7
#define EZBMC_ERRNO_REQ_LENGTH_EXCEEDED	0xC8
#define EZBMC_ERRNO_PARAMETER		0xC9
#define EZBMC_ERRNO_CANT_RETURN_BYTES	0xCA
#define EZBMC_ERRNO_NOT_PRESENT		0xCB
#define EZBMC_ERRNO_REQ_DATA_INVALID	0xCC
#define EZBMC_ERRNO_REQ_ILLEGAL		0xCD
#define EZBMC_ERRNO_RESP_UNAVAILABLE	0xCE
#define EZBMC_ERRNO_REQ_DUPLICATE	0xCF

// IPMI 1.5 for RMCP (IPMI over LAN).  Some commands conflict on description.

#define EZBMC_ERRNO_USER_PRIVILEGE		0x80
#define EZBMC_ERRNO_BAD_USER_SLOT_LEVEL		0x81	// aliased.  see spec
#define EZBMC_ERRNO_SEL_CLEAR_IN_PROGRESS	0x81	// for Get SEL entry
#define EZBMC_ERRNO_NULL_USER_SLOT_LEVEL	0x82
#define EZBMC_ERRNO_NO_SLOT_PRIVILEGE		0x83
#define EZBMC_ERRNO_SESSION_SEQ_ERANGE		0x84
#define EZBMC_ERRNO_BAD_SESSION_ID_ACTIVATE	0x85
#define EZBMC_ERRNO_PRIVILEGE_EXCEEDED		0x86
#define EZBMC_ERRNO_BAD_SESSION_ID_CLOSE	0x87

#define EZBMC_ERRNO_SDRR_UPDATE			0xD0
#define EZBMC_ERRNO_FW_UPDATE			0xD1
#define EZBMC_ERRNO_BMC_AGENT_INIT		0xD2
#define EZBMC_ERRNO_DEST_UNAVAILABLE		0xD3
#define EZBMC_ERRNO_INSUFFICIENT_PRIVILEGE	0xD4
#define EZBMC_ERRNO_NOT_NOW			0xD5

#define EZBMC_ERRNO_OPEN_IPMI		0xFF	// Driver "stole" this value

/****************************** Library-defined errors, > 0xFF */

#define	EZBMC_ERRNO_ASYNC_EVENT		0x100	// Generic errors
#define	EZBMC_ERRNO_IPMB_CMD		0x101
#define	EZBMC_ERRNO_BAD_RECV		0x102
#define EZBMC_ERRNO_UNKNOWN_BMC		0x103
// The two most likely errors on BMC_open of default device files, this
// allows a more meaningful error message than just EACCES or ENOENT
#define EZBMC_ERRNO_DEFAULT_DEV_EACCES	0x104
#define EZBMC_ERRNO_DEFAULT_DEV_ENOENT	0x105
#define EZBMC_ERRNO_IPMB_SCHIZOID	0x106
#define EZBMC_ERRNO_IPMB_BAD_ADDR	0x107
#define EZBMC_ERRNO_NO_RMCP		0x108
#define EZBMC_ERRNO_NO_DRIVER		0x109
#define EZBMC_ERRNO_BADHASH		0x10A
#define EZBMC_ERRNO_OLD_FW_GXL_ILO2	0x10B	// Gromit on ProLiant
#define EZBMC_ERRNO_OLD_FW_GXE_ILO3	0x10C	// Gromit on ProLiant

#define EZBMC_ERRNO_SDR_BAD_COUNT	0x200
#define EZBMC_ERRNO_SDR_BAD_READ	0x201
#define EZBMC_ERRNO_SDR_MISSING		0x202
#define EZBMC_ERRNO_SDR_ILLEGAL		0x203

#define EZBMC_ERRNO_SEL_BAD_COUNT	0x300

#define EZBMC_ERRNO_IPMI_DICT_MISSING	0x400
#define EZBMC_ERRNO_IPMI_DICT_BAD_PARSE	0x401

#define EZBMC_ERRNO_NOT_CELLULAR	0x500
#define EZBMC_ERRNO_PROPERTY_ILLEGAL	0x501
#define EZBMC_ERRNO_UNKNOWN_PARTITION	0x502
#define EZBMC_ERRNO_UNKNOWN_GROUPA	0x503
#define EZBMC_ERRNO_UNKNOWN_RECONFIG_DATA	0x504
#define EZBMC_ERRNO_UNKNOWN_RECONFIG_STATE	0x505
#define EZBMC_ERRNO_UNKNOWN_GROUPC	0x506
#define EZBMC_ERRNO_BAD_CELL2PARTITION_MAP	0x507

#define EZBMC_ERRNO_FRU_READ_COMMON_HEADER	0x600
#define EZBMC_ERRNO_FRU_CHECKSUM	0x601
#define EZBMC_ERRNO_FRU_FORMAT		0x602
#define EZBMC_ERRNO_FRU_PARTIAL		0x603
#define EZBMC_ERRNO_FRU_NOT_ASCII	0x604
#define EZBMC_ERRNO_FRU_NOT_BINARY	0x605
#define EZBMC_ERRNO_FRU_OEM_UNPARSED	0x610

#define EZBMC_ERRNO_NO_CELL		0x700
#define EZBMC_ERRNO_NO_PARTITION	0x701

// Runtime dynamic library loading for XML support, other link errors
#define EZBMC_ERRNO_LIBDL_NOT_LINKED	0x800
#define EZBMC_ERRNO_LIBDL_DLOPEN	0x801
#define EZBMC_ERRNO_LIBDL_DLSYM		0x802
#define EZBMC_ERRNO_LINK_IPMITEXT	0x803
#define EZBMC_ERRNO_LINK_IMLTEXT	0x804

// Actual XML usage
#define EZBMC_ERRNO_LIBXML2_BAD_PARSE	0x900

// ProLiant IML (Integrated Management Log)
#define EZBMC_ERRNO_IML_UNKNOWN		0xA00
#define EZBMC_ERRNO_IML_NO_SPACE	0xA01
#define EZBMC_ERRNO_IML_NOT_FOUND	0xA02
#define EZBMC_ERRNO_IML_INVALID		0xA03
#define EZBMC_ERRNO_IML_80_PERCENT	0xA04

// Returned by IPMI caching daemon
#define EZBMC_ERRNO_MANAGED_BY_DAEMON	0xB00

#define EZBMC_ERRNO_PL_DICT_MISSING	0xC00
#define EZBMC_ERRNO_PL_DICT_BAD_PARSE	0xC01

char *BMC_strerror(int errorNum);

#ifdef __cplusplus
}
#endif

#endif
