#ifndef	_DOT_EZBMC_PROPERTY_DOT_H
#define	_DOT_EZBMC_PROPERTY_DOT_H

#ifdef __cplusplus
extern "C" {
#endif

/* HP Property Types: HP OEM IPMI Extensions Document page 17, SDR table */

#define EZBMC_PROPERTY_TYPE_ASSOCIATION		0x00
#define EZBMC_PROPERTY_TYPE_DATA		0x01
#define EZBMC_PROPERTY_TYPE_CONTROL		0x02

#define EZBMC_PROPERTY_DATA_NUMBER              0x00
#define EZBMC_PROPERTY_DATA_ACEXPECTED          0x01
#define EZBMC_PROPERTY_DATA_GROUPA              0x02
#define EZBMC_PROPERTY_DATA_RECONFIG_DATA       0x03
#define EZBMC_PROPERTY_DATA_RECONFIG_STATE      0x04
#define EZBMC_PROPERTY_DATA_GROUPB              0x05
#define EZBMC_PROPERTY_DATA_GROUPC              0x06
#define EZBMC_PROPERTY_DATA_CELLINFO		0x07
#define EZBMC_PROPERTY_DATA_BIB			0x08
#define EZBMC_PROPERTY_DATA_CABINET_TYPE        0x09
#define EZBMC_PROPERTY_DATA_UUID                0x0A
#define EZBMC_PROPERTY_DATA_CREATOR_MFGR        0x0B
#define EZBMC_PROPERTY_DATA_OEM_MFGR            0x0C
#define EZBMC_PROPERTY_DATA_CREATOR_PRODUCT_NAME 0x0D
#define EZBMC_PROPERTY_DATA_OEM_PRODUCT_NAME    0x0E
#define EZBMC_PROPERTY_DATA_CREATOR_SERIAL_NUM  0x0F
#define EZBMC_PROPERTY_DATA_OEM_SERIAL_NUM      0x10
#define EZBMC_PROPERTY_DATA_RIO_CABLE_STATUS	0x11
#define EZBMC_PROPERTY_DATA_DIMM_FRUINFO	0x12 // Arches only from here
#define EZBMC_PROPERTY_DATA_FPU_SYS_BACKPLANE	0x13
#define EZBMC_PROPERTY_DATA_FPU_IO_CHASSIS	0x14
#define EZBMC_PROPERTY_DATA_FPU_CELL_PDH	0x15
#define EZBMC_PROPERTY_DATA_FPU_CORE_IO		0x16
#define EZBMC_PROPERTY_DATA_FPU_UGUY		0x17
#define EZBMC_PROPERTY_DATA_FPU_MP		0x18
#define EZBMC_PROPERTY_DATA_FPU_UPDATE_PERMS	0x19
#define EZBMC_PROPERTY_DATA_FRONT_PANEL_LED	0x1A
#define EZBMC_PROPERTY_DATA_ASSET_TAG		0x1B

#define EZBMC_CONTROL_DATA_BINARY_POWER 0x00

#define EZBMC_PROPERTY_READABLE		0x01
#define EZBMC_PROPERTY_MULTI_GET	0x02
#define EZBMC_PROPERTY_WRITEABLE	0x04
#define EZBMC_PROPERTY_MULTI_SET	0x08
#define EZBMC_PROPERTY_PARTIAL_SET	0x10
#define EZBMC_PROPERTY_LOCKABLE		0x20

#define EZBMC_PROPERTY_GET_ALL		0xFFFF

#define EZBMC_PROPERTY_WRITE_LOCK	0
#define EZBMC_PROPERTY_READ_LOCK	1
#define EZBMC_PROPERTY_BREAK_LOCK   (BMC_LockedProperty_t *)0x1234DEAFDEADBEEF

// LEDs in various places, these are states, use them in app code
#define EZBMC_INDICATOR_MISSING		0
#define EZBMC_INDICATOR_QUIESCENT	1	// sometimes compared <=
#define EZBMC_INDICATOR_ON		2
#define EZBMC_INDICATOR_OFF		3
#define EZBMC_INDICATOR_BLINKING	4
#define	EZBMC_INDICATOR_UNKNOWN		5

// magic flag - yes there's an entity here, no it doesn't have an indicator
// should be no need to use this in user apps.  This is really in support
// of Oly/Eiger, so that apps can still print out entity existence

#define EZBMC_INDICATOR_MISSING_SDR	(SDR_entry_t*)0x1234DEAFDEADBEEF

typedef struct {
	uint32_t	checksum;
	uint32_t	sequence_id;
	uint16_t	major_rev;
	uint16_t	minor_rev;
	uint8_t		cell_width;
	uint8_t		r1[7];
	char		model_string[16];
	char		serial_num[10];
	char		complex_name[20];
	char		orig_prod_num[6];
	char		cur_prod_num[6];
	uint8_t		r2[2];
	uint8_t		cell_assignments[64];
	uint8_t		r3[384];
	uint16_t	GNI_reqs[64];
	uint8_t		r4[64];
	uint64_t	GI_ranges[64];
	uint8_t		r5[64];
	uint16_t	min_ZI_reqs[64];
	uint16_t	max_ZI_reqs[64];
	uint8_t		r6[64];
	uint8_t		r7[256];
	uint8_t		r8[512];
	uint32_t	diag_license;
	uint32_t	sub_id;
	uint8_t		r9[8];
	uint8_t		maxparts;
	uint8_t		r10[7];
	uint16_t	GSM_info[16];
	uint8_t		r11[632];
} __attribute__((packed)) GroupA_t;

// SPPA Platform EAS, Appendix E, Table E-1.
// The Extended Data Area header prepends appropriate properties

typedef struct {
	uint32_t	CRC;
	uint16_t	length;
	uint8_t		r0[6];
} __attribute__((packed)) ExtDataHeader_t;

// SPPA Platform EAS, Appendix E, Table E-2.
// "markers" for walking all the "elements" in appropriate properties

typedef struct {
	uint16_t	ID;
	uint16_t	length;
} __attribute__((packed)) ExtDataElement_t;

// SPPA Platform EAS, Appendix D, after prepending the headers per appendix E.
typedef struct {
	ExtDataHeader_t	EDheader;	// Never ever ever ever change this...
	ExtDataElement_t EDelement;	// ...or this..
	uint32_t	checksum;	// ...or this..
	uint32_t	sequence_id;	// ...or this
	uint64_t	PAonly1[4];	// You're on your own from here
	uint64_t	r1;
	uint64_t	CellConfiguration;
	uint8_t		RootCells[4];
	uint8_t		PDnumber;
	uint8_t		PAonly2[4];
	uint8_t		r2[6];
	uint8_t		ia64;		/* Must be 1, 0 == PA */
	uint64_t	r3[3];		/* Look closely at offsets */
	uint16_t	ICODprocs;
	uint8_t		r4[6];
	uint64_t	PAonly3[16];
	uint8_t		PartitionName[64];
	uint8_t		CellIntegration[64];
	uint8_t		IPaddr[16];
	uint8_t		pad[0x200 - 0x178];
} __attribute__((packed)) GroupC_t;

typedef struct {
	uint64_t	affected_cell_mask; /* cells affected by reconfig */
	uint64_t	pd_boot_mask; /* partitions booted after reconfig */
	GroupA_t	GroupA;
} __attribute__((packed)) reconfig_data_t;

// Rows of variable-length tables in Cell Info property, also a row in
// the maximally-sized tables in the CellInfo_t structure.

typedef struct {
	uint8_t  slottype;
	uint8_t  cardtype;
	uint8_t  r1[6];
	uint16_t VendorID;		// Info0
	uint16_t DeviceID;
	uint16_t CmdReg;
	uint16_t StatusReg;
	uint8_t  RevID;			// Info1
	uint8_t  Class[3];
	uint8_t  CacheLineSize;
	uint8_t  LatencyTimer;
	uint8_t  HeaderType;
	uint8_t  BIST;
	physloc_t physloc;
	uint64_t paHWpath;		// Size is 0x28 == 40 bytes, per doc
} __attribute__((packed)) CellInfoIOslot_t;

typedef struct {
	uint8_t slot;
	uint8_t size;
	uint8_t status;
	uint8_t type;
} __attribute__((packed)) CellInfoDIMMinfo_t;

// Finally, real cell info.  This packed mapping is valid up until the
// variable length table for IO slots.  I can only read the number of 
// bytes up to nIOslots in one big chunk.

#define CELL_MAX_IO_SLOTS	16	// 12 on Orca/Dome; 8 on midrange
#define CELL_MAX_DIMM_SLOTS	32	// For all

typedef struct {
	ExtDataHeader_t	EDheader;	// Never ever ever ever change this...
	ExtDataElement_t EDelement;	// ...or this
	uint32_t	SFWminor;	// "SFW" mnemonic used by MP card
	uint32_t	SFWmajor;
	uint64_t	Cap;
	uint64_t	r1[2];
	uint8_t		status;
	uint8_t		state;
	uint16_t	r2;
	uint8_t		layoutrev;
	uint8_t		r3[3];
	physloc_t	physloc;

	// these 64 bits are CPU information
	uint16_t	CPUdeconfigured;	// bitmask
	uint16_t	CPUpresent;		// bitmask
	uint16_t	pa1;
	uint8_t		CPUnummax;
	uint8_t		ClockDomain;

	uint64_t	CPUspeed;		// ticks per 10 msec

	physloc_t	IOphysloc;
	uint64_t	IOinfo;
	uint64_t	r4[2];				// already aligned

	uint16_t	IOslotInfoSize;
	uint8_t		r5[6];				// Align to uint64 
	CellInfoIOslot_t IOslots[CELL_MAX_IO_SLOTS];	// read max size

	// Everything up to this point is a direct overlay from get_property
	// The remaining fields follow the general flow but the offsets do
	// not match.  There are also some convenience fields (nIOslots and
	// nDIMMs) that are calculated; they do not exist in the property.
	// This simplifies retrieval/caching at the cost of a little space.

	uint64_t	cell_memory_size;		// Read from prop
	uint16_t	DIMMinfoSize;			// Read from prop
	uint8_t		r6[6];				// Align to uint64 
	CellInfoDIMMinfo_t DIMMs[CELL_MAX_DIMM_SLOTS];	// Read max size
	uint16_t	nIOslots;			// Calculated
	uint16_t	nDIMMs;				// Calculated

	// Read directly from the Cell Memory Interleave extended data.
	// It may not exist (indicates no interleaving?), in which case
	// all values will be zero, which is fine for other calculations.
	// 2008: bug 7373 said the original code wasn't working.  The
	// original docs, pag2_1.pdf, said CMITableRev was a separate
	// 8-byte field.  It once worked.  As of 2008, both an Orca and
	// a Dune showed the pag2_5.pdf layout where TableRev had shrunk
	// to two-bytes and coalesced into the following field.
	// Orca shows a major.minor of 0.0 while Dune is 1.0.  In all
	// cases the spec says they should always be 1.0 so who knows.
        
	uint16_t	CMIreserved;
	uint8_t		CMITableRevMinor;
	uint8_t		CMITableRevMajor;
	uint8_t		CMIMIR;
	uint8_t		CMICells;
	uint8_t		CMIHWCM;
	uint8_t		CMIKGM;

	// This read directly, if offsets are played directly.  It's
	// a maximum-length table because that was a quicker, safer
	// fix for bug 7373 (less than a day from machine up to build
	// deadline).

	uint16_t	CLM_Size[EZBMC_MAX_CELLS];

	// RegionInfo[MIR] is ignored (August 2008)

	// Tagged on to the back end of this struct, once malloc'd, are
	// space for the following two tables.  They're malloc'd elsewhere,
	// then the CellInfo is realloc, tables are copied, then freed.
	// CellInfoIOslot_t   IOslots[nIOslots];
	// CellInfoDIMMinfo_t DIMMs[nDIMMs];		

} __attribute__((packed)) CellInfo_t;

typedef struct {
	int32_t key;
	uint8_t property;
	uint8_t locktype;
	time_t  locktime;
	char holderSWID[128];
} BMC_LockedProperty_t;

typedef struct {
	uint8_t EntityID, EntityInst;
	unsigned char RevAlpha;
	uint8_t RevMajor, RevMinor;
	uint16_t RevBuild;
	uint32_t HWcompat;
} __attribute__((packed)) Arches_FPU_t;

int BMC_property_lock(BMC_t *bmc,
                      SDR_entry_t *pSDR,
		      char *requesterSWID,
                      uint8_t locktype,
                      BMC_LockedProperty_t *locked);

int BMC_property_unlock(BMC_t *bmc, 
                        SDR_entry_t *pSDR,
		        BMC_LockedProperty_t *locked);

int BMC_property_get(BMC_t *bmc, 
		     SDR_entry_t *pSDR,
		     BMC_LockedProperty_t *locked, 
		     uint32_t offset, 
		     uint16_t length, 
		     uint8_t rsp[]);

int BMC_property_set(BMC_t *bmc, 
		     SDR_entry_t *pSDR,
		     BMC_LockedProperty_t *locked, 
		     uint32_t offset, 
		     uint16_t length, 
		     uint8_t data[]);

SDR_entry_t *BMC_property_match_data(BMC_t *bmc, 
				uint8_t EntityID,
				uint8_t EntityInst,
				uint16_t DataType);

SDR_entry_t *BMC_property_match_control(BMC_t *bmc, 
				uint8_t EntityID,
				uint8_t EntityInst,
				uint16_t ControlType);

int BMC_GroupC_get(BMC_t *bmc, 
		   int partnum, 
		   GroupC_t **GroupC);

int BMC_GroupC_set(BMC_t *bmc, 
		   int partnum, 
		   GroupC_t *GroupC);

int BMC_CellInfo_get(BMC_t *bmc, 
		     int cellnum, 
		     CellInfo_t **pCellInfo);

int BMC_indicator_get(BMC_t *bmc, SDR_entry_t *pSDR, unsigned int *effect);

int BMC_indicator_set(BMC_t *bmc, SDR_entry_t *pSDR, unsigned int effect);

int BMC_partition_indicators(BMC_t *bmc,
			     SDR_entry_t ***cabinets,
			     SDR_entry_t ***cells,
			     SDR_entry_t ***IOCs,
			     unsigned int *nIndicators);

void BMC_physloc_parse(BMC_t *bmc, char textmsg[], physloc_t *pl);

#ifdef __cplusplus
}
#endif

#endif
