#ifndef _EZBMC_IPMI_DOT_H
#define _EZBMC_IPMI_DOT_H

#ifdef __cplusplus
extern "C" {
#endif

/* Common IPMI constants.  It's only the ones needed by the devloper or
   given to him, if you think I'm doing them all you're nuts. */

/* SDR types: IPMI 1.0 table 28-11 */

#define EZBMC_SDR_TYPE_SENSOR_FULL		0x01
#define EZBMC_SDR_TYPE_SENSOR_COMPACT		0x02
#define EZBMC_SDR_TYPE_ENTITY_ASSOCIATION	0x08
#define EZBMC_SDR_TYPE_ENTITY_ASSOCIATION_DEVREL 0x09
#define EZBMC_SDR_TYPE_DEVICE_GENERIC		0x10
#define EZBMC_SDR_TYPE_DEVICE_FRU		0x11
#define EZBMC_SDR_TYPE_DEVICE_MC		0x12
#define EZBMC_SDR_TYPE_MC_CONFIRMATION          0x13
#define EZBMC_SDR_TYPE_BMC_MSGCHAN_INFO         0x14
#define EZBMC_SDR_TYPE_OEM			0xC0
#define EZBMC_SDR_TYPE_HP_PROPERTY		EZBMC_SDR_TYPE_OEM
#define EZBMC_SDR_TYPE_DEVICE_FRU_IGNORE	0x42

/* Sensor types: IPMI 1.0 table 30-3 */

#define EZBMC_SENSOR_TYPE_TEMPERATURE		0x01
#define EZBMC_SENSOR_TYPE_VOLTAGE		0x02
#define EZBMC_SENSOR_TYPE_CURRENT		0x03
#define EZBMC_SENSOR_TYPE_FAN			0x04
#define EZBMC_SENSOR_TYPE_PHYSICAL_SECURITY	0x05
#define EZBMC_SENSOR_TYPE_PLATFORM_SECURITY	0x06
#define EZBMC_SENSOR_TYPE_PROCESSOR		0x07
#define EZBMC_SENSOR_TYPE_POWER_SUPPLY		0x08
#define EZBMC_SENSOR_TYPE_POWER_UNIT		0x09
#define EZBMC_SENSOR_TYPE_COOLING_DEVICE	0x0A
#define EZBMC_SENSOR_TYPE_MEMORY		0x0C
#define EZBMC_SENSOR_TYPE_DRIVE_BAY             0x0D
#define EZBMC_SENSOR_TYPE_POST_ERROR		0x0F
#define EZBMC_SENSOR_TYPE_EVENT_LOGGING		0x10
#define EZBMC_SENSOR_TYPE_SYSTEM_EVENT		0x12
#define EZBMC_SENSOR_TYPE_SFW_EVENT		0x13
#define EZBMC_SENSOR_TYPE_MODULE_BOARD		0x15
#define EZBMC_SENSOR_TYPE_ADDIN_CARD		0x17
#define EZBMC_SENSOR_TYPE_CHASSIS		0x18
#define EZBMC_SENSOR_TYPE_DRIVE_CABLE           0x1B
#define EZBMC_SENSOR_TYPE_DRIVE_TERMINATION     0x1C
#define EZBMC_SENSOR_TYPE_SYSTEM_BOOT		0x1D
#define EZBMC_SENSOR_TYPE_ACPI_POWER_STATE      0x22
#define EZBMC_SENSOR_TYPE_WATCHDOG2		0x23
#define EZBMC_SENSOR_TYPE_ENTITY_PRESENCE	0x25
#define EZBMC_SENSOR_TYPE_LAN			0x27
#define EZBMC_SENSOR_TYPE_MGMT_SUBSYS_HEALTH	0x28
#define EZBMC_SENSOR_TYPE_BATTERY		0x29

// For ATCA
#define EZBMC_SENSOR_TYPE_PICMG3_HOTSWAP	0xF0
#define EZBMC_SENSOR_TYPE_PICMG3_IPMB		0xF1

/* Sensor unit type codes.  IPMI 1.0 Table 28.13 */

#define EZBMC_UNIT_TYPE_UNSPECIFIED 	0 
#define EZBMC_UNIT_TYPE_DEGREESC    	1 
#define EZBMC_UNIT_TYPE_DEGREESF    	2 
#define EZBMC_UNIT_TYPE_DEGREESK 	3    
#define EZBMC_UNIT_TYPE_VOLTS 		4       
#define EZBMC_UNIT_TYPE_AMPS 		5        
#define EZBMC_UNIT_TYPE_WATTS 		6       
#define EZBMC_UNIT_TYPE_JOULES 		7      
#define EZBMC_UNIT_TYPE_COULOMBS 	8    
#define EZBMC_UNIT_TYPE_VA 		9          
#define EZBMC_UNIT_TYPE_NITS 		10       
#define EZBMC_UNIT_TYPE_LUMEN 		11      
#define EZBMC_UNIT_TYPE_LUX 		12        
#define EZBMC_UNIT_TYPE_CANDELA 	13    
#define EZBMC_UNIT_TYPE_KPA 		14        
#define EZBMC_UNIT_TYPE_PSI 		15        
#define EZBMC_UNIT_TYPE_NEWTON 		16     
#define EZBMC_UNIT_TYPE_CFM 		17        
#define EZBMC_UNIT_TYPE_RPM 		18        
#define EZBMC_UNIT_TYPE_HZ 		19         
#define EZBMC_UNIT_TYPE_USEC 		20       
#define EZBMC_UNIT_TYPE_MSEC 		21       
#define EZBMC_UNIT_TYPE_SEC 		22        
#define EZBMC_UNIT_TYPE_MIN 		23        
#define EZBMC_UNIT_TYPE_HOUR 		24       
#define EZBMC_UNIT_TYPE_DAY 		25        
#define EZBMC_UNIT_TYPE_WEEK 		26       
#define EZBMC_UNIT_TYPE_MIL 		27        
#define EZBMC_UNIT_TYPE_INCH 		28       
#define EZBMC_UNIT_TYPE_FEET 		29       
#define EZBMC_UNIT_TYPE_CUIN 		30       
#define EZBMC_UNIT_TYPE_CUFT 		31       
#define EZBMC_UNIT_TYPE_MM 		32         
#define EZBMC_UNIT_TYPE_CM 		33         
#define EZBMC_UNIT_TYPE_M 		34          
#define EZBMC_UNIT_TYPE_CUCM 		35       
#define EZBMC_UNIT_TYPE_CUM 		36        
#define EZBMC_UNIT_TYPE_LITER 		37      
#define EZBMC_UNIT_TYPE_FLOZ 		38       
#define EZBMC_UNIT_TYPE_RAD 		39        
#define EZBMC_UNIT_TYPE_STERAD 		40     
#define EZBMC_UNIT_TYPE_REV 		41        
#define EZBMC_UNIT_TYPE_CYCLE 		42      
#define EZBMC_UNIT_TYPE_GRAVITY 	43    
#define EZBMC_UNIT_TYPE_OZ 		44         
#define EZBMC_UNIT_TYPE_LB 		45         
#define EZBMC_UNIT_TYPE_FTLB 		46       
#define EZBMC_UNIT_TYPE_OZIN 		47       
#define EZBMC_UNIT_TYPE_GAUSS 		48      
#define EZBMC_UNIT_TYPE_GILBERT 	49    
#define EZBMC_UNIT_TYPE_HENRY 		50      
#define EZBMC_UNIT_TYPE_MHENRY 		51     
#define EZBMC_UNIT_TYPE_FARAD 		52      
#define EZBMC_UNIT_TYPE_UFARAD 		53     
#define EZBMC_UNIT_TYPE_OHM 		54        
#define EZBMC_UNIT_TYPE_SIEMEN 		55     
#define EZBMC_UNIT_TYPE_MOLE 		56       
#define EZBMC_UNIT_TYPE_BECQ 		57       
#define EZBMC_UNIT_TYPE_PPM 		58        
#define EZBMC_UNIT_TYPE_RESERVED 	59   
#define EZBMC_UNIT_TYPE_DB 		60         
#define EZBMC_UNIT_TYPE_DBA 		61        
#define EZBMC_UNIT_TYPE_DBC 		62        
#define EZBMC_UNIT_TYPE_GRAY 		63       
#define EZBMC_UNIT_TYPE_SIEVERT 	64    
#define EZBMC_UNIT_TYPE_CTK 		65        
#define EZBMC_UNIT_TYPE_BIT 		66        
#define EZBMC_UNIT_TYPE_KBIT 		67       
#define EZBMC_UNIT_TYPE_MBIT 		68       
#define EZBMC_UNIT_TYPE_GBIT 		69       
#define EZBMC_UNIT_TYPE_BYTE 		70       
#define EZBMC_UNIT_TYPE_KBYTE 		71      
#define EZBMC_UNIT_TYPE_MBYTE 		72      
#define EZBMC_UNIT_TYPE_GBYTE 		73      
#define EZBMC_UNIT_TYPE_WORD 		74       
#define EZBMC_UNIT_TYPE_DWORD 		75      
#define EZBMC_UNIT_TYPE_QWORD 		76      
#define EZBMC_UNIT_TYPE_LINE 		77       
#define EZBMC_UNIT_TYPE_HIT 		78        
#define EZBMC_UNIT_TYPE_MISS 		79       
#define EZBMC_UNIT_TYPE_RETRY 		80      
#define EZBMC_UNIT_TYPE_RESET 		81      
#define EZBMC_UNIT_TYPE_ORUNOFLOW   	82
#define EZBMC_UNIT_TYPE_UNDERRUN    	83
#define EZBMC_UNIT_TYPE_COLL        	84
#define EZBMC_UNIT_TYPE_PKT         	85
#define EZBMC_UNIT_TYPE_MSG         	86
#define EZBMC_UNIT_TYPE_CHAR        	87
#define EZBMC_UNIT_TYPE_ERR         	88
#define EZBMC_UNIT_TYPE_CERR  		89      
#define EZBMC_UNIT_TYPE_UERR 		90       

/* Event/Reading Type Codes */

#define EZBMC_EVRD_TYPE_ANY	 		0x00	// for BMC_sensor_match
#define EZBMC_EVRD_TYPE_THRESHOLD 		0x01
#define EZBMC_EVRD_TYPE_DISCRETE_USAGE  	0x02
#define EZBMC_EVRD_TYPE_DISCRETE_STATE 		0x03
#define EZBMC_EVRD_TYPE_DISCRETE_PREDICTIVE 	0x04
#define EZBMC_EVRD_TYPE_DISCRETE_LIMIT 		0x05
#define EZBMC_EVRD_TYPE_DISCRETE_PERFORMANCE 	0x06
#define EZBMC_EVRD_TYPE_DISCRETE_SEVERITY 	0x07
#define EZBMC_EVRD_TYPE_DISCRETE_AVAILABILITY 	0x08
#define EZBMC_EVRD_TYPE_DISCRETE_ENABLED 	0x09
#define EZBMC_EVRD_TYPE_DISCRETE_TRANSITION 	0x0A
#define EZBMC_EVRD_TYPE_DISCRETE_REDUNDANCY 	0x0B
#define EZBMC_EVRD_TYPE_DISCRETE_ACPI 		0x0C
#define EZBMC_EVRD_TYPE_DISCRETE_SENSOR_SPECIFIC 0x6F
#define EZBMC_EVRD_TYPE_OEM			0x70

// See "Get Sensor Reading", IPMI 1.5 section 29.14 and 29.15.  EvRdType
// of "Threshold" overrides the masking described in full/compact sensors.
// Okay, the spec says "at OR above" and "at OR below" but...

#define EZBMC_STATE_ABOVE_NONRECOVERABLE	0x20
#define EZBMC_STATE_ABOVE_CRITICAL		0x10
#define EZBMC_STATE_ABOVE_NONCRITICAL		0x08
#define EZBMC_STATE_BELOW_NONRECOVERABLE	0x04
#define EZBMC_STATE_BELOW_CRITICAL		0x02
#define EZBMC_STATE_BELOW_NONCRITICAL		0x01

#define EZBMC_STATE_ABOVE_ANY \
    (EZBMC_STATE_ABOVE_NONRECOVERABLE | \
     EZBMC_STATE_ABOVE_NONRECOVERABLE | \
     EZBMC_STATE_ABOVE_NONCRITICAL)

#define EZBMC_STATE_BELOW_ANY \
    (EZBMC_STATE_BELOW_NONRECOVERABLE | \
     EZBMC_STATE_BELOW_NONRECOVERABLE | \
     EZBMC_STATE_BELOW_NONCRITICAL)

///////////////////////////////////////////////////////
// IPMI Spec 1.5: Table 36-2 Generic Event/Reading Type Codes

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_USAGE
#define EZBMC_STATE_USAGE_TO_IDLE                       (1 << 0x00)
#define EZBMC_STATE_USAGE_TO_ACTIVE                     (1 << 0x01)
#define EZBMC_STATE_USAGE_TO_BUSY                       (1 << 0x02)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_STATE
#define EZBMC_STATE_STATE_DEASSERTED                    (1 << 0x00)
#define EZBMC_STATE_STATE_ASSERTED                      (1 << 0x01)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_PREDICTIVE
#define EZBMC_STATE_PREDICTIVE_FAILURE_DEASSERTED       (1 << 0x00)
#define EZBMC_STATE_PREDICTIVE_FAILURE_ASSERTED         (1 << 0x01)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_LIMIT
#define EZBMC_STATE_LIMIT_NOT_EXCEEDED                  (1 << 0x00)
#define EZBMC_STATE_LIMIT_EXCEEDED                      (1 << 0x01)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_PERFORMANCE
#define EZBMC_STATE_PERFORMANCE_MET                     (1 << 0x00)
#define EZBMC_STATE_PERFORMANCE_LAGS                    (1 << 0x01)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_SEVERITY
#define EZBMC_STATE_SEVERITY_TO_OK                            (1 << 0x00)
#define EZBMC_STATE_SEVERITY_TO_NONCRITICAL_FROM_OK           (1 << 0x01)
#define EZBMC_STATE_SEVERITY_TO_CRITICAL_FROM_LESS_SEVERE     (1 << 0x02)
#define EZBMC_STATE_SEVERITY_TO_NONRECOV_FROM_LESS_SEVERE     (1 << 0x03)
#define EZBMC_STATE_SEVERITY_TO_NONCRITICAL_FROM_MORE_SEVERE  (1 << 0x04)
#define EZBMC_STATE_SEVERITY_TO_CRITICAL_FROM_NONRECOV        (1 << 0x05)
#define EZBMC_STATE_SEVERITY_TO_NONRECOV                      (1 << 0x06)
#define EZBMC_STATE_SEVERITY_MONITOR                          (1 << 0x07)
#define EZBMC_STATE_SEVERITY_INFORMATION                      (1 << 0x08)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_AVAILABILITY
#define EZBMC_STATE_AVAILABILITY_ABSENT                 (1 << 0x00)
#define EZBMC_STATE_AVAILABILITY_PRESENT                (1 << 0x01)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_ENABLED
#define EZBMC_STATE_DEVICE_DISABLED                     (1 << 0x00)
#define EZBMC_STATE_DEVICE_ENABLED                      (1 << 0x01)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_TRANSITION
#define EZBMC_STATE_TRANSITION_TO_RUNNING               (1 << 0x00)
#define EZBMC_STATE_TRANSITION_TO_INTEST                (1 << 0x01)
#define EZBMC_STATE_TRANSITION_TO_POWER_OFF             (1 << 0x02)
#define EZBMC_STATE_TRANSITION_TO_ONLINE                (1 << 0x03)
#define EZBMC_STATE_TRANSITION_TO_OFFLINE               (1 << 0x04)
#define EZBMC_STATE_TRANSITION_TO_OFFDUTY               (1 << 0x05)
#define EZBMC_STATE_TRANSITION_TO_DEGRADED              (1 << 0x06)
#define EZBMC_STATE_TRANSITION_TO_POWER_SAVE            (1 << 0x07)
#define EZBMC_STATE_TRANSITION_INSTALL_ERROR            (1 << 0x08)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_REDUNDANCY
#define EZBMC_STATE_REDUNDANCY_FULLY                    (1 << 0x00)
#define EZBMC_STATE_REDUNDANCY_LOST                     (1 << 0x01)
#define EZBMC_STATE_REDUNDANCY_DEGRADED                 (1 << 0x02)
#define EZBMC_STATE_REDUNDANCY_NONE_SUFF_FROM_REDUNDANT (1 << 0x03)
#define EZBMC_STATE_REDUNDANCY_NONE_SUFF_FROM_INSUFF    (1 << 0x04)
#define EZBMC_STATE_REDUNDANCY_NONE_INSUFF              (1 << 0x05)
#define EZBMC_STATE_REDUNDANCY_DEGRADED_FROM_FULLY      (1 << 0x06)
#define EZBMC_STATE_REDUNDANCY_DEGRADED_FROM_NONE       (1 << 0x07)

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_ACPI
#define EZBMC_STATE_POWER_STATE_D0                      (1 << 0x00)
#define EZBMC_STATE_POWER_STATE_D1                      (1 << 0x01)
#define EZBMC_STATE_POWER_STATE_D2                      (1 << 0x02)
#define EZBMC_STATE_POWER_STATE_D3                      (1 << 0x03)
// End of IPMI Spec 1.5: Table 36-2

///////////////////////////////////////////////////////
// IPMI Spec 1.5: Table 36-3, Sensor Type Codes

// EvRd = EZBMC_EVRD_TYPE_DISCRETE_SENSOR_SPECIFIC
// Sensor type = EZBMC_SENSOR_TYPE_POWER_SUPPLY
#define EZBMC_STATE_PS_PRESENCE_DETECTED                (1 << 0x00)
#define EZBMC_STATE_PS_FAILURE_DETECTED                 (1 << 0x01)
#define EZBMC_STATE_PS_PREDICTIVE_FAILURE               (1 << 0x02)
#define EZBMC_STATE_PS_AC_LOST                          (1 << 0x03)
#define EZBMC_STATE_PS_OUT_OF_RANGE                     (1 << 0x04)
#define EZBMC_STATE_PS_OUT_OF_RANGE_PRESENT             (1 << 0x05)
#define EZBMC_STATE_PS_CONFIGURATION_ERROR              (1 << 0x06) /* IPMI 2.0: Table 42-3 */
// End of IPMI Spec 1.5: Table 36-3

// IPMI 1.5 section 37.1 says "only full sensors have analog readings".
// However section 36.1 says (and the bad English is verbatim),
// "Threshold-based sensors return a different response...The offset The
// Get Sensor Reading command for a threshold-based sensor contains the
// present 'analog' reading from the sensor along in addition to the
// discrete threshold comparison status bit field."  Now, that's the
// raw thing, but in a compact sensor with no conversion factors...
// To apply any factors, first do a "Get Sensor Reading Factors" command,
// cobble up a fake SDR full sensor record and finally call 
// BMC_sensor_conver_analog().  No Integrity servers support a 
// Get Sensor Reading factors call, so ignore it.

#define EZBMC_SENSOR_ANALOG_VALID(PPP)					\
	(PPP && (PPP->RecType <= EZBMC_SDR_TYPE_SENSOR_COMPACT) &&	\
	 ((PPP->s.UnitsFlags & 0xC0) != 0xC0) &&			\
	    (								\
	    	(PPP->s.EvRdType == EZBMC_EVRD_TYPE_THRESHOLD) ||	\
	   	(PPP->RecType == EZBMC_SDR_TYPE_SENSOR_FULL)		\
	    )								\
	)

// This is for ISS use of full sensors where they convert nothing because
// M == 0.  I threw B in there for completeness.

#define EZBMC_SENSOR_ANALOG_PRACTICAL(PPP)				\
	(PPP && (PPP->RecType <= EZBMC_SDR_TYPE_SENSOR_COMPACT) &&	\
	 ((PPP->s.UnitsFlags & 0xC0) != 0xC0) &&			\
	    (								\
	    	(PPP->s.EvRdType == EZBMC_EVRD_TYPE_THRESHOLD) ||	\
		(							\
		    (PPP->RecType == EZBMC_SDR_TYPE_SENSOR_FULL) &&	\
	   	    (PPP->s.M || PPP->s.B)				\
		)							\
	    )								\
	)

// Entity IDs, mostly filled in from actual SDRR entries

#define EZBMC_ENTITY_UNSPECIFIED		0

#define EZBMC_ENTITY_OTHER			1

#define EZBMC_ENTITY_UNKNOWN			2

#define EZBMC_ENTITY_PROCESSOR			3	// especially PIROM

#define EZBMC_ENTITY_DISK			4

#define EZBMC_ENTITY_HP_IO_CHASSIS		5	// cellular

#define EZBMC_ENTITY_SYS_MGMT_MODULE		6
#define EZBMC_ENTITY_HP_MP			6	// cellular

#define EZBMC_ENTITY_SYS_BOARD			7	// Main/motherboard

#define EZBMC_ENTITY_MEMORY_MODULE		8

#define EZBMC_ENTITY_PROCESSOR_MODULE		9

#define EZBMC_ENTITY_POWER_SUPPLY		10
#define EZBMC_ENTITY_HP_BULK_POWER_SUPPLY	10	// cellular - 0x0A

#define EZBMC_ENTITY_ADDIN_CARD			11
#define EZBMC_ENTITY_HP_CORE_IO			11	// cellular - 0x0B

#define EZBMC_ENTITY_FRONT_PANEL_BOARD		12

#define EZBMC_ENTITY_BACK_PANEL_BOARD		13

#define EZBMC_ENTITY_POWER_SYS_BOARD		14	// 0E

#define EZBMC_ENTITY_DRIVE_BACKPLANE		15
#define EZBMC_ENTITY_HP_MASS_STORAGE_BACKPLANE	15	// cellular - 0x0F

#define EZBMC_ENTITY_SYS_BOARD_INTERNAL_EXP	16

#define EZBMC_ENTITY_SYS_BOARD_OTHER		17	// 0x11

#define EZBMC_ENTITY_PROCESSOR_BOARD		18
#define EZBMC_ENTITY_HP_CELL			18	// cellular - 0x12

#define EZBMC_ENTITY_POWER_UNIT			19	// 0x13 - collection

#define EZBMC_ENTITY_POWER_MODULE_CONVERTER	20

#define EZBMC_ENTITY_POWER_MGMT_BOARD		21

#define EZBMC_ENTITY_HP_BAY			22

#define EZBMC_ENTITY_SYSTEM_CHASSIS		23
#define EZBMC_ENTITY_HP_CABINET			23	// cellular - 0x17

#define EZBMC_ENTITY_SUB_CHASSIS		24

#define EZBMC_ENTITY_OTHER_CHASSIS_BOARD	25

#define EZBMC_ENTITY_DISK_BAY			26

#define EZBMC_ENTITY_PERIPHERAL_BAY		27

#define EZBMC_ENTITY_DEVICE_BAY			28	// !disk && !peripheral

#define EZBMC_ENTITY_COOLING_DEVICE		29	// 1D: actual fan

#define EZBMC_ENTITY_COOLING_UNIT		30	// 1E: Collection

#define EZBMC_ENTITY_CABLE			31

#define EZBMC_ENTITY_DIMM			32

#define EZBMC_ENTITY_SMS			33	// Management Software

#define EZBMC_ENTITY_BIOS			34

#define EZBMC_ENTITY_OS				35

#define EZBMC_ENTITY_SYSTEM_BUS			36

#define EZBMC_ENTITY_GROUP			37

#define EZBMC_ENTITY_RMC_DEVICE			38

#define EZBMC_ENTITY_EXTERNAL_ENVIRONMENT	39

#define EZBMC_ENTITY_BATTERY			40	// 0x28

#define EZBMC_ENTITY_BLADE_MODULE		41

#define EZBMC_ENTITY_CONNECTIVITY_SWITCH	42	// 0x2A

#define EZBMC_ENTITY_PM_MODULE			43	// Processor & Memory

#define EZBMC_ENTITY_IO_MODULE			44	// 0x2C

#define EZBMC_ENTITY_PROCESSOR_IO_MODULE	45

#define EZBMC_ENTITY_MANAGEMENT_FIRMWARE	46

#define EZBMC_ENTITY_IPMI_CHANNEL		47

#define EZBMC_ENTITY_PCI_BUS			48

#define EZBMC_ENTITY_PCI_EXPRESS_BUS		49

#define EZBMC_ENTITY_SCSI_BUS			50

#define EZBMC_ENTITY_SATA_BUS			51

#define EZBMC_ENTITY_PROCESSOR_BUS		52

// From Superdome SDR spreadsheet
#define EZBMC_ENTITY_AC_INPUT			0xD0	// Should have had HP_
#define EZBMC_ENTITY_AC_POWER			0xD1	// ditto
#define EZBMC_ENTITY_HP_COMPLEX			0xD2
#define	EZBMC_ENTITY_HP_PARTITION		0xD3
#define EZBMC_ENTITY_HP_PDH_RISER		0xD4
#define EZBMC_ENTITY_HP_CELL_SLOT		0xD5
#define EZBMC_ENTITY_HP_IO_SLOT			0xD6
#define EZBMC_ENTITY_HP_RCS_BOARD		0xD7	// Arches (dune)
#define EZBMC_ENTITY_HP_HSO_BOARD		0xD8	// Arches (dune)

#define EZBMC_HP_CONTROL_BINARY_POWER		0x00
#define EZBMC_HP_CONTROL_TERNARY_POWER		0x01
#define EZBMC_HP_CONTROL_INDICATOR		0x02
#define EZBMC_HP_CONTROL_OLSTAR			0x03
#define EZBMC_HP_CONTROL_PARTITION		0x04

/* IPMI 1.0 table 28-10 / 1.5 table 37-11: IPMB/I2C device types/modifiers.
   There are lots more, this is all we care about in HP ia64 servers.
   BMC in Foundation boxes uses the IPMI 1.5 definitions even though the 
   SDR version says it's 1.0 */

#define EZBMC_IPMBI2C_TYPE_FRU			0x10

#define EZBMC_IPMBI2C_MOD_FRU_LEGACY		0	/* IPMI 1.0 */
#define EZBMC_IPMBI2C_MOD_DIMM			1	/* IPMI 1.5 */
#define EZBMC_IPMBI2C_MOD_FRU			2	/* IPMI 1.5 */
#define EZBMC_IPMBI2C_MOD_PIROM			3	/* IPMI 1.5 */

/* System enclosure and chassis types, from IPMI FRU Information Storage
 * Definition (another spec) table 14. */
enum {
EZBMC_ENCLOSURE_OTHER = 1,
EZBMC_ENCLOSURE_UNKNOWN,
EZBMC_ENCLOSURE_DESKTOP,
EZBMC_ENCLOSURE_LOW_PROFILE_DESKTOP,
EZBMC_ENCLOSURE_PIZZA_BOX,
EZBMC_ENCLOSURE_MINI_TOWER,
EZBMC_ENCLOSURE_TOWER,
EZBMC_ENCLOSURE_PORTABLE,
EZBMC_ENCLOSURE_LAPTOP,
EZBMC_ENCLOSURE_NOTEBOOK,
EZBMC_ENCLOSURE_HANDHELD,
EZBMC_ENCLOSURE_DOCKING_STATION,
EZBMC_ENCLOSURE_ALL_IN_ONE,
EZBMC_ENCLOSURE_SUBNOTEBOOK,
EZBMC_ENCLOSURE_SPACE_SAVING,
EZBMC_ENCLOSURE_LUNCHBOX,		/* 0x10 == 16 */
EZBMC_ENCLOSURE_MAIN_SERVER_CHASSIS,
EZBMC_ENCLOSURE_EXPANSION_CHASSIS,
EZBMC_ENCLOSURE_SUBCHASSIS,
EZBMC_ENCLOSURE_BUS_EXPANSION_CHASSIS,
EZBMC_ENCLOSURE_PERIPHERAL_CHASSIS,
EZBMC_ENCLOSURE_RAID_CHASSIS,
EZBMC_ENCLOSURE_RACK_MOUNT_CHASSIS,
};

#ifdef __cplusplus
}
#endif

#endif
