#ifndef RASBUS_DOT_H
#define RASBUS_DOT_H

#include <stdlib.h>
#include <unistd.h>
#include <string.h>

// non-ia64 needs __USE_GNU to pick up MSG_EXCEPT in bits/msq.h
#if !defined(__ia64) && !defined(__USE_GNU)
#define	__USE_GNU
#define __UNSET__USE_GNU
#endif
#include <sys/types.h>
#include <sys/ipc.h>
#include <sys/msg.h>
#ifdef  __UNSET__USE_GNU
#undef  __USE_GNU
#undef  __UNSET__USE_GNU
#endif

#include <ezbmc.h>
#include <ezbmc_events.h>	// IPMI_MAX_RESPONSE_SIZE

// This version is exchanged in the subtype of an MQ_MSG_PING exchange.
// Appended to it will be the libezbmc.so major.minor.  Change SYSVMQ_VERSION
// if the PROTOCOL ever changes, and let normal ezbmc changes
// be reflected in the soname version.
#define SYSVMQ_VERSION		20090123
#define EZBMC_VERSION_SO	"9.0"

#ifdef DEBUG
#define IPMITIMEOUT	30	// helps during gdb sessions
#else
#define IPMITIMEOUT	6	// one second longer than IPMI spec timeout
#endif

#define MQ_MTYPE_MASTER	1	// Magic mtype/dest for daemon

// Since this is a BMC_CmdRsp backend, clients make a request, the daemon
// provides a response.  The request goes in msg.type from the list below
// and is an even number.  The daemon sets bit 0 in the response.

typedef enum {
    MQ_MSG_NADA = 		0x00,	// don't use this
    MQ_MSG_PING = 		0x02,
    MQ_MSG_IPMI_RAW_CMD = 	0x04,
    MQ_MSG_IPMI_RAW_CMD_IPMB = 	0x06,
    MQ_MSG_BLOCK_DATA = 	0x08,	// see below
    MQ_MSG_CACHE_GET_NEXT = 	0x20,	// By cache index
    MQ_MSG_CACHE_GET_PREV = 	0x22,
    MQ_MSG_CACHE_GET_ENTRY = 	0x24,
    MQ_MSG_CACHE_SET_ENTRY = 	0x26,
    MQ_MSG_HES_DEAD_JIM = 	0xF0
} mq_type_t;

// Block data selectors, used as subtype for MQ_MSG_CACHED_DATA_BLOCK.
// Names are similar to actual BMC_t field.

typedef enum {
    MQ_BLOCK_NADA = 0,	// don't use this
    Cap,	// BMC_header_t
    FPLCap,	// BMC_log_header_t
    SDRCap,	// BMC_log_header_t
    IMLCap,	// BMC_log_header_t (swag)
    SELCap,	// BMC_log_header_t
    SDRs,	// SDR_entry_t
    SDRraw,	// variable-length field in SDR_entry_t
    SDRX,	// SDR_Extension_entry_t, ProLiant only
    FPUs,	// FPU_t
    MPLANParms,	// MPLANParms_t
    BladeCap,	// Blade_header_t
    PartCap,	// Partition_header_t
    CellInfo	// CellInfo_t
} mq_block_data_t;

typedef struct {
	long dest;		// MUST BE FIRST, MUST BE long - aka "mtype"
	long src;		// who sent it, a hash of things
	pid_t srcpid;		// keepalive support
	unsigned long client_seq; // Sequence number, never modified by server
	mq_type_t type;		// housekeeping, raw IPMI, etc. UNSIGNED!!!
	int subtype;		// optional, depends on type
	uint32_t cache_index;	// Direct reference and/or speedup hint
	uint32_t cache_RecID;	// Qualifies cache_index
	uint32_t len;		// how much of body is valid
	uint8_t body[IPMI_MAX_RESPONSE_SIZE];
} sysVmq_msg_t;

// These calls are exported mainly for use by the IPMI caching daemon.
// If you try to use them in normal clients you'll regret it.

int _sysVmq_open(BMC_t *bmc);			// NULL == daemon, else client

void _sysVmq_close(BMC_t *bmc);			// NULL == daemon, else client

int _sysVmq_send(sysVmq_msg_t *msg_out,		// for the daemon
		 char *caller);

int _sysVmq_recv(sysVmq_msg_t *msg_in,		// for the daemon
		 unsigned int *timeout,
		 char *caller);

int _sysVmq_flush(long mtype, int all);		// for daemon and client

int _sysVmq_pending(void);			// for the daemon

int _sysVmq_remove(void);			// for the daemon

void _volatile_refresh(BMC_t *bmc);		// for the daemon

#endif
