/*
 ***************************************************************************
 *  Copyright (c) 1996-2007 Hewlett-Packard Development Company, L.P.
 *  HP Confidential
 ***************************************************************************
 *
 *  Title:    System Event Log Support - OS Independdant Data Structures
 *
 *  Module:   EVENTLOG.H
 *
 *  Version:  1.0
 *
 *  Date:     8/23/1996
 *
 *  Author:   Alan K. Minchew
 *
 *  Maintenance Contact: Bradley Reed
 *
 *  Ported for use in libIMLtext by John Marvin (November 2007)
 *	renamed to imltext_eventlog.h. Note, it is probably best to
 *	keep the formatting the same in this file so as to make it easier
 *	to merge additions from the "official" source.
 *
 ***************************************************************************
 *
 *  The "official" copy of this file is kept in the Automated Build System
 *  CVS repository, along with the IML specification.  The same process used
 *  to review and approve specification changes should also be used when
 *  updating this file.  See Appendix C in the spec for more information.
 *  Download the spec from http://abs.cca.cpqcorp.net/docs/ISS/IML.doc.
 *
 ***************************************************************************
 */

#ifndef imltext_eventlog_h
#define imltext_eventlog_h

#ifdef __cplusplus
extern "C" {
#endif

#pragma pack(1)


/****************************************************************************/
/* Common Readability Defines */
/****************************************************************************/

#ifndef TRUE
#define TRUE   1
#endif

#ifndef FALSE
#define FALSE  0
#endif

#ifndef VOID
#define VOID   void
#endif

#ifndef PVOID
#define PVOID  void*
#endif

#ifndef WINNT

#ifndef BOOL
#define BOOL   int
#endif

#ifndef BYTE
#define BYTE   unsigned char
#endif

#ifndef PBYTE
#define PBYTE  unsigned char*
#endif

#ifndef CHAR
#define CHAR   char
#endif

#ifndef SCHAR
#define SCHAR  signed char
#endif

#ifndef UCHAR
#define UCHAR  unsigned char
#endif

#ifndef PCHAR
#define PCHAR  char*
#endif

#ifndef PSCHAR
#define PSCHAR signed char*
#endif

#ifndef PUCHAR
#define PUCHAR unsigned char*
#endif

#ifndef SHORT
#define SHORT  short
#endif

#ifndef PSHORT
#define PSHORT short*
#endif

#ifndef USHORT
#define USHORT unsigned short
#endif

#ifndef PUSHORT
#define PUSHORT unsigned short*
#endif

#ifndef WORD
#define WORD   unsigned short
#endif

#ifndef PWORD
#define PWORD  unsigned short*
#endif

#ifndef DWORD
#define DWORD  unsigned long
#endif

#ifndef PDWORD
#define PDWORD unsigned long*
#endif

#ifndef LONG
#define LONG   long
#endif

#ifndef PLONG
#define PLONG  long*
#endif

#ifndef ULONG
#define ULONG  unsigned long
#endif

#ifndef PULONG
#define PULONG unsigned long*
#endif

#else

#undef near
#undef far
#define near
#define far

#ifndef ULONG
typedef unsigned long ULONG;
#endif

#ifndef PULONG
typedef ULONG *PULONG;
#endif

#ifndef USHORT
typedef unsigned short USHORT;
#endif

#ifndef PUSHORT
typedef USHORT *PUSHORT;
#endif

#ifndef UCHAR
typedef unsigned char UCHAR;
#endif

#ifndef PUCHAR
typedef UCHAR *PUCHAR;
#endif

#ifndef SCHAR
typedef signed char SCHAR;
#endif

#ifndef PSCHAR
typedef SCHAR *PSCHAR;
#endif

#ifndef PSZ
typedef char *PSZ;
#endif

#ifndef DWORD
typedef unsigned long       DWORD;
#endif

#ifndef BOOL
typedef int                 BOOL;
#endif

#ifndef BYTE
typedef unsigned char       BYTE;
#endif

#ifndef WORD
typedef unsigned short      WORD;
#endif

#ifndef FLOAT
typedef float               FLOAT;
#endif

#ifndef PFLOAT
typedef FLOAT               *PFLOAT;
#endif

#ifndef PBOOL
typedef BOOL near           *PBOOL;
#endif

#ifndef LPBOOL
typedef BOOL far            *LPBOOL;
#endif

#ifndef PBYTE
typedef BYTE near           *PBYTE;
#endif

#ifndef LPBYTE
typedef BYTE far            *LPBYTE;
#endif

#ifndef PINT
typedef int near            *PINT;
#endif

#ifndef LPINT
typedef int far             *LPINT;
#endif

#ifndef PWORD
typedef WORD near           *PWORD;
#endif

#ifndef LPWORD
typedef WORD far            *LPWORD;
#endif

#ifndef LPLONG
typedef long far            *LPLONG;
#endif

#ifndef PDWORD
typedef DWORD near          *PDWORD;
#endif

#ifndef LPDWORD
typedef DWORD far           *LPDWORD;
#endif

#ifndef LPVOID
typedef void far            *LPVOID;
#endif

#ifndef INT
typedef int                 INT;
#endif

#ifndef UINT
typedef unsigned int        UINT;
#endif

#ifndef PUINT
typedef unsigned int        *PUINT;
#endif

#endif


/****************************************************************************/
/* Defines */
/****************************************************************************/

/* Eventlog revision supported by this file (bHdrRev in the header structure) */

#define EVT_LOG_REVISION         0x01


/* Return codes for eventlog functions (interpreted) */

#define EVT_IOCTL_SUCCESS        0x00
#define EVT_IOCTL_END_OF_LOG     0x01
#define EVT_IOCTL_TOO_BIG        0x02
#define EVT_IOCTL_TOO_SMALL      0x03
#define EVT_IOCTL_NOT_FOUND      0x04
#define EVT_IOCTL_BAD_DRIVER     0x05
#define EVT_IOCTL_MEMORY         0x06
#define EVT_IOCTL_INVALID_DATA   0x07
#define EVT_IOCTL_UNKNOWN_ERROR  0x7F


/* Raw return codes (returned in register AH) */

#define EVT_ROM_SUCCESS          0x00        /* All */
#define EVT_ROM_TOO_BIG          0x87        /* Log Event only */
#define EVT_ROM_END_OF_LOG       0x87        /* Read Event only */
#define EVT_ROM_TOO_SMALL        0x88        /* Read Event only */
#define EVT_ROM_ENTRY_NOT_FOUND  0x87        /* Update Event only */
#define EVT_ROM_INVALID_DATA     0x88        /* Log Event, Update Event */

/* Eventlog functions */

#define EVT_LOG_EVENT            0x0E800
#define EVT_READ_EVENT           0x0E801
#define EVT_UPDATE_EVENT         0x0E802
#define EVT_CLEAR_ALL_EVENTS     0x0E803
#define EVT_READ_ALL_EVENTS      0x0E804
#define EVT_LCD_FUNCTION         0x0E810

/* LCD Sub-functions */

#define EVT_LCD_CLEAR_POPUP      0x00603


/* Eventlog clear all events type definitions */

#define EVT_RESET_EVENT_NUMBER   0           /* Reset event number index to 0 */
#define EVT_KEEP_EVENT_NUMBER    1           /* Don't reset the event number */

/* Max Eventlog entry size (inclusing header) */

#define EVT_MAX_SIZE             256

/* Eventlog severity codes */

#define EVT_STAT_INFO            0x02     /* Status or informational message */
#define EVT_STAT_POPUP           0x03     /* Status with popup on LCD */
#define EVT_STAT_REPAIRED        0x06     /* Degraded or worse cond repaired */
#define EVT_STAT_CAUTION         0x09     /* Component in degraded condition */
#define EVT_STAT_FAILED          0x0F     /* Failed with loss of functionality */
#define EVT_STAT_CRITICAL        EVT_STAT_FAILED /* Same as Failed */


/* Match code bits (unused bits are 0) */

#define EVT_BIT(n)               (1U << (n))
#define EVT_MATCH_CLASS          EVT_BIT(0)
#define EVT_MATCH_CODE           EVT_BIT(1)
#define EVT_MATCH_YEAR           EVT_BIT(2)
#define EVT_MATCH_MONTH          EVT_BIT(3)
#define EVT_MATCH_DAY            EVT_BIT(4)
#define EVT_MATCH_HOUR           EVT_BIT(5)
#define EVT_MATCH_MINUTE         EVT_BIT(6)
#define EVT_MATCH_SEVERITY       EVT_BIT(7)
#define EVT_MATCH_ALL_DATA       EVT_BIT(8)  /* All free form data */


/* Eventlog Standard match codes */

#define EVT_MATCH_NONE           0
#define EVT_MATCH_CLASS_CODE     (EVT_MATCH_CLASS      | \
                                  EVT_MATCH_CODE)
#define EVT_MATCH_SAME_DAY       (EVT_MATCH_CLASS_CODE | \
                                  EVT_MATCH_SEVERITY   | \
                                  EVT_MATCH_YEAR       | \
                                  EVT_MATCH_MONTH      | \
                                  EVT_MATCH_DAY        | \
                                  EVT_MATCH_ALL_DATA)
#define EVT_MATCH_SAME_HOUR      (EVT_MATCH_SAME_DAY   | \
                                  EVT_MATCH_HOUR)
#define EVT_MATCH_SAME_MIN       (EVT_MATCH_SAME_HOUR  | \
                                  EVT_MATCH_MINUTE)
#define EVT_MATCH_STANDARD       EVT_MATCH_SAME_HOUR


/* Standard Unknown value */

#define EVT_GENERAL_UNKNOWN      0xFF


/* Standard occurrance count */

#define EVT_OCCUR_STANDARD       1


/****************************************************************************/
/* Event Classes and Codes (codes for each class are indented)              */
/****************************************************************************/

#define EVT_CLASS_EMPTY             0x00

#define EVT_CLASS_TEST              0x01

#define EVT_CLASS_MACHINE_ENV       0x02
   #define EVT_MACHINE_OVERHEAT                 0x01
   #define EVT_MACHINE_FAN_FAIL                 0x02
   #define EVT_MACHINE_DOOR_OPEN                0x03
   #define EVT_MACHINE_FAN_REMOVED              0x04
   #define EVT_MACHINE_FAN_INSERTED             0x05
   #define EVT_MACHINE_FAN_NOT_REDUNDANT        0x06
   #define EVT_MACHINE_FAN_NOT_REDUNDANT_SHARED 0x07  
   #define EVT_MACHINE_FAN_FAIL_PARTITIONED     0x08
   #define EVT_MACHINE_DOOR_OPEN_PARTITIONED    0x09
   #define EVT_MACHINE_OVERHEAT_PARTITIONED     0x0A
   #define EVT_MACHINE_FAN_FAIL_SAS             0x0B
   #define EVT_MACHINE_OVERHEAT_SAS             0x0C

#define EVT_CLASS_MAIN_MEMORY       0x03
   #define EVT_MAIN_MEM_CORRECTED             0x01
   #define EVT_MAIN_MEM_NON_CORR              0x02
   #define EVT_MAIN_MEM_NON_CORR_MULTI        0x03
   #define EVT_MAIN_MEM_USER_ACTION           0x04
   #define EVT_MAIN_MEM_HARDWARE_STAT         0x05
   #define EVT_MAIN_MEM_CONFIG_ERROR          0x06
   #define EVT_MAIN_MEM_CONFIG_CHANGE         0x07
   #define EVT_MAIN_MEM_SPARE_ENGAGED         0x08
   #define EVT_MAIN_MEM_MIRROR_ENGAGED        0x09
   #define EVT_MAIN_MEM_CORRECTED_2           0x0A
   #define EVT_MAIN_MEM_SPARE_ENGAGED_2       0x0B
   #define EVT_MAIN_MEM_MIRROR_ENGAGED_2      0x0C
   #define EVT_MAIN_MEM_NOT_MIRRORED          0x0D
   #define EVT_MAIN_MEM_ONLINE_SPARE_DISABLED 0x0E
   #define EVT_MAIN_MEM_NOT_IN_RAID_MODE      0x0F
   #define EVT_MAIN_MEM_SWICHOVER_COMPLETE    0x10
   #define EVT_MAIN_MEM_BOARD_FAILURE         0x11
   #define EVT_MAIN_MEM_ROM_DIAG_DETECT_FAIL  0x12
   #define EVT_MAIN_MEM_CORRECTED_3           0x13
   #define EVT_MAIN_MEM_UNCORRECTABLE_BY_CPU  0x17
   #define EVT_MAIN_MEM_DIMM_RANK_DISABLED    0x23

#define EVT_CLASS_CACHE_MEMORY      0x04
   #define EVT_CACHE_MEM_ACCEL_ERROR   0x01

#define EVT_CLASS_CPU               0x05
   #define EVT_CPU_CORRECTED           0x01
   #define EVT_CPU_NON_CORR            0x02

#define EVT_CLASS_HOST_BUS          0x06
   #define EVT_HOST_BUS_NON_CORR       0x01
   #define EVT_INTERMODULE_BUS_ERROR   0x02

#define EVT_CLASS_EISA_BUS          0x07
   #define EVT_EISA_BUS_MASTER_TIMEOUT 0x01
   #define EVT_EISA_BUS_SLAVE_TIMEOUT  0x02     /* No free form data */
   #define EVT_EISA_BUS_BOARD_TIMEOUT  0x03
   #define EVT_EISA_BUS_REFRESH_NMI    0x04     /* No free form data */

#define EVT_CLASS_PCI_BUS           0x08
   #define EVT_PCI_BUS_ERROR           0x01
   #define EVT_PCIE_CRU_NMI_SOURCE     0x02

#define EVT_CLASS_EXPANSION_SLOT    0x09
   #define EVT_SLOT_SWITCH_OPEN        0x01
   #define EVT_SLOT_SWITCH_CLOSED      0x02
   #define EVT_SLOT_POWER_ON           0x03
   #define EVT_SLOT_POWER_OFF          0x04
   #define EVT_SLOT_FATAL_POWER_FAULT  0x05
   #define EVT_SLOT_POWER_UP_FAULT     0x06
   #define EVT_SLOT_POWER_LOSS         0x07
   #define EVT_SLOT_CANNOT_CONFIG      0x08
   #define EVT_SLOT_BOARD_FAILURE      0x09

#define EVT_CLASS_POST              0x0A
   #define EVT_POST_ERROR                          0x01
//added 20111207 for IML_Spec V1_50 begin
   #define EVT_POST_INFORMATION                    0x02
   #define EVT_OPTION_CARD_POST_ERROR              0x03
   #define EVT_OPTION_CARD_POST_INFORMATION        0x04 
//added 20111207 for IML_Spec V1_50 end

#define EVT_CLASS_POWER_SUPPLY      0x0B
   #define EVT_PS_FAILURE                          0x01
   #define EVT_PS_BATTERY_LOW                      0x02
   #define EVT_PS_MODULE_FAILED                    0x03
   #define EVT_PS_REMOVED                          0x04
   #define EVT_PS_INSERTED                         0x05
   #define EVT_PS_NOT_REDUNDANT                    0x06
   #define EVT_PS_MODULES_NOT_REDUNDANT            0x07
   #define EVT_PS_AC_VOLTAGE_PROBLEM               0x08
   #define EVT_PS_AC_VOLTAGE_OVERLOAD              0x09
   #define EVT_PS_POWERED                          0x0A
   #define EVT_PS_UNPOWERED                        0x0B
   #define EVT_PS_POWER_MODULE_FAILURE             0x0C
   #define EVT_PS_POWER_MODULE_REMOVED             0x0D
   #define EVT_PS_POWER_MODULE_INSERTED            0x0E
   #define EVT_PS_POWER_MODULE_NOT_REDUNDANT       0x0F
   #define EVT_PS_POWER_MODULE_OVERLOAD            0x10
   #define EVT_PS_AC_VOLTAGE_PROBLEM_PARTITIONED   0x11
   #define EVT_PS_BATTERY_LOW_PARTITIONED          0x12
   #define EVT_PS_FAILURE_PARTITIONED              0x13
   #define EVT_PS_FAILURE_SAS                      0x14

#define EVT_CLASS_UPS               0x0C
   /* future */

#define EVT_CLASS_ASR               0x0D
   #define EVT_ASR_RESET               0x01     /* No free form data */
   #define EVT_ASR_LOCKUP_DETECTED     0x02
   #define EVT_ASR_RESET_LIMIT         0x03     /* No free form data */

#define EVT_CLASS_OS                0x0E
   #define EVT_OS_SYSTEM_CRASH         0x01
   #define EVT_OS_AUTO_SHUTDOWN        0x02
   #define EVT_OS_EXCEPTION            0x03
   #define EVT_OS_NMI_DUMP_SWITCH      0x04     /* No free form data */
   #define EVT_OS_POWER_SHED           0x05
   #define EVT_OS_VIRTUAL_NMI_DUMP_SWITCH 0x06     /* No free form data */

#define EVT_CLASS_DIAGS             0x0F
   /* future */

#define EVT_NETWORK_ADAPTER         0x11
   #define EVT_NIC_ADAPTER_CHECK                   0x01
   #define EVT_NIC_LINK_DOWN                       0x02
   #define EVT_NIC_XMIT_TIMEOUT                    0x03
   #define EVT_NIC_NOT_REDUNDANT                   0x04
   #define EVT_NIC_REDUNDANCY_REDUCED              0x05
   #define EVT_NIC_LINK_DOWN_PARTITIONED           0x06
   #define EVT_NIC_REDUNDANCY_REDUCED_PARTITIONED  0x07

#define EVT_SCSI_SUBSYSTEM          0x12
   #define EVT_SCSI_CTRL_FAILED        0x01
   #define EVT_SCSI_DEVICE_FAILED      0x02
   #define EVT_SCSI_CTRL_NOT_REDUNDANT 0x03

#define EVT_DRIVEARRAY_SUBSYSTEM    0x13
   #define EVT_ARRAY_CTRL_FAILED               0x01
   #define EVT_ARRAY_DEVICE_FAILED             0x02
   #define EVT_ARRAY_ACCEL_FAILED              0x03
   #define EVT_ARRAY_CTRL_NOT_REDUNDANT        0x04
   #define EVT_ARRAY_CTRL_FAILED_PARTITIONED   0x05
   #define EVT_ARRAY_DEVICE_FAILED_PARTITIONED 0x06
   #define EVT_ARRAY_DEVICE_FAILED_SAS         0x07
   #define EVT_ARRAY_SAS_PHY_ERROR             0x08
   #define EVT_ARRAY_CTRL_NOT_REDUNDANT_SUN    0x09
   #define EVT_ARRAY_SAS_PHY_ERROR_EXTENDED    0x0A

#define EVT_UNRECOV_SYSTEM_ERR      0x14
   #define EVT_UNRECOV_NMI             0x01
   #define EVT_UNRECOV_BINIT           0x02
   #define EVT_UNRECOV_NMI_PLUS_DATA   0x03
   #define EVT_UNRECOV_ROCKY_CHIPSET   0x04	// from iLO on Hydra

#define EVT_SYSTEM_REV              0x20
   #define EVT_ROM_FLASHED             0x01

#define EVT_MAINTENANCE             0x21
   #define EVT_MAINT_IML_CLEARED       0x01
   #define EVT_MAINT_NOTE              0x02

#define EVT_CLASS_INFRASTRUCTURE_ENVIRONMENT   0x22
   #define EVT_ENCL_INADEQUATE_POWER                   0x01
   #define EVT_ENCL_MANUAL_OVERRIDE                    0x02
   #define EVT_ENCL_FUSE_OPEN                          0x03
   #define EVT_ENCL_I2C_FAULT                          0x04
   #define EVT_ENCL_BLADE_INS_OR_REM                   0x05  // Deprecated
   #define EVT_ENCL_PWR_LOAD_BALANCING                 0x06
   #define EVT_ENCL_DC_PWR_PROBLEM                     0x07
   #define EVT_ENCL_AC_FACILITY_PWR_INP_EXCEEDED       0x08
   #define EVT_ENCL_LOST_CHASSIS_CONNECTION            0x09
   #define EVT_ENCL_NEW_CHASSIS_CONNECTION             0x0A
   #define EVT_ENCL_RACK_INFRASTRUCTURE_CHANGE         0x0B
   #define EVT_ENCL_UNKNOWN_PWR_CONSUMPTION            0x0C
   #define EVT_ENCL_IMPROPERLY_CONF_PWR_SYS            0x0D
   #define EVT_ENCL_MANAGER_STATUS                     0x0E
   #define EVT_ENCL_BLOWER_FAULT                       0x0F
   #define EVT_ENCL_BLOWER_REMOVED                     0x10
   #define EVT_ENCL_ETHERNET_SWITCH_FAULT              0x11
   #define EVT_ENCL_INPUT_PWR_SENSE_ERROR              0x12
   #define EVT_ENCL_BLADE_INSERTED                     0x13
   #define EVT_ENCL_BLADE_REMOVED                      0x14
   #define EVT_ENCL_RACK_TOPOLOGY_ERROR                0x15
   #define EVT_ENCL_CHASSIS_ERROR                      0x18  //0x16 and 0x17 are being used by Gromit for Debug purposes
   #define EVT_ENCL_INFRASTRUCTURE_FIRMWARE_MISMATCH   0x19

   /* Continue support for duplicate names */
   #define EVT_ENCLOSURE_MANAGER_STATUS            EVT_ENCL_MANAGER_STATUS
   #define EVT_ENCL_SWITCH_FAULT                   EVT_ENCL_ETHERNET_SWITCH_FAULT
   #define EVT_ENCL_VOLTAGE_SENSE_ERROR            EVT_ENCL_INPUT_PWR_SENSE_ERROR
   
#ifdef ILO_V850
/* Events internal to the iLO controller...nobody else should use them, or see them. */
#define EVT_IOP_SYSTEM              0x23
#endif

// These events are not logged to the IML but they are used for communication between the iLO 2 firmware 
// and the Embedded Health driver.  The event code values are defined in the Health driver source - they
// won't be defined here in order to keep from having to update this shared header as new Embedded Health
// alerts are defined.
#define EVT_CLASS_EMBEDDED_HEALTH   0x24

#define EVT_CLASS_XNC_ORION				0x25
   #define EVT_XNC_ORION_PECI_ERROR			0x01
   #define EVT_XNC_ORION_DS2_ERROR			0x02
   #define EVT_XNC_ORION_CPU_SKU_ERROR			0x04
   #define EVT_XNC_ORION_BOOTROM_TIMEOUT		0x06
   #define EVT_XNC_ORION_QPI_LINK_TRAIN_ERROR		0x07
   #define EVT_XNC_ORION_WJF_LINK_TRAIN_ERROR		0x08
   #define EVT_XNC_ORION_CSL_HANDSHAKE_TIMEOUT		0x09
   #define EVT_XNC_ORION_CSL_PARTNER_MISSING		0x0A
   #define EVT_XNC_ORION_SYSTEM_INIT_FAILURE		0x34
   #define EVT_XNC_ORION_SYSTEM_INIT_SOCKET_FAILURE	0x35
   #define EVT_XNC_ORION_SYSTEM_CPU_SOCKET_DISABLED	0x39
   #define EVT_XNC_ORION_IO_DISABLED			0x40
   #define EVT_XNC_ORION_EVENTS_DROPPED			0x51
   #define EVT_XNC_ORION_FMP_POWER_FAULT		0x80
   #define EVT_XNC_ORION_FMP_RESET_ERROR		0x81
   #define EVT_XNC_ORION_FMP_POST_FAULT			0x82
   #define EVT_XNC_ORION_UNCORRECTABLE_XNC_ERROR	0xC0
   #define EVT_XNC_ORION_CORRECTABLE_XNC_ERROR		0xC1
   #define EVT_XNC_ORION_UNCORRECTABLE_XNC_FABRIC_ERROR	0xC4
   #define EVT_XNC_ORION_CORRECTABLE_XNC_FABRIC_ERROR	0xC5

/****************************************************************************/
/* Data structures */
/****************************************************************************/

/* Time stamp of event (creation or last update) */

typedef struct _evtTimeStamp
{
   BYTE     bCentury;            /* hi-order two digits of year (19 of 1996) */
   BYTE     bYear;               /* lo-order two digits of year (96 of 1996) */
   BYTE     bMonth;              /* one-based month number (1-12) */
   BYTE     bDay;                /* one-based day number (1-31) */
   BYTE     bHour;               /* zero-based hour (0-23) */
   BYTE     bMinute;             /* zero-based minute (0-59) */
} EVT_TIME_STAMP, *PEVT_TIME_STAMP;


/* Chassis (common to many events) */

/* Chassis type defines */
#define EVT_CHASSIS_SYSTEM          0x01
#define EVT_CHASSIS_EXTERN_STORAGE  0x02
#define EVT_CHASSIS_INTERN_STORAGE  0x03
#define EVT_CHASSIS_BLADE           0x04     // New for GARdian/Ice
#define EVT_CHASSIS_POWER           0x05     // New for GARdian/Ice
#define EVT_CHASSIS_BLADE_SYSTEM    0x04     // redefined for existing agents
#define EVT_CHASSIS_DIST_POWER_SYSTEM 0x05   // ''
#define EVT_CHASSIS_ICE_STORAGE     0x04
#define EVT_CHASSIS_DISTRIB_POWER   0x05

typedef struct _evtChassis
{
   BYTE     bType;               /* Chassis Type (System==1; Extern==2) */
   BYTE     bId;                 /* Chassis id */
                                 /*   for type 1 - chassis id (0 is system) */
                                 /*   for type 2 or 3 - adapter slot */
                                 /*   for type 4 or 5 - high byte of ICMB address */
   BYTE     bPort;               /* Chassis port or bus number */
                                 /*   for type 4 or 5 - low byte of ICMB address */
} EVT_CHASSIS, *PEVT_CHASSIS;



/* Defines used in multiple data structures */

/* Fan/Temp Zone locator defines */
#define EVT_LOCALE_SYSTEM           0x00  /* System board (compatibility value) */
#define EVT_LOCALE_SYSTEM_BOARD     0x01  /* Host System board */
#define EVT_LOCALE_IO_BOARD         0x02  /* I/O board */
#define EVT_LOCALE_CPU              0x03  /* CPU board */
#define EVT_LOCALE_MEMORY           0x04  /* Memory board */
#define EVT_LOCALE_STORAGE          0x05  /* Storage bays */
#define EVT_LOCALE_REM_MEDIA        0x06  /* Removable Media Bays */
#define EVT_LOCALE_POWER_SUPPLY     0x07  /* Power Supply Bays */
#define EVT_LOCALE_AMBIENT          0x08  /* Ambient / External / Room */
#define EVT_LOCALE_CHASSIS          0x09  /* Chassis */
#define EVT_LOCALE_BRIDGE_BOARD     0x0A  /* Bridge Card */
#define EVT_LOCALE_MGMT_BOARD       0x0B  /* Management board (driver define) */
#define EVT_LOCALE_MANAGEMENT_BOARD 0x0B  /* Remote Management Card */
#define EVT_LOCALE_BACKPLANE        0x0C  /* Generic Backplane */
#define EVT_LOCALE_NETWORK_SLOT     0x0D  /* Infrastructure Network */
#define EVT_LOCALE_BLADE_SLOT       0x0E  /* Blade Slot in Chassis / Infrastructure */
#define EVT_LOCALE_VIRTUAL          0x0F  /* Software-defined sensor */
#define EVT_LOCALE_UNKNOWN          EVT_GENERAL_UNKNOWN  /* Unknown */

/* Eventlog Machine Environment structs */

typedef struct _evtMachOverheat
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bZoneId;             /* Temperature zone # */
   BYTE     bZoneType;           /* Temperature zone type (see above) */
   BYTE     bTemp;               /* Recorded temperature (in degrees celsius) */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_OVERHEAT, *PEVT_MACH_OVERHEAT;

typedef struct _evtMachFanFail
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bFanId;              /* Fan ID number */
   BYTE     bFanZoneType;        /* Fan Zone Locator type */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_FAN_FAIL, *PEVT_MACH_FAN_FAIL;

typedef struct _evtMachDoorOpen
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bDoorId;             /* Door ID number */
   BYTE     bDoorZoneType;       /* Door Zone Locator type */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_DOOR_OPEN, *PEVT_MACH_DOOR_OPEN;

typedef struct _evtMachFanRemoved
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bFanId;              /* Fan ID number */
   BYTE     bFanZoneType;        /* Fan Zone Locator type */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_FAN_REMOVED, *PEVT_MACH_FAN_REMOVED;

typedef struct _evtMachFanInserted
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bFanId;              /* Fan ID number */
   BYTE     bFanZoneType;        /* Fan Zone Locator type */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_FAN_INSERTED, *PEVT_MACH_FAN_INSERTED;

typedef struct _evtMachFanNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bFanZoneType;        /* Fan Zone Locator type */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_FAN_NOT_REDUNDANT, *PEVT_MACH_FAN_NOT_REDUNDANT;

typedef struct _evtMachFanNotRedundantShared    
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bFanZoneType;        /* Fan Zone Locator type */
   BYTE     bSharedFanZoneType;  /* Shared Fan Zone Locator type */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_MACH_FAN_NOT_REDUNDANT_SHARED, *PEVT_MACH_FAN_NOT_REDUNDANT_SHARED;

typedef struct _evtMachSASFanFail
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bFanId;              /* Fan ID number */
   BYTE     bFanZoneType;        /* Fan zone locator type */
   UCHAR    szPortID [2];        /* 2 ASCII chars received from SA firmware.*/
   BYTE     bBox;                /* BoxOnPort value returned from SA firmware. Sequential number provided on a
                                    per port basis. Used with PortID to find SAS box location.*/
   CHAR     szChassis_Sun[1];    /* Chassis name - for storage boxes which contain their own (external) array 
                                    controllers; followed by IPF slot unique number string. '\0' for either
                                    if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                    would be \0) */
} EVT_MACH_SAS_FAN_FAIL, *PEVT_MACH_SAS_FAN_FAIL;

typedef struct _evtMachSASOverheat
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSensorId;           /* Temperature sensor ID # returned from SA firmware */
   BYTE     bZoneType;           /* Temperature zone type */
   UCHAR    szPortID [2];        /* 2 ASCII chars received from SA firmware.*/
   BYTE     bBox;                /* BoxOnPort value returned from SA firmware. Sequential number provided on a
                                    per port basis. Used with PortID to find SAS box location.*/
   CHAR     szChassis_Sun[1];    /* Chassis name - for storage boxes which contain their own (external) array
                                    controllers; followed by IPF slot unique number string. '\0' for either
                                    if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                    would be \0) */
} EVT_MACH_SAS_OVERHEAT, *PEVT_MACH_SAS_OVERHEAT;

/* Eventlog Main Memory structs */

#define EVT_MEMORY_SYS_BOARD                    0
#define EVT_MEMORY_UNKNOWN                      EVT_GENERAL_UNKNOWN
#define EVT_KNOWN_AS_BOARD                      (0x00)
#define EVT_KNOWN_AS_CARTRIDGE                  (0x01)
#define EVT_MAX_MEMORY_MODE                     (0x01)
#define EVT_ONLINE_SPARE_MODE                   (0x02)
#define EVT_DUAL_BOARD_MIRRORED_MEMORY_MODE     (0x03)
#define EVT_SINGLE_BOARD_MIRRORED_MEMORY_MODE   (0x04)

typedef struct _evtMainMemory
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bModule;             /* Module number, 0xFF if unknown */
   CHAR     cSerialNumber[1];    /* Module serial number; '\0' if undefined */
} EVT_MAIN_MEMORY, *PEVT_MAIN_MEMORY;

typedef struct _evtSingleEntry
{
   BYTE     bModule;             /* Module number, 0xFF if unknown */
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
} EVT_MEM_SINGLE, *PEVT_MEM_SINGLE;

typedef struct _evtMainMemoryMulti
{
   BYTE     bResolution;         /* 1, 2 or 4 - num of possible locations */
   EVT_MEM_SINGLE mm[4];         /* 4 module/slot pairs (some may be unused) */
   CHAR     cSerialNumber[1];    /* Module serial number(s); '\0' if undefined */
                                 /*  seperated by a comma "," */
} EVT_MAIN_MEMORY_MULTI, *PEVT_MAIN_MEMORY_MULTI;

#define EVT_MAIN_MEM_ACTION_REMOVE        0x00
#define EVT_MAIN_MEM_ACTION_INSERT        0x01
#define EVT_MAIN_MEM_ACTION_UNLOCK        0x02
#define EVT_MAIN_MEM_ACTION_LOCK          0x03
typedef struct _evtMainMemoryUserAction
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bAction;             /* The action type */
   BYTE     bCartridgeOrBoard;   /* 0x00 is Board; 0x01 is Cartridge */
} EVT_MAIN_MEMORY_USER_ACTION, *PEVT_MAIN_MEMORY_USER_ACTION;

#define EVT_MAIN_MEM_HARDWARE_BUS_FAULT   0x00
#define EVT_MAIN_MEM_HARDWARE_POWER_FAULT 0x01
#define EVT_MAIN_MEM_HARDWARE_NON_REDUNDANT  0x02
#define EVT_MAIN_MEM_HARDWARE_ONLINE      0x03
typedef struct _evtMainMemoryHwStat
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bStatus;             /* The status type */
} EVT_MAIN_MEMORY_HW_STATUS, *PEVT_MAIN_MEMORY_HW_STATUS;

typedef struct _evtMainMemoryConfigErr
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bModule;             /* 0 is embedded; 0xFF if unknown */
   BYTE     bCartridgeOrBoard;   /* 0x00 is Board; 0x01 is Cartridge */
} EVT_MAIN_MEMORY_CONFIG_ERR, *PEVT_MAIN_MEMORY_CONFIG_ERR;

#define EVT_MAIN_MEM_CONFIG_ADD     0x00
#define EVT_MAIN_MEM_CONFIG_REMOVE  0x01
typedef struct _evtMainMemoryConfigChg
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bAction;             /* The config change type */
   ULONG    ulSize;              /* Size of changed module 0xFFFFFFFF if unknown*/
} EVT_MAIN_MEMORY_CONFIG_CHG, *PEVT_MAIN_MEMORY_CONFIG_CHG;

typedef struct _evtMainMemorySpareEngaged
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bModule;             /* 0 is embedded; 0xFF if unknown */
} EVT_MAIN_MEMORY_SPARE_ENGAGED, *PEVT_MAIN_MEMORY_SPARE_ENGAGED;

typedef struct _evtMainMemoryMirrorEngaged
{
   BYTE     bSlot;               /* 0 is embedded; 0xFF if unknown */
   BYTE     bModule;             /* 0 is embedded; 0xFF if unknown */
} EVT_MAIN_MEMORY_MIRROR_ENGAGED, *PEVT_MAIN_MEMORY_MIRROR_ENGAGED;

typedef struct _evtMainMemoryConfiguration
{
   BYTE     bConfig;
} EVT_MAIN_MEMORY_CONFIGURATION, *PEVT_MAIN_MEMORY_CONFIGURATION;

typedef struct _evtMainMemoryBoardFailure
{
   BYTE     bSlot;               /* Board number (non-zero) */
} EVT_MAIN_MEMORY_BOARD_FAILURE, *PEVT_MAIN_MEMORY_BOARD_FAILURE;

typedef struct _evtMainMemoryFailureInRomDiags
{
   BYTE     bBoard;              /* 0 is system board */
   BYTE     bModule;
   BYTE     bBank;
   struct
   {
      BYTE  bNotIsolated:1;
      BYTE  bReserved   :7;
   } flags;
   CHAR     szSerialNumber[1];   /* Module serial number - followed by spare number */
} EVT_MAIN_MEMORY_FAIL_IN_ROM_DIAG, *PEVT_MAIN_MEMORY_FAIL_IN_ROM_DIAG;


/* Eventlog Cache Memory structs */

typedef struct _evtCacheAccelParityError
{
   BYTE     bSocket;             /* Socket number, 0xFF if unknown */
} EVT_CACHE_ACCEL_PARITY_ERROR, *PEVT_CACHE_ACCEL_PARITY_ERROR;


/* Eventlog CPU structs */

#define EVT_CPU_CORR_ECC_CACHE   1
typedef struct _evtCpuCorrectable
{
   BYTE     bSocket;             /* Socket number in slot */
   BYTE     bSlot;               /* CPU Slot */
   BYTE     bType;               /* Error type */
} EVT_CPU_CORRECTABLE, *PEVT_CPU_CORRECTABLE;

#define EVT_CPU_UNCORR_PROC_PARITY  0x07
#define EVT_CPU_UNCORR_P5_IPERR     0x0E
#define EVT_CPU_UNCORR_P5_APERR     0x0F
#define EVT_CPU_UNCORR_P5_IEERR     0x10
#define EVT_CPU_UNCORR_P5_APCHECK   0x11
#define EVT_CPU_UNCORR_CPU_LOCAL    0x12
typedef struct _evtCpuUncorrectable
{
   BYTE     bSocket;             /* Socket number in slot */
   BYTE     bSlot;               /* CPU Slot */
   BYTE     bType;               /* Error type */
} EVT_CPU_UNCORRECTABLE, *PEVT_CPU_UNCORRECTABLE;


/* Eventlog Host Bus structs */

#define EVT_HOST_BUS_ADDR_ERR    0x00
#define EVT_HOST_BUS_DATA_ERR    0x01
typedef struct _evtHostBusUncorrectable
{
   BYTE     bError;              /* 0==Address parity; 1==Data parity */
} EVT_HOST_BUS_UNCORRECTABLE, *PEVT_HOST_BUS_UNCORRECTABLE;

typedef struct _evtIntermoduleBusUncorrectable
{
   ULONG     ulError;              /* ulErrorInfo returned from Int15 */
} EVT_INTERMODULE_BUS_UNCORRECTABLE, *PEVT_INTERMODULE_BUS_UNCORRECTABLE;


/* Eventlog EISA Bus structs */

typedef struct _evtEisaBus
{
   BYTE     bSlot;               /* Slot where error occurred */
} EVT_EISA_BUS, *PEVT_EISA_BUS;


/* Eventlog PCI Bus structs */

typedef struct _evtPciBus
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Physical slot number */
   BYTE     bBus;                /* PCI Bus Number */
   BYTE     bDevice;             /* PCI Device Number */
   BYTE     bFunction;           /* PCI Function Number */
} EVT_PCI_BUS, *PEVT_PCI_BUS;


/* Eventlog Expansion Slot structs */

typedef struct _evtExpansionSlot
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* 0 is embedded */
} EVT_EXPANSION_SLOT, *PEVT_EXPANSION_SLOT;

#define EVT_SLOT_WRONG_TYPE         0x01
#define EVT_SLOT_WRONG_REVISION     0x02
#define EVT_SLOT_GENERAL_FAULT      0x03
#define EVT_SLOT_OUT_OF_RESOURCES   0x04
#define EVT_SLOT_NO_ADAPTER         0x05
#define EVT_SLOT_UNSUPPORTED_DEVICE 0x06
#define EVT_SLOT_WRONG_BUS_FREQ     0x07
#define EVT_SLOT_PCIX_MODE_INCOMPATIBLE 0x08
#define EVT_SLOT_PCIX_FREQ_INCOMPATIBLE 0x09
typedef struct _evtExpansionSlotConfigErr
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* 0 is embedded */
   BYTE     bError;              /* Board configuration error */
} EVT_EXPANSION_SLOT_CONFIG_ERR, *PEVT_EXPANSION_SLOT_CONFIG_ERR;


/* Eventlog Post Message structs */

typedef struct _evtPostMessage
{
   BYTE     bError;              /* Post error code */
   CHAR     cMessage[231];       /* Post message */
} EVT_POST_MESSAGE, *PEVT_POST_MESSAGE;


/* Eventlog Power Supply structs */

#define PS_NO_ERROR                           0xFF
#define PS_ERR_GEN_FAILURE                    0x00
#define PS_ERR_BIST_FAILURE                   0x01
#define PS_ERR_FAN_FAILURE                    0x02
// reserved                                   0x03
// reserved                                   0x04
#define PS_ERR_EPROM_FAILED                   0x05
#define PS_ERR_VREF_FAILED                    0x06
#define PS_ERR_DAC_FAILED                     0x07
#define PS_ERR_RAMTEST_FAILED                 0x08
#define PS_ERR_VOLTAGE_CHNL_FAILED            0x09
// reserved                                   0x0A
// reserved                                   0x0B
#define PS_ERR_GIVEUP_ON_STARTUP              0x0C
#define PS_ERR_NVRAM_INVALID                  0x0D
#define PS_ERR_CALIBRATION_TABLE_INVALID      0x0E
typedef struct _evtPowerSupplyFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply ID */
   BYTE     bPsErrorId;          /* Power Supply Error ID */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_SUPPLY_FAILURE, *PEVT_POWER_SUPPLY_FAILURE;

typedef struct _evtBatteryLow
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
} EVT_BATTERY_LOW, *PEVT_BATTERY_LOW;

/* Macro below used to convert the SIT entry DC-DC converter type to the */
/* equivalent Eventlog converter type. */
#define SIT_2_EVT_DCDC_CONV_TYPE(sit)    ((BYTE) ((sit)+1))
#define EVT_DCDC_CONV_PROC       1
#define EVT_DCDC_CONV_PCI_BUS    2
#define EVT_DCDC_CONV_IO         3
typedef struct _evtPowerModuleFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number of converter */
   BYTE     bConverter;          /* Converter socket number */
   BYTE     bConverterType;      /* Converter type (from above) */
} EVT_POWER_MODULE_FAILURE, *PEVT_POWER_MODULE_FAILURE;

typedef struct _evtPowerSupplyRemoved
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply ID */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_SUPPLY_REMOVED, *PEVT_POWER_SUPPLY_REMOVED;

typedef struct _evtPowerSupplyInserted
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply ID */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_SUPPLY_INSERTED, *PEVT_POWER_SUPPLY_INSERTED;

typedef struct _evtPowerNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_NOT_REDUNDANT, *PEVT_POWER_NOT_REDUNDANT;

typedef struct _evtInfPowerNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE        bType;            /* Type of redundancy lost (breaker, busbar, etc.) */
   CHAR        cChassisName[1];  /* Storage chassis name; '\0' if undefined */
} EVT_INF_POWER_NOT_REDUNDANT, *PEVT_INF_POWER_NOT_REDUNDANT;

typedef struct _evtPowerModulesNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number of converter */
   BYTE     bConverter;          /* Converter socket number */
   BYTE     bConverterType;      /* Converter type (from above) */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_MODULES_NOT_REDUNDANT, *PEVT_POWER_MODULES_NOT_REDUNDANT;

#define PS_AC_OVER_VOLTAGE       0x01
#define PS_AC_UNDER_VOLTAGE      0x02
#define PS_AC_LINE_HIT           0x03
#define PS_AC_BROWN_OUT          0x04
#define PS_AC_POWER_LOSS         0x05
typedef struct _evtPowerAcVoltage
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply id */
   BYTE     bError;              /* Error number */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_AC_VOLTAGE, *PEVT_POWER_AC_VOLTAGE;

typedef struct _evtPowerOverload
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply id */
   BYTE     bVoltage;            /* Channel voltage (in volts) */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_AC_OVERLOAD, *PEVT_POWER_AC_OVERLOAD;

typedef struct _evtPowerSupplyPowered
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply id */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_SUPPLY_POWERED, *PEVT_POWER_SUPPLY_POWERED;

typedef struct _evtPowerSupplyUnpowered
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply id */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_POWER_SUPPLY_UNPOWERED, *PEVT_POWER_SUPPLY_UNPOWERED;

#define PS_SYS_PWR_MOD_GENERAL_FAILURE    0x00
typedef struct _evtSysPowerModuleFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bId;                 /* Power Module id */
   BYTE     bError;              /* Error number */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_SYS_POWER_MODULE_FAILURE, *PEVT_SYS_POWER_MODULE_FAILURE;

typedef struct _evtSysPowerModuleRemoved
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bId;                 /* Power Module id */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_SYS_POWER_MODULE_REMOVED, *PEVT_SYS_POWER_MODULE_REMOVED;

typedef struct _evtSysPowerModuleInserted
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bId;                 /* Power Module id */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_SYS_POWER_MODULE_INSERTED, *PEVT_SYS_POWER_MODULE_INSERTED;

typedef struct _evtSysPowerModuleNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_SYS_POWER_MODULE_NOT_REDUNDANT, *PEVT_SYS_POWER_MODULE_NOT_REDUNDANT;

typedef struct _evtSysPowerModuleOverload
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bId;                 /* Power Module id */
   BYTE     bVoltage;            /* Channel voltage (in volts) */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_SYS_POWER_MODULE_OVERLOAD, *PEVT_SYS_POWER_MODULE_OVERLOAD;

typedef struct _evtSASPowerSupplyFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bPsId;               /* Power Supply ID */
   UCHAR    szPortID [2];        /* 2 ASCII chars received from SA firmware.*/
   BYTE     bBox;                /* BoxOnPort value returned from SA firmware. Sequential number provided on a 
                                    per port basis. Used with PortID to find SAS box location.*/
   CHAR     szChassis_Sun[1];    /* Chassis name - for storage boxes which contain their own (external) array 
                                    controllers; followed by IPF slot unique number string. '\0' for either
                                    if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                    would be \0) */
} EVT_SAS_POWER_SUPPLY_FAILURE, *PEVT_SAS_POWER_SUPPLY_FAILURE;

/* Eventlog UPS structs */

/* future */


/* Eventlog ASR structs */

typedef struct _evtAsrLockup
{
   CHAR     cMessage[1];         /* Crash data information */
} EVT_ASR_LOCKUP, *PEVT_ASR_LOCKUP;


/* Eventlog Operating System structs */

typedef struct _evtOsCrash
{
   CHAR     cMessage[1];         /* Abend/crash information */
} EVT_OS_CRASH, *PEVT_OS_CRASH;

#define EVT_SHUTDOWN_FAN               0x01
#define EVT_SHUTDOWN_OVERHEAT          0x02
#define EVT_SHUTDOWN_VRM               0x03
#ifndef EVT_SHUTDOWN_ABORT
#define EVT_SHUTDOWN_ABORT             0x81
#endif
#ifndef EVT_SHUTDOWN_FAN_ABORT
#define EVT_SHUTDOWN_FAN_ABORT         0x82
#endif
#ifndef EVT_SHUTDOWN_TEMP_ABORT
#define EVT_SHUTDOWN_TEMP_ABORT        0x83
#endif
#ifndef EVT_SHUTDOWN_VRM_ABORT
#define EVT_SHUTDOWN_VRM_ABORT         0x84
#endif
#ifndef EVT_SHUTDOWN_SOFT_POWER_DOWN
#define EVT_SHUTDOWN_SOFT_POWER_DOWN   0x85
#endif
#ifndef EVT_SOFTWARE_ASR_SHUTDOWN
#define EVT_SOFTWARE_ASR_SHUTDOWN      0x86
#endif
#ifndef EVT_SHUTDOWN_HARD_POWER_DOWN
#define EVT_SHUTDOWN_HARD_POWER_DOWN   0x87
#endif

typedef struct _evtAutoShutdown
{
   BYTE     bCause;              /* One of the above defines */
} EVT_AUTO_SHUTDOWN, *PEVT_AUTO_SHUTDOWN;

typedef struct _evtOsFatalException
{
   BYTE     bException;          /* Intel exception number */
   CHAR     cCause[1];           /* Cause of exception */
} EVT_OS_FATAL_EXCEPTION, *PEVT_OS_FATAL_EXCEPTION;

/* NMI Dump Switch no data */

typedef struct _evtOsPowerShed
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bZoneId;             /* Zone ID (blade position or network slot) */
   BYTE     bZoneType;           /* Zone type (blade or network slot) */
   CHAR     cChassisName[1];     /* Storage chassis name; '\0' if undefined */
} EVT_OS_PWR_SHED, *PEVT_OS_PWR_SHED;

typedef EVT_OS_PWR_SHED EVT_POWER_SHED, *PEVT_POWER_SHED; /* Drvier defined */

/* Eventlog Diagnostics structs */

/* future */


/* Eventlog Network Adapter structs */

typedef struct _evtNicError
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_NIC_ERROR, *PEVT_NIC_ERROR;

/* The following is used for:     */
/*    EVT_NIC_NOT_REDUNDANT       */
/*    EVT_NIC_REDUNDANCY_REDUCED  */

typedef struct _evtNicsNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_NICS_NOT_REDUNDANT, *PEVT_NICS_NOT_REDUNDANT;


/* Eventlog SCSI Sub-system structs */

typedef struct _evtScsiCtrlFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number (0==system board) */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_SCSI_CTRL_FAILURE, *PEVT_SCSI_CTRL_FAILURE;

typedef struct _evtScsiDeviceFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bBay;                /* Device bay number */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_SCSI_DEVICE_FAILURE, *PEVT_SCSI_DEVICE_FAILURE;

typedef struct _evtScsiCtrlNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_SCSI_CTRLS_NOT_REDUNDANT, *PEVT_SCSIS_CTRL_NOT_REDUNDANT;


/* Eventlog Drive Array Sub-system structs */

typedef struct _evtArrayCtrlsFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number (0==system board) */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_ARRAY_CTRL_FAILURE, *PEVT_ARRAY_CTRL_FAILURE;

typedef struct _evtArrayDevFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bBay;                /* Device bay number */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_ARRAY_DEV_FAILURE, *PEVT_ARRAY_DEV_FAILURE;

typedef struct _evtArrayAccelFailure
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSlot;               /* Slot number (0==system board) */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_ARRAY_ACCEL_FAILURE, *PEVT_ARRAY_ACCEL_FAILURE;

typedef struct _evtArrayCtrlsNotRedundant
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Chassis name; '\0' if undefined */
} EVT_ARRAY_CTRLS_NOT_REDUNDANT, *PEVT_ARRAY_CTRLS_NOT_REDUNDANT;

typedef struct _evtSASArrayDevFailure
{
   EVT_CHASSIS Chassis;           /* Standard chassis info */
   BYTE     bBay;                 /* Drive bay number */
   UCHAR    szPortID [2];         /* 2 ASCII chars received from SA firmware.*/
   BYTE     bBox;                 /* BoxOnPort value returned from SA firmware. Sequential number provided on a
                                     per port basis. Used with PortID to find SAS box location.*/
   CHAR     szChassis_Sun[1];     /* Chassis name - for storage boxes which contain their own (external) array
                                     controllers; followed by IPF slot unique number string. '\0' for either
                                     if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                     would be \0) */
} EVT_SAS_ARRAY_DEV_FAILURE, *PEVT_SAS_ARRAY_DEV_FAILURE;


typedef struct _evtSASArrayPhyError
{
   EVT_CHASSIS Chassis;           /* Standard chassis info */
   UCHAR    szPortID [2];         /* 2 ASCII chars received from SA firmware.*/
   BYTE     bBox;                 /* BoxOnPort value returned from SA firmware. Sequential number provided on a
                                     per port basis. Used with PortID to find SAS box location.*/
   BYTE     bExpanderNumber;      /* Expander number within the box.*/
   BYTE     bExpanderPhyNumber;   /* Phy number of the expander.*/
   CHAR     szChassis_Sun[1];     /* Chassis name - for storage boxes which contain their own (external) array
                                     controllers; followed by IPF slot unique number string. '\0' for either
                                     if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                     would be \0) */
} EVT_SAS_ARRAY_PHY_ERROR, *PEVT_SAS_ARRAY_PHY_ERROR;

typedef struct _evtArrayCtrlsNotRedundantSun
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     szChassis_Sun[1];    /* Chassis name followed by IPF slot unique number string; '\0' for either 
                                    if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                    would be \0) */
} EVT_ARRAY_CTRLS_NOT_REDUNDANT_SUN, *PEVT_ARRAY_CTRLS_NOT_REDUNDANT_SUN;

typedef struct _evtSASArrayPhyErrorExtended
{
   EVT_CHASSIS Chassis;           /* Standard chassis info */
   UCHAR    szPortID [2];         /* PortID of Array controller reporting the PHY error. 2 ASCII chars received from SA
                                     firmware.*/
   BYTE     bBoxNumber;           /* BoxOnPort value returned from SA firmware. Sequential number provided on a
                                     per port basis. Used with PortID to find SAS box location.*/
   BYTE     bErrorPath;           /* 1 - Storage controller to external storage box.
                                     2 - Storage controller to internal device.
                                     3 - Storage controller to onboard expander.
                                     4 - Onboard expander to external storage box.
                                     5 - Onboard expander to internal device.
                                     6 - Storage box to storage box.
                                     7 - Storage box to bay in storage box.
                                     8 - Storage controller to switch expander.
                                     9 - Switch expander to storage box.*/
   CHAR     szChassis_Sun[1];     /* Chassis name - for storage boxes which contain their own (external) array
                                     controllers; followed by IPF slot unique number string. '\0' for either
                                     if undefined (ie if not for a IPF cellular system the IPF Slot string 
                                     would be \0) */
} EVT_SAS_ARRAY_PHY_ERROR_EXTENDED, *PEVT_SAS_ARRAY_PHY_ERROR_EXTENDED;

/* Eventlog Unrecoverable System Error structs */

typedef struct _evtUnrecovNmiOrBinitPlusData
{
   ULONG ulDataLow;              /* Bytes 3-0 returned from the ROM call */
   ULONG ulDataHigh;             /* Bytes 7-4 returned from the ROM call */
} EVT_UNRECOV_NMI_OR_BINIT_PLUS_DATA, *PEVT_UNRECOV_NMI_OR_BINIT_PLUS_DATA;

/* Eventlog System Revision structs */

typedef struct _evtRomFlashed
{
   CHAR     cText[1];            /* ROM identifier, version, and/or date string, '\0' if none */
} EVT_ROM_FLASH_OCCURRED, *PEVT_ROM_FLASH_OCCURRED;

/* Eventlog Maintenance structs */

typedef struct _evtMaintenanceInfo
{
   CHAR     cText[1];            /* Maintenance information string; '\0' if none */
} EVT_MAINTENANCE_INFO, *PEVT_MAINTENANCE_INFO;

#ifdef ILO_V850
/* Events internal to the iLO controller...nobody else should use them, or see them. */
/* Embedded IOP records */
typedef struct _evtIOPInfo
{
   UINT32 number;
} EVT_IOP_INFO, *PEVT_IOP_INFO;

/* Embedded IOP records - type 2 */
/* note: depending on the record type, one or both of the number
 * fields may be used.
 * Depending on the record type, one or more strings may follow.  In this case
 * the strings are separated by NULL characters, and terminated with a NULL.
 */
typedef struct _evtIOPInfo_2
{
   UINT32 number1;
   UINT32 number2;
   CHAR   cText[1];
} EVT_IOP_INFO_2, *PEVT_IOP_INFO_2;

/* ICE infrastructure records */
typedef struct _evtICEInfo
{
   // Currently just packed data (when ICE Alert packet is finalized)
   // the data can be represented here also.
   // This data would be (cast) on the host to the ICE alert structure
   // structure anyway
   CHAR data[1] ;
} EVT_RACK_INFO, *PEVT_RACK_INFO;
#endif

typedef struct _evtHealthRequest
{
   EVT_CHASSIS Chassis;
   CHAR        cChassisName[1];
} EVT_HEALTHREQUEST, *PEVT_HEALTHREQUEST;


/****************************************************************************/
/* Eventlog Infrastructure Environment structs                              */
/* EVT_CLASS_INFRASTRUCTURE_ENVIRONMENT                                     */
/****************************************************************************/

//
//  EVT_ENCL_INADEQUATE_POWER
//
#define CANT_PWR_ON_REASON_LOST_REDUNDANT_PWR            0x00
#define CANT_PWR_ON_REASON_NOT_ENOUGH_PWR                0x01
#define CANT_PWR_ON_REASON_MANAGEMENT_BOARD              0x02     // no slime found
#define CANT_PWR_ON_REASON_NO_PWR_MGMT_BOARD             0x03     // no juice found
typedef struct _evtInfEnvInadequatePwrToPwrOn
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bBlade;              /* Blade position number */
   BYTE     bReason;             /* Reason code (see above) */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_INADEQUATE_PWR_TO_PWR_ON, *PEVT_INF_ENV_INADEQUATE_PWR_TO_PWR_ON;

//
//  EVT_ENCL_MANUAL_OVERRIDE
//
typedef struct _evtInfEnvManualOverride
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bBlade;              /* Blade position number */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_MANUAL_OVERRIDE, *PEVT_INF_ENV_MANUAL_OVERRIDE;

//
//  EVT_ENCL_FUSE_OPEN
//
typedef struct _evtInfEnvFuseOpen
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bZoneId;
   BYTE     bZoneType;
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_FUSE_OPEN, *PEVT_INF_ENV_FUSE_OPEN;

//
//  EVT_ENCL_I2C_FAULT
//
typedef struct _evtInfEnvI2CFault
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bBus;                /* I2C Bus number */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_I2C_FAULT, *PEVT_INF_ENV_I2C_FAULT;

//
//  EVT_ENCL_BLADE_INS_OR_REM
//
//  Deprecated in favor of EVT_ENCL_BLADE_INSERTED and EVT_ENCL_BLADE_REMOVED
//
#define EVT_BLADE_REMOVED         0x00
#define EVT_BLADE_INSERTED        0x01
typedef struct _evtInfEnvBladeInsRem
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bBlade;              /* Blade position number */
   BYTE     bPresent;            /* 0==removed, 1==inserted */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_BLADE_INS_REM, *PEVT_INF_ENV_BLADE_INS_REM;

//
//  EVT_ENCL_PWR_LOAD_BALANCING
//
#define EVT_PWR_UNBALANCED_LEFT   0x01  /* Power Bus A */
#define EVT_PWR_UNBALANCED_RIGHT  0x02  /* Power Bus B */
typedef struct _evtInfEnvPwrLoadBalancing
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cSide;               /* 1==Left, 2==right */
   WORD     wAddress;            /* ICMB Address of Chassis */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_PWR_LOAD_BALANCING, *PEVT_INF_ENV_PWR_LOAD_BALANCING;

//
//  EVT_ENCL_DC_PWR_PROBLEM
//
#define EVT_PWR_PROBLEM_LEFT   0x00  /* Power Bus A */
#define EVT_PWR_PROBLEM_RIGHT  0x01  /* Power Bus B */
typedef struct _evtInfEnvDcPwrProblem
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cSide;               /* 0==Left, 1==right */
   WORD     wVoltage;            /* Voltage in millivolts */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_DC_PWR_PROBLEM, *PEVT_INF_ENV_DC_PWR_PROBLEM;

//
//  EVT_ENCL_AC_FACILITY_PWR_INP_EXCEEDED
//
typedef struct _evtInfEnvAcPwrInputPwrExceeded
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_AC_INPUT_PWR_EXCEEDED, *PEVT_INF_ENV_AC_INPUT_PWR_EXCEEDED;

//
//  EVT_ENCL_LOST_CHASSIS_CONNECTION
//
typedef struct _evtInfEnvLossOfChassisConnectivity
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   WORD     wAddress;            /* ICMB Address of Lost Chassis */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_LOSS_OF_CHASSIS_CONNECTIVITY, *PEVT_INF_ENV_LOSS_OF_CHASSIS_CONNECTIVITY;

//
//  EVT_ENCL_NEW_CHASSIS_CONNECTION
//
typedef struct _evtInfEnvNewChassisConnectivity
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   WORD     wAddress;            /* ICMB Address of New Chassis */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_NEW_CHASSIS_CONNECTIVITY, *PEVT_INF_ENV_NEW_CHASSIS_CONNECTIVITY;

//
//  EVT_ENCL_RACK_INFRASTRUCTURE_CHANGE
//
#define EVT_RACK_NAME_CHANGED         0x01
#define EVT_CHASSIS_NAME_CHANGED      0x02
#define EVT_SERVICE_CHANGED           0x03
#define EVT_RACK_NAME_CONFLICT        0x04
#define EVT_RACK_UID_CHANGED          0x05
// 0x06 is reserved
#define EVT_RACK_LAN_SETTINGS_CHANGED 0x07
#define EVT_RACK_UID_STATE_CHANGED    0x08
typedef struct _evtInfEnvRackInfrastructureChg
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bType;               /* Type of infrastructure change (see above) */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_RACK_INFRASTRUCTURE_CHG, *PEVT_INF_ENV_RACK_INFRASTRUCTURE_CHG;

//
//  EVT_ENCL_UNKNOWN_PWR_CONSUMPTION
//
typedef struct _evtInfEnvUnknownPwrConsumption
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_UNKNOWN_PWR_CONSUMPTION, *PEVT_INF_ENV_UNKNOWN_PWR_CONSUMPTION;

//
//  EVT_ENCL_IMPROPERLY_CONF_PWR_SYS
//
#define EVT_LOAD_BALANCING_WIRE_MISSING            0x01
#define EVT_TOO_MANY_COMPRESSORS                   0x02
#define EVT_IMPROPERLY_CONFIGURED_PWR_BANK         0x03
#define EVT_DC_TO_DC_CONFIG_INVALID                0x04
#define EVT_LOCATION_NA                            0x00
#define EVT_LOCATION_LEFT_SIDE                     0x01
#define EVT_LOCATION_RIGHT_SIDE                    0x02
typedef struct _evtInfEnvPwrSubSysMisconfigured
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bError;              /* Type of power configuration error (see above) */
   BYTE     bLocation;           /* Location of power configuration error (see above) */
   WORD     wAddress;            /* ICMB Address of Chassis */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_PWR_SUBSYS_MISCONFIGURED, *PEVT_INF_ENV_PWR_SUBSYS_MISCONFIGURED;

//
//  EVT_ENCL_MANAGER_STATUS
//
typedef struct _evtInfEnvEnclosureMgrStatus
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_ENCLOSURE_MGR_STATUS, *PEVT_INF_ENV_ENCLOSURE_MGR_STATUS;

//
//  EVT_ENCL_BLOWER_FAULT
//
typedef struct _evtInfEnvBlowerFault
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bProblem;            /* 1==blower 1 fault, 2==blower 2 fault, etc. */
   BYTE     bSide;               /* 1==Left side, 2==right side */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_BLOWER_FAULT, *PEVT_INF_ENV_BLOWER_FAULT;

//
//  EVT_ENCL_BLOWER_REMOVED
//
typedef struct _evtInfEnvBlowerRemoved
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bProblem;            /* 1==blower 1, 2==blower 2, etc. */
   BYTE     bSide;               /* 1==Left side, 2==right side */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_BLOWER_REMOVED, *PEVT_INF_ENV_BLOWER_REMOVED;

//
//  EVT_ENCL_ETHERNET_SWITCH_FAULT
//
#define EVT_ETH_POST_FAILURE           0x01
#define EVT_ETH_MICRO_FAULT            0x02
#define EVT_ETH_POWER_FAULT            0x03
#define EVT_ETH_OVERCURRENT            0x04
#define EVT_ETH_FAN_1_FAILED           0x05
#define EVT_ETH_TEMP_CAUTION           0x06
#define EVT_ETH_TEMP_FAILED            0x07
#define EVT_ETH_RJ45_MODULE_MISSING    0x08
#define EVT_ETH_FAN_2_FAILED           0x09
typedef struct _evtInfEnvEthernetSwitchFault
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bProblem;            /* See above */
   BYTE     bSide;               /* 1==Left side, 2==right side */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_ETHERNET_SWITCH_FAULT, *PEVT_INF_ENV_ETHERNET_SWITCH_FAULT;

//
//  EVT_ENCL_INPUT_PWR_SENSE_ERROR
//
#define EVT_PWR_BUS_BAR_A              0x01
#define EVT_PWR_BUS_BAR_B              0x02
typedef struct _evtInfEnvInputPwrSenseError
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bSide;               /* EVT_PWR_BUS_BAR_A or EVT_PWR_BUS_BAR_B */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_INPUT_PWR_SENSE_ERR, *PEVT_INF_ENV_INPUT_PWR_SENSE_ERR;

//
//  EVT_ENCL_BLADE_INSERTED
//  EVT_ENCL_BLADE_REMOVED
//
#define EVT_A_SIDE                     0x01
#define EVT_B_SIDE                     0x02
typedef struct _evtInfEnvBladeInsRem2
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bZoneId;             /* Blade slot number; or network slot (1==A, 2==B) */
   BYTE     bZoneType;           /* EVT_LOCALE_NETWORK_SLOT or EVT_LOCALE_BLADE_SLOT */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_ENV_BLADE_INS_REM_2, *PEVT_INF_ENV_BLADE_INS_REM_2;

//
//  EVT_ENCL_RACK_TOPOLOGY_ERROR
//
#define EVT_INVALID_CABLING            0x01
#define EVT_INVALID_PWR_ZONE           0x02
typedef struct _evtInfEnvRackTopologyErr
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bReason;             /* see above */
} EVT_INF_ENV_RACK_TOPOLOGY_ERR, *PEVT_INF_ENV_RACK_TOPOLOGY_ERR;

//
//  EVT_ENCL_CHASSIS_ERROR
//

//defines for main locations
#define EVT_ENCL_CHASSIS_SLOT1       0x00
#define EVT_ENCL_CHASSIS_SLOT2       0x01
#define EVT_ENCL_CHASSIS_SLOT3       0x02
#define EVT_ENCL_CHASSIS_SLOT4       0x03
#define EVT_ENCL_CHASSIS_SLOT5       0x04
#define EVT_ENCL_CHASSIS_SLOT6       0x05
#define EVT_ENCL_CHASSIS_SLOT7       0x06
#define EVT_ENCL_CHASSIS_SLOT8       0x07
#define EVT_ENCL_SLIME_BOARD         0x08
#define EVT_ENCL_SIGNAL_BACKPLANE    0x09
#define EVT_ENCL_POWER_BACKPLANE_A   0x0A
#define EVT_ENCL_POWER_BACKPLANE_B   0x0B
#define EVT_ENCL_ICE_MAKER_EAST      0x0C
#define EVT_ENCL_ICE_MAKER_WEST      0x0D
#define EVT_ENCL_RJ45_10_EAST        0x0E
#define EVT_ENCL_RJ45_10_WEST        0x0F
#define EVT_ENCL_RJ45_6_EAST         0x10
#define EVT_ENCL_RJ45_6_WEST         0x11
#define EVT_ENCL_UNKNOWN             0x12

//defines for sublocations
#define EVT_ENCL_GROMIT                 0x00
#define EVT_ENCL_FRU_EEPROM             0x01
#define EVT_ENCL_MEMORY                 0x02
#define EVT_ENCL_ICMB_UART              0x03
#define EVT_ENCL_ROM                    0x04
#define EVT_ENCL_LM75                   0x05
#define EVT_ENCL_I2C_BUS_0              0x06
#define EVT_ENCL_I2C_BUS_1              0x07
#define EVT_ENCL_I2C_BUS_2              0x08
#define EVT_ENCL_SOFTWARE               0x09
#define EVT_ENCL_I2C_BUS                0x0A
#define EVT_ENCL_DEV_9544_FUSE_MUX      0x0B
#define EVT_ENCL_DEV_9555_QUICK_SWITCH  0x0C
#define EVT_ENCL_DEV_9555_SENSE         0x0D
#define EVT_ENCL_DEV_9555_ENABLE        0x0E
#define EVT_ENCL_DEV_9555_IO_EXPANDER   0x0F
#define EVT_ENCL_DEV_9544_MUX           0x10

//defines for errors
#define EVT_ENCL_I2C_ERROR           0x00
#define EVT_ENCL_INTERRUPT_ERROR     0x01
#define EVT_ENCL_INVALID_FRU_DATA    0x02
#define EVT_ENCL_POST_FAILURE        0x03
#define EVT_ENCL_BACKUP_ROM_BOOTED   0x04
#define EVT_ENCL_BUS_ERROR           0x05
#define EVT_ENCL_STACK_OVERFLOW      0x06
#define EVT_ENCL_I2C_BUS_TIMEOUT     0x07
#define EVT_ENCL_UNKNOWN_I2C_ERROR   0x08

typedef struct _evtInfEnvChassisErr
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bLocation;           /* see above for location codes*/
   BYTE     bSubLocation;        /* see above for sublocation codes*/
   BYTE     bError;              /* see above for error codes*/
} EVT_INF_ENV_CHASSIS_ERR, *PEVT_INF_ENV_CHASSIS_ERR;

#ifdef ILO_V850
/* Events internal to the iLO controller...nobody else should use them, or see them. */
//
//  EVT_ENCL_UNKNOWN_ICMB
//
#define EVT_CANT_TALK                  0x01
typedef struct _evtInfEnvRackUnknownICMB
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bReason;             /* see above */
} EVT_INF_ENV_RACK_UNKNOWN_ICMB, *PEVT_INF_ENV_RACK_UNKNOWN_ICMB;
#endif

//
//  EVT_ENCL_INFRASTRUCTURE_FIRMWARE_MISMATCH
//
typedef struct _evtInfFirmwareMismatch
{
   EVT_CHASSIS Chassis;          /* Standard chassis info */
   BYTE     bCurrentMajor;       /* Major Version Number of current firmware */
   BYTE     bCurrentMinor;       /* Minor Version Number of current firmware */
   BYTE     bRequiredMajor;      /* Major Version Number of required firmware */
   BYTE     bRequiredMinor;      /* Minor Version Number of required firmware */
   WORD     wICMB_Number;        /* ICMB of offending un-upgraded chassis */
   CHAR     cChassisName[1];     /* Chassis (or serial) number (\0 if not available) */
} EVT_INF_FIRMWARE_MISMATCH, *PEVT_INF_FIRMWARE_MISMATCH;

//
// EVT_CLASS_EMBEDDED HEALTH Structures
// 

typedef struct _evtEmbeddedHealth
{
  WORD wAlertID;
  WORD wFlags;
  WORD wDataValue;            
} EVT_EMBEDDED_HEALTH, *PEVT_EMBEDDED_HEALTH;


//
// EVT_CLASS_XNC_ORION Structures
// 

typedef struct _evtXncOrion
{
  BYTE	bLocation;		// 0x08A == Upper, 0x08C == Lower
} EVT_XNC_ORION, *PEVT_XNC_ORION;

/****************************************************************************/
/* Eventlog free form data union                                            */
/****************************************************************************/

typedef union _evtFreeForm
{
   unsigned char				      b[1];
   EVT_MACH_OVERHEAT                                  MachHeat;
   EVT_MACH_FAN_FAIL                                  MachFan;
   EVT_MACH_DOOR_OPEN                                 MachDoor;
   EVT_MACH_FAN_REMOVED                               MachFanRem;
   EVT_MACH_FAN_INSERTED                              MachFanIns;
   EVT_MACH_FAN_NOT_REDUNDANT                         MachFanNotRed;
   EVT_MACH_FAN_NOT_REDUNDANT_SHARED                  MachFanNotRedShared;
   EVT_MACH_SAS_FAN_FAIL                              MachFanSas;
   EVT_MACH_SAS_OVERHEAT                              MachHeatSas;
   EVT_MAIN_MEMORY                                    MainMem;
   EVT_MAIN_MEMORY_MULTI                              MainMemMulti;
   EVT_MAIN_MEMORY_USER_ACTION                        MainMemAction;
   EVT_MAIN_MEMORY_HW_STATUS                          MainMemHwStat;
   EVT_MAIN_MEMORY_CONFIG_ERR                         MainMemCfErr;
   EVT_MAIN_MEMORY_CONFIG_CHG                         MainMemCfChg;
   EVT_MAIN_MEMORY_SPARE_ENGAGED                      MainMemSpare;
   EVT_MAIN_MEMORY_MIRROR_ENGAGED                     MainMemMirror;
   EVT_MAIN_MEMORY_CONFIGURATION                      MainMemConfig;
   EVT_MAIN_MEMORY_BOARD_FAILURE                      MainMemBoardFailure;
   EVT_MAIN_MEMORY_FAIL_IN_ROM_DIAG                   MainMemFailInRomDiag;
   EVT_CACHE_ACCEL_PARITY_ERROR                       CacheAccelError;
   EVT_CPU_CORRECTABLE                                CpuCorr;
   EVT_CPU_UNCORRECTABLE                              CpuUncorr;
   EVT_HOST_BUS_UNCORRECTABLE                         HbUncorr;
   EVT_INTERMODULE_BUS_UNCORRECTABLE                  IntModUncorr;
   EVT_EISA_BUS                                       EisaBus;
   EVT_PCI_BUS                                        PciBus;
   EVT_EXPANSION_SLOT                                 Slot;
   EVT_EXPANSION_SLOT_CONFIG_ERR                      SlotConfig;
   EVT_POST_MESSAGE                                   PostMsg;
   EVT_POWER_SUPPLY_FAILURE                           PsFail;
   EVT_BATTERY_LOW                                    BatLow;
   EVT_POWER_MODULE_FAILURE                           PowerMod;
   EVT_POWER_SUPPLY_REMOVED                           PsRem;
   EVT_POWER_SUPPLY_INSERTED                          PsIns;
   EVT_POWER_NOT_REDUNDANT                            PsNotRed;
   EVT_INF_POWER_NOT_REDUNDANT                        PsInfNotRed;
   EVT_POWER_MODULES_NOT_REDUNDANT                    PowerModNotRed;
   EVT_POWER_AC_VOLTAGE                               PsAcVolt;
   EVT_POWER_AC_OVERLOAD                              PsAcOverload;
   EVT_POWER_SUPPLY_UNPOWERED                         PsUnpowered;
   EVT_POWER_SUPPLY_POWERED                           PsPowered;
   EVT_SYS_POWER_MODULE_FAILURE                       PsModFail;
   EVT_SYS_POWER_MODULE_REMOVED                       PsModRem;
   EVT_SYS_POWER_MODULE_INSERTED                      PsModIns;
   EVT_SYS_POWER_MODULE_NOT_REDUNDANT                 PsModNotRed;
   EVT_SYS_POWER_MODULE_OVERLOAD                      PsModOverload;
   EVT_SAS_POWER_SUPPLY_FAILURE                       PsFailSas;
   EVT_ASR_LOCKUP                                     AsrLockup;
   EVT_OS_CRASH                                       OsCrash;
   EVT_AUTO_SHUTDOWN                                  Shutdown;
   EVT_OS_FATAL_EXCEPTION                             OsExcept;
   EVT_OS_PWR_SHED                                    OsPwrShed;
   EVT_NIC_ERROR                                      NicErr;
   EVT_NICS_NOT_REDUNDANT                             NicNotRed;
   EVT_SCSI_CTRL_FAILURE                              ScsiCtrl;
   EVT_SCSI_DEVICE_FAILURE                            ScsiDev;
   EVT_SCSI_CTRLS_NOT_REDUNDANT                       ScsiNotRed;
   EVT_ARRAY_CTRL_FAILURE                             ArrayCtrl;
   EVT_ARRAY_DEV_FAILURE                              ArrayDev;
   EVT_ARRAY_ACCEL_FAILURE                            ArrayAccel;
   EVT_ARRAY_CTRLS_NOT_REDUNDANT                      ArrayNotRed;
   EVT_SAS_ARRAY_DEV_FAILURE                          ArrayDevSas;
   EVT_SAS_ARRAY_PHY_ERROR                            ArraySasPHY;
   EVT_ARRAY_CTRLS_NOT_REDUNDANT_SUN                  ArrayNotRedSun;
   EVT_SAS_ARRAY_PHY_ERROR_EXTENDED                   ArraySasPHYExtended;
   EVT_UNRECOV_NMI_OR_BINIT_PLUS_DATA                 NmiPlusData;
   EVT_ROM_FLASH_OCCURRED                             RomFlash;
   EVT_MAINTENANCE_INFO                               Maint;
   EVT_HEALTHREQUEST                                  HealthRequest;
   EVT_INF_ENV_INADEQUATE_PWR_TO_PWR_ON               InfCantPwrOn;
   EVT_INF_ENV_MANUAL_OVERRIDE                        InfManOverride;
   EVT_INF_ENV_FUSE_OPEN                              InfFuseOpen;
   EVT_INF_ENV_I2C_FAULT                              InfI2cFlt;
   EVT_INF_ENV_BLADE_INS_REM                          InfBladeInsRem;      // Deprecated
   EVT_INF_ENV_PWR_LOAD_BALANCING                     InfPwrLoadBal;
   EVT_INF_ENV_DC_PWR_PROBLEM                         InfDcPwrProblem;
   EVT_INF_ENV_AC_INPUT_PWR_EXCEEDED                  InfAcPwrProblem;
   EVT_INF_ENV_LOSS_OF_CHASSIS_CONNECTIVITY           InfLostCon;
   EVT_INF_ENV_NEW_CHASSIS_CONNECTIVITY               InfNewCon;
   EVT_INF_ENV_RACK_INFRASTRUCTURE_CHG                InfRackChange;
   EVT_INF_ENV_UNKNOWN_PWR_CONSUMPTION                InfUnknownPwrUse;
   EVT_INF_ENV_PWR_SUBSYS_MISCONFIGURED               InfPwrMisconfig;
   EVT_INF_ENV_ENCLOSURE_MGR_STATUS                   InfEnclMgrStatus;
   EVT_INF_ENV_BLOWER_FAULT                           InfBlwrFault;
   EVT_INF_ENV_BLOWER_REMOVED                         InfBlwrRem;
   EVT_INF_ENV_ETHERNET_SWITCH_FAULT                  InfEthSwFlt;
   EVT_INF_ENV_INPUT_PWR_SENSE_ERR                    InfInPwrSenseErr;
   EVT_INF_ENV_BLADE_INS_REM_2                        InfBladeInsRem2;
   EVT_INF_ENV_RACK_TOPOLOGY_ERR                      InfTopErr;
   EVT_INF_ENV_CHASSIS_ERR                            InfChassisError;
   #ifdef ILO_V850
   /* Events internal to the iLO controller...nobody else should use them, or see them. */
   EVT_INF_ENV_RACK_UNKNOWN_ICMB                      InfUnkICMB;
   EVT_IOP_INFO                                       IOP;
   EVT_IOP_INFO_2                                     IOP_2;
   EVT_RACK_INFO                                      Rack;
   #endif
   EVT_INF_FIRMWARE_MISMATCH                          InfFirmwareMismatch;
   EVT_EMBEDDED_HEALTH                                EmbeddedHealth;
   EVT_XNC_ORION				      XncOrion;
} EVT_FREE_FORM, *PEVT_FREE_FORM;

#pragma pack()

int  IML_parse_entry(IML_entry_t *pIML, char msg[], uint32_t msglen);

#ifdef __cplusplus
}
#endif

#endif /* imltext_eventlog_h */
