/*
 ***************************************************************************
 *  Copyright (c) 1996-2007 Hewlett-Packard Development Company, L.P.
 *  HP Confidential
 ***************************************************************************
 *
 *  Title:    System Event Log Support - String definitions
 *
 *  Module:   EVENTSTR.H
 *
 *  Version:  1.0
 *
 *  Date:     8/26/1996
 *
 *  Author:   Alan K. Minchew
 *
 *  Maintenance Contact: Bradley Reed
 *
 *  Ported for use in libIMLtext by John Marvin (November 2007)
 *	renamed to imltext_eventstr.h. Note, it is probably best to
 *	keep the formatting the same in this file so as to make it easier
 *	to merge additions from the "official" source.
 *
 ***************************************************************************
 *
 *  The "official" copy of this file is kept in the Automated Build System
 *  CVS repository, along with the IML specification.  The same process used
 *  to review and approve specification changes should also be used when
 *  updating this file.  See Appendix C in the spec for more information.
 *  Download the spec from http://abs.cca.cpqcorp.net/docs/ISS/IML.doc.
 *
 ***************************************************************************
 */

#ifndef imltext_eventstr_h
#define imltext_eventstr_h

#ifdef __cplusplus
extern "C" {
#endif

/* General substitution strings */
#define STR_UNKNOWN \
   "Unknown"
#define STR_CHASSIS_FORMAT \
   "Chassis %s, "
#define STR_NO_CHASSIS \
   ""
#define STR_TEMPERATURE \
   "%uC"

#define STR_EXTERNAL \
   "External"
#define STR_INTERNAL \
   "Internal"

/* Substitution Power Supply Error strings */
#define STR_PSERR_NONE \
   "No Error"
#define STR_PSERR_UNKNOWN \
   "Unknown Failure"
#define STR_PSERR_GENERR \
   "General Failure"
#define STR_PSERR_BIST \
   "BIST Failure"
#define STR_PSERR_FAN \
   "Fan Failure"
#define STR_PSERR_EPROM \
   "EPROM Failure"
#define STR_PSERR_VREF \
   "VREF Failure"
#define STR_PSERR_DAC \
   "DAC Failure"
#define STR_PSERR_RAMTEST \
   "RAM Test Failed"
#define STR_PSERR_VOLTAGE_CHANNEL \
   "Voltage Channel Failure"
#define STR_PSERR_GIVEUP \
   "Give Up On Startup"
#define STR_PSERR_NVRAM_INVALID \
   "NVRAM Invalid"
#define STR_PSERR_CALIBRATION \
   "Calibration Table Invalid"

/* Substitution locale strings */
#define STR_LOCALE_UNKNOWN \
  "Unknown"
#define STR_LOCALE_SYSTEM \
  "System"
#define STR_LOCALE_SYSTEM_BOARD \
  "System Board"
#define STR_LOCALE_IO_BOARD \
  "I/O Board"
#define STR_LOCALE_CPU \
  "CPU"
#define STR_LOCALE_MEMORY \
  "Memory"
#define STR_LOCALE_STORAGE \
  "Storage"
#define STR_LOCALE_REM_MEDIA \
  "Removable Media"
#define STR_LOCALE_POWER_SUPPLY \
  "Power Supply"
#define STR_LOCALE_AMBIENT \
  "Ambient"
#define STR_LOCALE_CHASSIS \
  "Chassis"
#define STR_LOCALE_BRIDGE_BOARD \
  "Bridge Board"
#define STR_LOCALE_MGMT_BOARD \
  "Management Board"
#define STR_LOCALE_BACKPLANE \
  "Backplane"
#define STR_LOCALE_NETWORK_SLOT \
  "Network Slot"
#define STR_LOCALE_BLADE_SLOT \
  "Blade Slot"
#define STR_LOCALE_VIRTUAL \
  "Virtual"

/* Misc. redundancy sub-strings */
#define STR_REDUNDANCY_COMPRESSOR \
  "Enclosure"
#define STR_REDUNDANCY_YETI \
  "Power Module"
#define STR_REDUNDANCY_BUSBAR \
  "Bus Bar"
#define STR_REDUNDANCY_BREAKER \
  "Breaker"
#define STR_REDUNDANCY_POWERSUBSYS \
  "Power Subsystem"

/* Misc. AC problem sub-strings */
#define STR_ACPROBLEM_OVER\
  "Line Over Voltage"
#define STR_ACPROBLEM_UNDER\
  "Line Under Voltage"
#define STR_ACPROBLEM_LINEHIT \
  "Line Hit"
#define STR_ACPROBLEM_BROWNOUT\
  "Brown Out"
#define STR_ACPROBLEM_POWERLOSS \
  "AC Power Loss"

/* Misc. location sub-strings */
#define STR_LOCATION_LEFT_SIDE \
  "Left Side"
#define STR_LOCATION_RIGHT_SIDE \
  "Right Side"
#define STR_LOCATION_UNKNOWN \
  "Unknown Location"

/* Ethernet switch fault error code strings */
#define STR_ETH_SW_POST_FAILED \
  "Powering up"
#define STR_ETH_SW_MICRO_FAILED \
  "Micro-controller fault"
#define STR_ETH_SW_PWR_FAULT \
  "Power fault"
#define STR_ETH_SW_OVERCURRENT \
  "Over-current fault"
#define STR_ETH_SW_FAN_1_FAILED \
  "Fan 1 failed or removed"
#define STR_ETH_SW_TEMP_CAUTION \
  "Temperature at caution level"
#define STR_ETH_SW_TEMP_CRITICAL \
  "Temperature at critical level"
#define STR_ETH_SW_RJ45_MISSING \
  "RJ45 module missing"
#define STR_ETH_SW_FAN_2_FAILED \
  "Fan 2 failed or removed"

/* Power Bus strings */
#define STR_PWR_BUS_A \
  "Power Bus A"
#define STR_PWR_BUS_B \
  "Power Bus B"

/* This is to be displayed with ICE specific events */
#define STR_CHASSIS_FULL \
  "Enclosure Serial Number %.16s"
/* Only useful on p-Class enclosures - c-Class does not use the ICMB address */
#define STR_CHASSIS_ICMB \
  "Enclosure Address %04X"    

/* SUN information string formatting for partitioned IPF systems */
#define SUN_INFO_STRING_FORMAT \
   ", %s"

/* Blade enclosure types */
#define ENCLOSURE_TYPE_SERVER_BLADE \
   "Server Blade Enclosure"
#define ENCLOSURE_TYPE_POWER \
   "Power Enclosure"

/* Empty eventlog entry (here only for completeness) */
#define STR_EVT_EMPTY \
   "Empty"

/* The test eventlog entry */
#define STR_EVT_TEST \
   "Reserved"

/* Unknown event (for forward compatibility) */
#define STR_EVT_UNKNOWN \
   "Unknown Event (Class 0x%02X, Code 0x%02X)"

/* Machine Overheating messages */
#define STR_EVT_SYSTEM_OVERHEAT \
   "System Overheating (Zone %s, Location %s, Temperature %s)"
#define STR_EVT_CHASSIS_OVERHEAT \
   "External Chassis Overheating (Chassis %s, Zone %s, Location %s, Temperature %s)"
#define STR_EVT_STORSYS_OVERHEAT \
   "External Storage System Overheating (%sSlot %s, Zone %s, Location %s, Temperature %s)"
#define STR_EVT_INT_STORSYS_OVERHEAT \
   "Internal Storage System Overheating (%sSlot %s, Zone %s, Location %s, Temperature %s)"
#define STR_EVT_BLADE_OVERHEAT \
   "Server Blade Enclosure Overheating (Zone %s, Location %s, Temperature %s, %s)"
#define STR_EVT_POWER_OVERHEAT \
   "Power Enclosure Overheating (Zone %s, Location %s, Temperature %s, %s)"
#define STR_EVT_OVERHEAT_SAS \
   "%s SAS Enclosure Overheating (Zone %u, Location %s, Box %u, Port %s, %s)"

/* Machine Fan messages */
#define STR_EVT_FAN_FAIL \
   "Fan Failure (Fan %s, Location %s)"
#define STR_EVT_CHASSIS_FAN_FAIL \
   "External Chassis Fan Failure (Chassis %s, Fan %s, Location %s)"
#define STR_EVT_STORSYS_FAN_FAIL \
   "External Storage System Fan Failure (%sSlot %s, Fan %s, Location %s)"
#define STR_EVT_INT_STORSYS_FAN_FAIL \
   "Internal Storage System Fan Failure (%sSlot %s, Fan %s, Location %s)"
#define STR_EVT_BLADE_FAN_FAIL \
   "Server Blade Enclosure Fan Failure (Fan %s, Location %s, %s)"
#define STR_EVT_POWER_FAN_FAIL \
   "Power Enclosure Fan Failure (Fan %s, Location %s, %s)"
#define STR_EVT_FAN_FAIL_SAS \
   "%s SAS Enclosure Fan Failure (Fan %u, Location %s, Box %u, Port %s, %s)"

/* Machine Door messages */
#define STR_EVT_DOOR_OPEN \
   "Side panel removed or improperly installed"
#define STR_EVT_CHASSIS_DOOR_OPEN \
   "External Chassis side panel removed or improperly installed (Chassis %s)"
#define STR_EVT_STORSYS_DOOR_OPEN \
   "External Storage System side panel removed or improperly installed (%sSlot %s)"
#define STR_EVT_INT_STORSYS_DOOR_OPEN \
   "Internal Storage System side panel removed or improperly installed (%sSlot %s)"
#define STR_EVT_BLADE_DOOR_OPEN \
   "Server Blade Enclosure side panel removed or improperly installed"
#define STR_EVT_POWER_DOOR_OPEN \
   "Power Enclosure side panel removed or improperly installed"

/* Machine Fan Inserted messages */
#define STR_EVT_FAN_INSERTED \
   "System Fan Inserted (Fan %s, Location %s)"
#define STR_EVT_CHASSIS_FAN_INSERTED \
   "External Chassis Fan Inserted (Chassis %s, Fan %s, Location %s)"
#define STR_EVT_STORSYS_FAN_INSERTED \
   "External Storage System Fan Inserted (%sSlot %s, Fan %s, Location %s)"
#define STR_EVT_INT_STORSYS_FAN_INSERTED \
   "Internal Storage System Fan Inserted (%sSlot %s, Fan %s, Location %s)"
#define STR_EVT_BLADE_FAN_INSERTED \
   "Server Blade Enclosure Fan Inserted (Fan %s, Location %s, %s)"
#define STR_EVT_POWER_FAN_INSERTED \
   "Power Enclosure Fan Inserted (Fan %s, Location %s, %s)"

/* Machine Fan Removed messages */
#define STR_EVT_FAN_REMOVED \
   "System Fan Removed (Fan %s, Location %s)"
#define STR_EVT_CHASSIS_FAN_REMOVED \
   "External Chassis Fan Removed (Chassis %s, Fan %s, Location %s)"
#define STR_EVT_STORSYS_FAN_REMOVED \
   "External Storage System Fan Removed (%sSlot %s, Fan %s, Location %s)"
#define STR_EVT_INT_STORSYS_FAN_REMOVED \
   "Internal Storage System Fan Removed (%sSlot %s, Fan %s, Location %s)"
#define STR_EVT_BLADE_FAN_REMOVED \
   "Server Blade Enclosure Fan Removed (Fan %s, Location %s, %s)"
#define STR_EVT_POWER_FAN_REMOVED \
   "Power Enclosure Fan Removed (Fan %s, Location %s, %s)"

/* Machine Fans Not Redundant messages */
#define STR_EVT_FAN_NOT_REDUNDANT \
   "System Fans Not Redundant (Location %s)"
#define STR_EVT_FAN_NOT_REDUNDANT_SHARED \
   "System Fans Not Redundant (Shared Location %s)"
#define STR_EVT_CHASSIS_FAN_NOT_REDUNDANT \
   "External Chassis Fans Not Redundant (Chassis %s, Location %s)"
#define STR_EVT_STORSYS_FAN_NOT_REDUNDANT \
   "External Storage System Fans Not Redundant (%sSlot %s, Location %s)"
#define STR_EVT_INT_STORSYS_FAN_NOT_REDUNDANT \
   "Internal Storage System Fans Not Redundant (%sSlot %s, Location %s)"
#define STR_EVT_BLADE_FAN_NOT_REDUNDANT \
   "Server Blade Enclosure Fans Not Redundant (Location %s, %s)"
#define STR_EVT_POWER_FAN_NOT_REDUNDANT \
   "Power Enclosure Fans Not Redundant (Location %s, %s)"

/* Main Memory Correctable error messages */
#define STR_EVT_MAIN_MEM_CORR \
   "Corrected Memory Error threshold exceeded (Slot %s, Memory Module %s)"
#define STR_EVT_MAIN_MEM_CORR_SYSTEM \
   "Corrected Memory Error threshold exceeded (System Memory)"
#define STR_EVT_MAIN_MEM_CORR_SYSTEM_2 \
   "Corrected Memory Error threshold exceeded (System Memory, Memory Module %s)"
#define STR_EVT_MAIN_MEM_CORR_UNKNOWN \
   "Corrected Memory Error threshold exceeded (Memory Module Unknown)"
#define STR_EVT_MAIN_MEM_CORR_SN \
   "Corrected Memory Error threshold exceeded (Slot %s, Memory Module %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_CORR_SYSTEM_SN \
   "Corrected Memory Error threshold exceeded (System Memory, Serial Number %s)"
#define STR_EVT_MAIN_MEM_CORR_SYSTEM_SN_2 \
   "Corrected Memory Error threshold exceeded (System Memory, Memory Module %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_CORR_UNKNOWN_SN \
   "Corrected Memory Error threshold exceeded (Memory Module Unknown, Serial Number %s)"
#define STR_EVT_MAIN_MEM_BANK_CORR \
   "Corrected Memory Error threshold exceeded (Slot %s, Bank %s)"
#define STR_EVT_MAIN_MEM_BANK_CORR_SYSTEM \
   "Corrected Memory Error threshold exceeded (System Memory)"
#define STR_EVT_MAIN_MEM_BANK_CORR_SYSTEM_2 \
   "Corrected Memory Error threshold exceeded (System Memory, Bank %s)"
#define STR_EVT_MAIN_MEM_BANK_CORR_UNKNOWN \
   "Corrected Memory Error threshold exceeded (Bank Unknown)"
#define STR_EVT_MAIN_MEM_BANK_CORR_SN \
   "Corrected Memory Error threshold exceeded (Slot %s, Bank %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_BANK_CORR_SYSTEM_SN \
   "Corrected Memory Error threshold exceeded (System Memory, Serial Number %s)"
#define STR_EVT_MAIN_MEM_BANK_CORR_SYSTEM_SN_2 \
   "Corrected Memory Error threshold exceeded (System Memory, Bank %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_BANK_CORR_UNKNOWN_SN \
   "Corrected Memory Error threshold exceeded (Bank Unknown, Serial Number %s)"

/* Main Memory Uncorrectable error messages */
#define STR_EVT_MAIN_MEM_UNCORR \
   "Uncorrectable Memory Error (Slot %s, Memory Module %s)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM \
   "Uncorrectable Memory Error (System Memory)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_2 \
   "Uncorrectable Memory Error (System Memory, Memory Module %s)"
#define STR_EVT_MAIN_MEM_UNCORR_UNKNOWN \
   "Uncorrectable Memory Error (Module Unknown)"
#define STR_EVT_MAIN_MEM_UNCORR_SN \
   "Uncorrectable Memory Error (Slot %s, Memory Module %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_SN \
   "Uncorrectable Memory Error (System Memory, Serial Number %s)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_SN_2 \
   "Uncorrectable Memory Error (System Memory, Memory Module %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_UNCORR_UNKNOWN_SN \
   "Uncorrectable Memory Error (Module Unknown, Serial Number %s)"

/* Main Memory Uncorrectable error messages (multiple locations) */
#define STR_EVT_MAIN_MEM_UNCORR_NEXT \
   " or (Slot %s, Memory Module %s)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_NEXT \
   " or (System Memory)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_NEXT_2 \
   " or (System Memory, Memory Module %s)"
#define STR_EVT_MAIN_MEM_UNCORR_UNKNOWN_NEXT \
   " or (Module Unknown)"
#define STR_EVT_MAIN_MEM_UNCORR_SN_NEXT \
   " or (Slot %s, Memory Module %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_SN_NEXT \
   " or (System Memory, Serial Number %s)"
#define STR_EVT_MAIN_MEM_UNCORR_SYSTEM_SN_NEXT_2 \
   " or (System Memory, Memory Module %s, Serial Number %s)"
#define STR_EVT_MAIN_MEM_UNCORR_UNKNOWN_SN_NEXT \
   " or (Module Unknown, Serial Number %s)"

/* Main Memory User Action messages */
#define STR_EVT_MAIN_MEM_CARTRIDGE_REMOVED \
   "Memory Cartridge Removed (Slot %s)"
#define STR_EVT_MAIN_MEM_CARTRIDGE_INSERTED \
   "Memory Cartridge Inserted (Slot %s)"
#define STR_EVT_MAIN_MEM_BOARD_REMOVED \
   "Memory Board Removed (Slot %s)"
#define STR_EVT_MAIN_MEM_BOARD_INSERTED \
   "Memory Board Inserted (Slot %s)"
#define STR_EVT_MAIN_MEM_CARTRIDGE_UNLOCKED \
   "Memory Cartridge Unlocked (Slot %s)"
#define STR_EVT_MAIN_MEM_CARTRIDGE_LOCKED \
   "Memory Cartridge Locked (Slot %s)"

/* Main Memory Hardware Status messages */
#define STR_EVT_MAIN_MEM_CARTRIDGE_BUS_FAULT \
   "Memory Cartridge Bus Fault (Slot %s)"
#define STR_EVT_MAIN_MEM_CARTRIDGE_POWER_FAULT \
   "Memory Cartridge Power Fault (Slot %s)"
#define STR_EVT_MAIN_MEM_CARTRIDGE_NON_REDUNDANT \
   "Memory Cartridge Not Redundant (Slot %s)"
#define STR_EVT_MAIN_MEM_CARTRIDGE_ONLINE \
   "Memory Cartridge Online (Slot %s)"

/* Main Memory Configuration Error messages */
#define STR_EVT_MAIN_MEM_CONFIG_ERR \
   "Memory Cartridge Configuration Error (Slot %s, Memory Module %s)"
#define STR_EVT_MAIN_MEM_CONFIG_ERR_BOARD \
   "Memory Board Configuration Error (Slot %s, Memory Module %s)"

/* Main Memory Configuration change messages */
#define STR_EVT_MAIN_MEM_ADDED \
   "Memory Added (Size %s MB)"
#define STR_EVT_MAIN_MEM_REMOVED \
   "Memory Successfully Removed"

/* Main Memory Online Spare Engaged messages */
#define STR_EVT_MAIN_ONLINE_SPARE_ENGAGED \
   "Online Spare Memory Copy Process Started for Faulty Module (Slot %s, Memory Module %s)"
#define STR_EVT_MAIN_ONLINE_SPARE_BANK_ENGAGED \
   "Online Spare Memory Copy Process Started for Faulty Module (Slot %s, Bank %s)"
#define STR_EVT_MAIN_ONLINE_SPARE_ENGAGED_SYSTEM \
   "Online Spare Memory Copy Process Started for Faulty Module (System Memory, Memory Module %s)"
#define STR_EVT_MAIN_ONLINE_SPARE_BANK_ENGAGED_SYSTEM \
   "Online Spare Memory Copy Process Started for Faulty Module (System Memory, Bank %s)"
#define STR_EVT_MAIN_ONLINE_SPARE_BANK_ENGAGED_UN \
   "Online Spare Memory Copy Process Started for Faulty Module (Module Unknown)"

/* Main Memory Mirrored Memory Engaged messages */
#define STR_EVT_MAIN_MIRROR_MEMORY_ENGAGED \
   "Mirrored Memory Engaged for Faulty Module (Slot %s, Memory Module %s)"
#define STR_EVT_MAIN_MIRROR_MEMORY_BANK_ENGAGED \
   "Mirrored Memory Engaged for Faulty Module (Slot %s, Bank %s)"
#define STR_EVT_MAIN_MIRROR_MEMORY_ENGAGED_SYSTEM \
   "Mirrored Memory Engaged for Faulty Module (System Memory, Memory Module %s)"
#define STR_EVT_MAIN_MIRROR_MEMORY_BANK_ENGAGED_SYSTEM \
   "Mirrored Memory Engaged for Faulty Module (System Memory, Bank %s)"
#define STR_EVT_MAIN_MIRROR_MEMORY_ENGAGED_GENERIC \
   "Mirrored Memory Engaged for Faulty Module (Module Unknown)"

/* Main Memory No Longer Mirrored messages */
#define STR_EVT_MAIN_MIRROR_NOT_MIRRORED \
   "Loss of Mirroring in Memory Subsystem"

/* Main Memory Online Spare Disabled messages */
#define STR_EVT_MAIN_MEM_ONLINE_SPARE_DISABLED \
   "Online Spare Memory Disabled"

/* Main Memory Not In RAID Mode messages */
#define STR_EVT_MAIN_MEM_NOT_IN_RAID_MODE \
   "Memory Subsystem Not In RAID Mode"

/* Main Memory Online Spare Switchover Complete messages */
#define STR_EVT_MAIN_MEM_SWICHOVER_COMPLETE \
   "Online Spare Memory Switchover Complete"

/* Main Memory Board Failure messages */
#define STR_EVT_MAIN_MEM_BOARD_FAILURE \
   "Memory Board Failure (Slot %s)"

/* Main Memory module failure during ROM-based diagnostic messages */
#define STR_EVT_MAIN_MEM_FAIL_IN_ROM_DIAG \
   "Uncorrectable Memory Error detected by ROM-based memory validation (%sMemory Module %d%s)"
#define STR_EVT_MAIN_MEM_FAIL_IN_ROM_DIAG_NO_ISOL \
   "Uncorrectable Memory Error detected by ROM-based memory validation (unable to isolate to single module) (%sMemory Module %d%s)"

/* Cache Memory error messages */
#define STR_EVT_CACHE_PARITY_ERROR \
   "Accelerator Cache Memory Parity Error (Socket %s)"

/* Cpu Correctable error messages */
#define STR_EVT_CPU_CORR \
   "Processor Correctable error threshold exceeded (Board %s, Processor %s)"

/* Cpu Uncorrectable error messages */
#define STR_EVT_CPU_UNCORR \
   "Processor Uncorrectable internal error (Board %s, Processor %s)"

/* Host Bus Parity error messages */
#define STR_EVT_HOST_BUS_DATA \
   "Unrecoverable Host Bus Data Parity error"
#define STR_EVT_HOST_BUS_ADDR \
   "Unrecoverable Host Bus Address Parity error"

/* Intermodule Bus error messages */
#define STR_EVT_INTERMODULE_BUS_ERROR \
   "Unrecoverable Intermodule Bus error (Error code %s)"

/* EISA Bus error messages */
#define STR_EVT_EISA_BUS_MASTER_TIMEOUT \
   "EISA Expansion Bus Master Timeout (Slot %s)"
#define STR_EVT_EISA_BUS_SLAVE_TIMEOUT \
   "EISA Expansion Bus Slave Timeout"
#define STR_EVT_EISA_BUS_BOARD_TIMEOUT \
   "EISA Expansion Board Error (Slot %s)"
#define STR_EVT_EISA_BUS_REFRESH_NMI \
   "EISA Expansion Bus Arbitration Error"

/* PCI Bus error messages */
#define STR_EVT_PCI_BUS_ERROR \
   "PCI Bus Error (Chassis %s, Slot %s, Bus %s, Device %s, Function %s)"
#define STR_EVT_PCI_BUS_ERROR_2 \
   "PCI Bus Error (Slot %s, Bus %s, Device %s, Function %s)"

/* Hot Plug event messages */
#define STR_EVT_SLOT_SWITCH_OPEN \
   "Slot Release Lever Opened (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_SWITCH_CLOSED \
   "Slot Release Lever Closed (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_POWER_ON \
   "Slot Power On (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_POWER_OFF \
   "Slot Power Off (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_POWER_FAULT \
   "Slot Power Fault (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_POWER_UP_FAULT \
   "Slot Power Up Fault (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_POWER_LOSS \
   "Unexpected Slot Power Loss (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_CANNOT_CONFIG \
   "Adapter Initialization Failure (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_BOARD_FAILURE \
   "Adapter Failure (Chassis %s, Slot %s)"
#define STR_EVT_SLOT_SWITCH_OPEN_2 \
   "Slot Release Lever Opened (Slot %s)"
#define STR_EVT_SLOT_SWITCH_CLOSED_2 \
   "Slot Release Lever Closed (Slot %s)"
#define STR_EVT_SLOT_POWER_ON_2 \
   "Slot Power On (Slot %s)"
#define STR_EVT_SLOT_POWER_OFF_2 \
   "Slot Power Off (Slot %s)"
#define STR_EVT_SLOT_POWER_FAULT_2 \
   "Slot Power Fault (Slot %s)"
#define STR_EVT_SLOT_POWER_UP_FAULT_2 \
   "Slot Power Up Fault (Slot %s)"
#define STR_EVT_SLOT_POWER_LOSS_2 \
   "Unexpected Slot Power Loss (Slot %s)"
#define STR_EVT_SLOT_CANNOT_CONFIG_2 \
   "Adapter Initialization Failure (Slot %s)"
#define STR_EVT_SLOT_BOARD_FAILURE_2 \
   "Adapter Failure (Slot %s)"

/* Post error messages */
#define STR_EVT_POST_ERROR \
   "POST Error: %s"
//added 20111207 for IML_Spec V1_50 begin
#define STR_EVT_POST_INFORMATION \
   "POST Information: %s"
#define STR_EVT_OPTION_CARD_POST_ERROR \
   "Option Card Post Error: %s"
#define STR_EVT_OPTION_CARD_POST_INFORMATION \
   "Option Card Post Information: %s" 
//added 20111207 for IML_Spec V1_50 end

/* Power Supply error messages */
#define STR_EVT_SYSTEM_PS_FAILURE \
   "System Power Supply: %s (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_FAILURE \
   "External Chassis Power Supply: %s (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_FAILURE \
   "External Storage System Power Supply: %s (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_FAILURE \
   "Internal Storage System Power Supply: %s (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_FAILURE \
   "Server Blade Enclosure Power Supply: %s (Power Supply %s, %s)"
#define STR_EVT_POWER_PS_FAILURE \
   "Power Enclosure Power Supply: %s (Power Supply %s, %s)"
#define STR_EVT_PS_SYSTEM_BATTERY_LOW \
   "Real-Time Clock Battery Failing"
#define STR_EVT_PS_SYSTEM_BATTERY_LOW_2 \
   "Real-Time Clock Battery Failing (Chassis %s)"
#define STR_EVT_PS_MODULE_PROC \
   "A CPU Power Module has Failed"
#define STR_EVT_PS_MODULE_PCI_BUS \
   "A PCI Power Module has Failed"
#define STR_EVT_PS_MODULE_IO \
   "An I/O Power Module has Failed"
#define STR_EVT_PS_MODULE_UNKNOWN \
   "A Power Module has Failed"
#define STR_EVT_PS_MODULE_SYSTEM \
   "%s (System Board, Socket %s)"
#define STR_EVT_PS_MODULE_CHASSIS \
   "%s (Chassis %s, Slot %s, Socket %s)"
#define STR_EVT_PS_MODULE_STORAGE \
   "%s (Chassis %s, Slot %s, Socket %s)"
#define STR_EVT_PS_FAILURE_SAS \
   "%s SAS Enclosure Power Supply Failure (Power Supply %u, Box %u, Port %s, %s)"

/* Power Supply Removed messages */
#define STR_EVT_SYSTEM_PS_REMOVED \
   "System Power Supply Removed (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_REMOVED \
   "External Chassis Power Supply Removed (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_REMOVED \
   "External Storage System Power Supply Removed (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_REMOVED \
   "Internal Storage System Power Supply Removed (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_REMOVED \
   "Server Blade Enclosure Power Supply Removed (Power Supply %s, %s)"
#define STR_EVT_POWER_PS_REMOVED \
   "Power Enclosure Power Supply Removed (Power Supply %s, %s)"

/* Power Supply Inserted messages */
#define STR_EVT_SYSTEM_PS_INSERTED \
   "System Power Supply Inserted (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_INSERTED \
   "External Chassis Power Supply Inserted (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_INSERTED \
   "External Storage System Power Supply Inserted (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_INSERTED \
   "Internal Storage System Power Supply Inserted (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_INSERTED \
   "Server Blade Enclosure Power Supply Inserted (Power Supply %s, %s)"
#define STR_EVT_POWER_PS_INSERTED \
   "Power Enclosure Power Supply Inserted (Power Supply %s, %s)"

/* Power Supply Not Redundant messages */
#define STR_EVT_SYSTEM_PS_NOT_REDUNDANT \
   "System Power Supplies Not Redundant"
#define STR_EVT_CHASSIS_PS_NOT_REDUNDANT \
   "External Chassis Power Supplies Not Redundant (Chassis %s)"
#define STR_EVT_STORSYS_PS_NOT_REDUNDANT \
   "External Storage System Power Supplies Not Redundant (%sSlot %s)"
#define STR_EVT_INT_STORSYS_PS_NOT_REDUNDANT \
   "Internal Storage System Power Supplies Not Redundant (%sSlot %s)"
#define STR_EVT_BLADE_PS_NOT_REDUNDANT \
   "Server Blade Enclosure Power Supplies Not Redundant (in %s, %s)"
#define STR_EVT_POWER_PS_NOT_REDUNDANT \
   "Power Enclosure Power Supplies Not Redundant (in %s, %s)"

/* Power Modules Not Redundant messages */
#define STR_EVT_SYSTEM_PS_MODULE_NOT_REDUNDANT \
   "System Power Modules Not Redundant"
#define STR_EVT_CHASSIS_PS_MODULE_NOT_REDUNDANT \
   "External Chassis Power Modules Not Redundant (Chassis %s)"
#define STR_EVT_STORSYS_PS_MODULE_NOT_REDUNDANT \
   "External Storage System Power Modules Not Redundant (%sSlot %s)"
#define STR_EVT_INT_STORSYS_PS_MODULE_NOT_REDUNDANT \
   "Internal Storage System Power Modules Not Redundant (%sSlot %s)"
#define STR_EVT_BLADE_PS_MODULE_NOT_REDUNDANT \
   "Server Blade Enclosure Power Modules Not Redundant"
#define STR_EVT_POWER_PS_MODULE_NOT_REDUNDANT \
   "Power Enclosure Power Modules Not Redundant"

/* Power AC Voltage Problem messages */
#define STR_EVT_SYSTEM_PS_AC_VOLTAGE \
   "System AC Power Problem (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_AC_VOLTAGE \
   "External Chassis AC Power Problem (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_AC_VOLTAGE \
   "External Storage System AC Power Problem (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_AC_VOLTAGE \
   "Internal Storage System AC Power Problem (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_AC_VOLTAGE \
   "Server Blade Enclosure AC Power Problem (Power Supply %s, Reason: %s, %s)"
#define STR_EVT_POWER_PS_AC_VOLTAGE \
   "Power Enclosure AC Power Problem (Power Supply %s, Reason: %s, %s)"

/* Power AC Overload messages */
#define STR_EVT_SYSTEM_PS_AC_OVERLOAD \
   "System AC Power Overload (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_AC_OVERLOAD \
   "External Chassis AC Power Overload (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_AC_OVERLOAD \
   "External Storage System AC Power Overload (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_AC_OVERLOAD \
   "Internal Storage System AC Power Overload (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_AC_OVERLOAD \
   "Server Blade Enclosure AC Power Overload (Power Supply %s, Voltage: %s, %s)"
#define STR_EVT_POWER_PS_AC_OVERLOAD \
   "Power Enclosure AC Power Overload (Power Supply %s, Voltage: %s, %s)"

/* Power Supply Powered messages */
#define STR_EVT_SYSTEM_PS_POWERED \
   "System Power Supply Powered Up (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_POWERED \
   "External Chassis System Power Supply Powered Up (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_POWERED \
   "External Storage System Power Supply Powered Up (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_POWERED \
   "Internal Storage System Power Supply Powered Up (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_POWERED \
   "Server Blade Enclosure System Power Supply Powered Up (Power Supply %s)"
#define STR_EVT_POWER_PS_POWERED \
   "Power Enclosure System Power Supply Powered Up (Power Supply %s)"

/* Power Supply Unpowered messages */
#define STR_EVT_SYSTEM_PS_UNPOWERED \
   "System Power Supply Powered Down (Power Supply %s)"
#define STR_EVT_CHASSIS_PS_UNPOWERED \
   "External Chassis System Power Supply Powered Down (Chassis %s, Power Supply %s)"
#define STR_EVT_STORSYS_PS_UNPOWERED \
   "External Storage System Power Supply Powered Down (%sSlot %s, Power Supply %s)"
#define STR_EVT_INT_STORSYS_PS_UNPOWERED \
   "Internal Storage System Power Supply Powered Down (%sSlot %s, Power Supply %s)"
#define STR_EVT_BLADE_PS_UNPOWERED \
   "Server Blade Enclosure System Power Supply Powered Down (Power Supply %s)"
#define STR_EVT_POWER_PS_UNPOWERED \
   "Power Enclosure System Power Supply Powered Down (Power Supply %s)"

/* System Power Module Failure messages */
#define STR_EVT_SYSTEM_PS_MOD_FAILURE \
   "System Power Module Failure (Power Module %s)"
#define STR_EVT_CHASSIS_PS_MOD_FAILURE \
   "External Chassis Power Module Failure (Chassis %s, Power Module %s)"
#define STR_EVT_STORSYS_PS_MOD_FAILURE \
   "External Storage System Power Module Failure (%sSlot %s, Power Module %s)"
#define STR_EVT_INT_STORSYS_PS_MOD_FAILURE \
   "Internal Storage System Power Module Failure (%sSlot %s, Power Module %s)"
#define STR_EVT_BLADE_PS_MOD_FAILURE \
   "Server Blade Enclosure Power Module Failure (Power Module %s)"
#define STR_EVT_POWER_PS_MOD_FAILURE \
   "Power Enclosure Power Module Failure (Power Module %s)"

/* System Power Module Removed messages */
#define STR_EVT_SYSTEM_PS_MOD_REMOVED \
   "System Power Module Removed (Power Module %s)"
#define STR_EVT_CHASSIS_PS_MOD_REMOVED \
   "External Chassis Power Module Removed (Chassis %s, Power Module %s)"
#define STR_EVT_STORSYS_PS_MOD_REMOVED \
   "External Storage System Power Module Removed (%sSlot %s, Power Module %s)"
#define STR_EVT_INT_STORSYS_PS_MOD_REMOVED \
   "Internal Storage System Power Module Removed (%sSlot %s, Power Module %s)"
#define STR_EVT_BLADE_PS_MOD_REMOVED \
   "Server Blade Enclosure Power Module Removed (Power Module %s)"
#define STR_EVT_POWER_PS_MOD_REMOVED \
   "Power Enclosure Power Module Removed (Power Module %s)"

/* System Power Module Inserted messages */
#define STR_EVT_SYSTEM_PS_MOD_INSERTED \
   "System Power Module Inserted (Power Module %s)"
#define STR_EVT_CHASSIS_PS_MOD_INSERTED \
   "External Chassis Power Module Inserted (Chassis %s, Power Module %s)"
#define STR_EVT_STORSYS_PS_MOD_INSERTED \
   "External Storage System Power Module Inserted (%sSlot %s, Power Module %s)"
#define STR_EVT_INT_STORSYS_PS_MOD_INSERTED \
   "Internal Storage System Power Module Inserted (%sSlot %s, Power Module %s)"
#define STR_EVT_BLADE_PS_MOD_INSERTED \
   "Server Blade Enclosure Power Module Inserted (Power Module %s)"
#define STR_EVT_POWER_PS_MOD_INSERTED \
   "Power Enclosure Power Module Inserted (Power Module %s)"

/* System Power Modules Not Redundant messages */
#define STR_EVT_SYSTEM_PS_MOD_NOT_REDUNDANT \
   "System Power Modules Not Redundant"
#define STR_EVT_CHASSIS_PS_MOD_NOT_REDUNDANT \
   "External Chassis Power Modules Not Redundant (Chassis %s)"
#define STR_EVT_STORSYS_PS_MOD_NOT_REDUNDANT \
   "External Storage System Power Modules Not Redundant (%sSlot %s)"
#define STR_EVT_INT_STORSYS_PS_MOD_NOT_REDUNDANT \
   "Internal Storage System Power Modules Not Redundant (%sSlot %s)"
#define STR_EVT_BLADE_PS_MOD_NOT_REDUNDANT \
   "Server Blade Enclosure Power Modules Not Redundant"
#define STR_EVT_POWER_PS_MOD_NOT_REDUNDANT \
   "Power Enclosure Power Modules Not Redundant"

/* System Power Module Overload messages */
#define STR_EVT_SYSTEM_PS_MOD_OVERLOAD \
   "System Power Module Overload (Power Module %s)"
#define STR_EVT_CHASSIS_PS_MOD_OVERLOAD \
   "External Chassis Power Module Overload (Chassis %s, Power Module %s)"
#define STR_EVT_STORSYS_PS_MOD_OVERLOAD \
   "External Storage System Power Module Overload (%sSlot %s, Power Module %s)"
#define STR_EVT_INT_STORSYS_PS_MOD_OVERLOAD \
   "Internal Storage System Power Module Overload (%sSlot %s, Power Module %s)"
#define STR_EVT_BLADE_PS_MOD_OVERLOAD \
   "Server Blade Enclosure Power Module Overload (Power Module %s)"
#define STR_EVT_POWER_PS_MOD_OVERLOAD \
   "Power Enclosure Power Module Overload (Power Module %s)"

/* UPS event messages */
   /* future */

/* ASR error messages */
#define STR_EVT_ASR_RESET_DETECTED \
   "ASR Detected by System ROM"
#define STR_EVT_ASR_SYSTEM_LOCKUP \
   "ASR Lockup Detected: %s"
#define STR_EVT_ASR_RESET_LIMIT_DETECTED \
   "ASR Reset Limit Detected by System ROM"

/* OS error messages */
#ifdef WIN32
#define STR_EVT_OS_CRASH \
   "Blue Screen Trap (%s)"
#endif
#ifdef UNIX
#define STR_EVT_OS_CRASH \
   "Kernel Panic (%s)"
#endif
#ifdef NETWARE
#define STR_EVT_OS_CRASH \
   "Abnormal Program Termination (%s)"
#endif
#ifndef STR_EVT_OS_CRASH
#define STR_EVT_OS_CRASH \
   "Abnormal Program Termination (%s)"
#endif
#define STR_EVT_OS_SHUTDOWN_FAN \
   "Automatic Operating System Shutdown Initiated Due to Fan Failure"
#define STR_EVT_OS_SHUTDOWN_TEMP \
   "Automatic Operating System Shutdown Initiated Due to Overheat Condition"
#define STR_EVT_OS_SHUTDOWN_VRM \
   "Automatic Operating System Shutdown Initiated Due to VRM Failure"
#define STR_EVT_OS_SHUTDOWN_ABORT \
   "Automatic Operating System Shutdown Aborted"
#define STR_EVT_OS_SHUTDOWN_FAN_ABORT \
   "Automatic Operating System Shutdown Due to Fan Failure Aborted"
#define STR_EVT_OS_SHUTDOWN_TEMP_ABORT \
   "Automatic Operating System Shutdown Due to Overheat Aborted"
#define STR_EVT_OS_SHUTDOWN_VRM_ABORT \
   "Automatic Operating System Shutdown Due to VRM Failure Aborted"
#define STR_EVT_OS_SHUTDOWN_SOFT_POWER_DOWN \
   "Automatic Operating System Shutdown Initiated by a Soft Power Down"
#define STR_EVT_OS_SHUTDOWN_SOFTWARE \
   "Automatic Operating System Shutdown Initiated by Software Automatic Server Recovery"

#define STR_EVT_OS_EXCEPTION \
   "Fatal Exception (Number %s, Cause %s)"
#ifdef WIN32
#define STR_EVT_OS_NMI_DUMP_SWITCH \
   "User Initiated Blue Screen Trap"
#endif
#ifdef UNIX
#define STR_EVT_OS_NMI_DUMP_SWITCH \
   "User Initiated Kernel Panic"
#endif
#ifdef NETWARE
#define STR_EVT_OS_NMI_DUMP_SWITCH \
   "User Initiated Abnormal Program Termination"
#endif
#ifndef STR_EVT_OS_NMI_DUMP_SWITCH
#define STR_EVT_OS_NMI_DUMP_SWITCH \
   "User Initiated Abnormal Program Termination"
#endif

#define STR_EVT_BLADE_OS_PWR_SHED \
   "Server Blade Enclosure Blade Shutdown Via Power Management Software (Slot %s)"
#define STR_EVT_NET_SWITCH_OS_PWR_SHED \
   "Server Blade Enclosure Network Component Shutdown Via Power Management Software (Slot %s)"

#ifdef WIN32
#define STR_EVT_VIRTUAL_NMI_SWITCH \
   "Remotely Initiated Blue Screen Trap"
#endif
#ifdef UNIX
#define STR_EVT_VIRTUAL_NMI_SWITCH \
   "Remotely Initiated Kernel Panic"
#endif
#ifdef NETWARE
#define STR_EVT_VIRTUAL_NMI_SWITCH \
   "Remotely Initiated Abnormal Program Termination"
#endif
#ifndef STR_EVT_VIRTUAL_NMI_SWITCH
#define STR_EVT_VIRTUAL_NMI_SWITCH \
   "Remotely Initiated Abnormal Program Termination"
#endif

/* Diagnostics error messages */
  /* future */

/* NIC event messages */
#define STR_EVT_NIC_ADAPTER_CHECK \
   "Network Adapter Fault (Chassis %s, Slot %s, Port %s)"
#define STR_EVT_NIC_LINK_DOWN \
   "Network Adapter Link Down (Chassis %s, Slot %s, Port %s)"
#define STR_EVT_NIC_XMIT_TIMEOUT \
   "Network Adapter Transmit Timeout (Chassis %s, Slot %s, Port %s)"
#define STR_EVT_NIC_NOT_REDUNDANT \
   "Network Adapters No Longer Redundant (Chassis %s, Slot %s, Port %s)"
#define STR_EVT_NIC_ADAPTER_CHECK_2 \
   "Network Adapter Fault (Slot %s, Port %s)"
#define STR_EVT_NIC_LINK_DOWN_2 \
   "Network Adapter Link Down (Slot %s, Port %s)"
#define STR_EVT_NIC_XMIT_TIMEOUT_2 \
   "Network Adapter Transmit Timeout (Slot %s, Port %s)"
#define STR_EVT_NIC_NOT_REDUNDANT_2 \
   "Network Adapters No Longer Redundant (Slot %s, Port %s)"
#define STR_EVT_NIC_REDUNDANCY_REDUCED \
   "Network Adapters Redundancy Reduced (Chassis %s, Slot %s, Port %s)"
#define STR_EVT_NIC_REDUNDANCY_REDUCED_2 \
   "Network Adapters Redundancy Reduced (Slot %s, Port %s)"

/* Scsi Controller error messages */
#define STR_EVT_SYSTEM_SCSI_CTRL_FAILURE \
   "SCSI Controller Failure (Slot %s)"
#define STR_EVT_CHASSIS_SCSI_CTRL_FAILURE \
   "SCSI Controller Failure (Chassis %s, Slot %s)"

/* Scsi Device error messages */
#define STR_EVT_SYSTEM_SCSI_DEVICE_FAILURE \
   "SCSI Device Failure (%sSlot %s, Bus %s, Bay %s)"

/* Scsi Redundancy Lost error messages */
#define STR_EVT_SCSI_NOT_REDUNDANT \
   "SCSI Controllers No Longer Redundant (Chassis %s)"
#define STR_EVT_SCSI_NOT_REDUNDANT_2 \
   "SCSI Controllers No Longer Redundant"

/* Drive Array Controller error messages */
#define STR_EVT_SYSTEM_ARRAY_CTRL_FAILURE \
   "Drive Array Controller Failure (Slot %s)"
#define STR_EVT_CHASSIS_ARRAY_CTRL_FAILURE \
   "Drive Array Controller Failure (Chassis %s, Slot %s)"

/* Drive Array Device error messages */
#define STR_EVT_SYSTEM_ARRAY_DEVICE_FAILURE \
   "Drive Array Device Failure (%sSlot %s, Bus %s, Bay %s)"
#define STR_EVT_SAS_DEVICE_FAILURE \
   "%s SAS Enclosure Device Failure (Bay %u, Box %u, Port %s, %s)"

/* Drive Array Accelerator error messages */
#define STR_EVT_SYSTEM_ARRAY_ACCEL_FAILURE \
   "Drive Array Accelerator Battery Failure (Bus %s, Slot %s)"
#define STR_EVT_CHASSIS_ARRAY_ACCEL_FAILURE \
   "Drive Array Accelerator Battery Failure (Chassis %s, Bus %s, Slot %s)"

/* Drive Array Redundancy Lost error messages */
#define STR_EVT_ARRAY_NOT_REDUNDANT \
   "Drive Array Controllers No Longer Redundant (Chassis %s)"
#define STR_EVT_ARRAY_NOT_REDUNDANT_2 \
   "Drive Array Controllers No Longer Redundant"
#define STR_EVT_ARRAY_NOT_REDUNDANT_SUN \
   "Drive Array Controllers No Longer Redundant (%s)"

/* Drive Array SAS PHY error messages */
#define STR_EVT_SAS_PHY_ERROR \
   "%s SAS Enclosure PHY Link Error (PHY %u, Expander %u, Box %u, Port %s, %s)"
#define STR_EVT_SAS_PHY_ERROR_EXTENDED \
   "%s SAS Enclosure PHY Link Error (%s, Box %u, Port %s, %s)"

/* Substrings for STR_EVT_SAS_PHY_ERROR_EXTENDED */
#define STR_SAS_PHY_FAIL_PATH_UNKNOWN \
   "Error path unknown"
#define STR_SAS_PHY_FAIL_PATH_1 \
   "Storage controller to external storage box"
#define STR_SAS_PHY_FAIL_PATH_2 \
   "Storage controller to internal device"
#define STR_SAS_PHY_FAIL_PATH_3 \
   "Storage controller to onboard expander"
#define STR_SAS_PHY_FAIL_PATH_4 \
   "Onboard expander to external storage box"
#define STR_SAS_PHY_FAIL_PATH_5 \
   "Onboard expander to internal device"
#define STR_SAS_PHY_FAIL_PATH_6 \
   "Storage box to storage box"
#define STR_SAS_PHY_FAIL_PATH_7 \
   "Storage box to bay in storage box"
#define STR_SAS_PHY_FAIL_PATH_8 \
   "Storage controller to switch expander"
#define STR_SAS_PHY_FAIL_PATH_9 \
   "Switch expander to storage box"

/* Unrecoverable error detected messages */
#define STR_EVT_NMI \
   "An Unrecoverable System Error (NMI) has occurred"
#define STR_EVT_BINIT \
   "An Unrecoverable System Error (BINIT) has occurred"
#define STR_EVT_NMI_PLUS_DATA \
   "An Unrecoverable System Error has occurred (Error code %s, %s)"

/* Autorev event messages */
#define STR_EVT_ROM_FLASHED \
   "ROM flashed (%s)"

/* Maintenance messages */
#define STR_EVT_MAINT_IML_CLEARED \
   "IML Cleared (%s)"
#define STR_EVT_MAINT_NOTE \
   "%s"

/* Infrastructure Environment messages */
#define STR_EVT_INF_ENV_INADEQUATE_PWR_TO_PWR_ON \
   "%s Inadequate Power To Power On: %s (%s, Slot %s)"
#define STR_EVT_INF_ENV_INADEQUATE_PWR_LOST_RED \
   "Lost Redundant Power"
#define STR_EVT_INF_ENV_INADEQUATE_PWR_NOT_ENOUGH_PWR \
   "Not Enough Power"
#define STR_EVT_INF_ENV_INADEQUATE_PWR_SVR_ENC_BOARD \
   "Denied By Server Enclosure Management Board"
#define STR_EVT_INF_ENV_INADEQUATE_PWR_PWR_ENC_BOARD \
   "Denied By Power Enclosure Management Board"
#define STR_EVT_INF_ENV_INADEQUATE_PWR_UNKNOWN \
   "Unknown Reason Code"

#define STR_EVT_INF_ENV_MANUAL_OVERRIDE_PWR_ON \
   "%s Blade Manual Power On (%s, Slot %s)"

#define STR_EVT_INF_ENV_FUSE_OPEN \
   "%s Blade Fuse or Breaker Tripped (%s, Slot %s, Fuse %s)"

#define STR_EVT_NET_INF_ENV_FUSE_OPEN \
   "%s Network Component Fuse or Breaker Tripped (%s, %s, Fuse %s)"

#define STR_EVT_INF_ENV_I2C_FAULT \
   "%s Blade I2C Bus Fault (%s, Bus %s)"

#define STR_EVT_INF_ENV_BLADE_REMOVED \
   "%s Blade Removed (%s, Slot %s)"
#define STR_EVT_INF_ENV_BLADE_INSERTED \
   "%s Blade Inserted (%s, Slot %s)"

#define STR_EVT_INF_ENV_PWR_NOT_BALANCED \
   "%s Power Not Balanced (%s, %s)"

#define STR_EVT_INF_ENV_DC_PWR_PROBLEM \
   "%s DC Power Out Of Tolerance (%s, %s, %d mV)"

#define STR_EVT_INF_ENV_AC_INPUT_PWR_PROBLEM \
   "%s AC Facility Input Power Exceeded (%s)"

#define STR_EVT_INF_ENV_LOST_CONNECTIVITY \
   "Loss Of Chassis Connectivity (%s)"

#define STR_EVT_INF_ENV_NEW_CONNECTIVITY \
   "New Chassis Connected (%s)"

#define STR_EVT_INF_ENV_RACK_NAME_CHG \
   "%s Rack Name Changed (%s)"

#define STR_EVT_INF_ENV_ENCL_NAME_CHG \
   "%s Name Changed (%s)"

#define STR_EVT_INF_ENV_SERVICE_CHG \
   "%s Service Change (%s)"

#define STR_EVT_INF_ENV_NAME_CONFLICT_CHG \
   "%s Rack Name Conflict (%s)"

#define STR_EVT_INF_ENV_RUID_CHANGED \
   "%s Rack Unique ID Changed (%s)"

#define STR_EVT_INF_ENV_LAN_SETTINGS \
   "%s LAN Settings Changed (%s)"

#define STR_EVT_INF_ENV_UID \
   "%s UID LED State Changed (%s)"

#define STR_EVT_INF_CHANGE_UNKNOWN \
   "%s Rack Infrastructure Changed (%s, Type 0x%02X)"

#define STR_EVT_INF_ENV_UNKNOWN_PWR_CONSUMPTION \
   "%s Unknown Power Consumption (%s)"

#define STR_EVT_INF_ENV_PWR_SUBSYS_MISCONFIGURED \
   "%s Power Subsystem Misconfigured: %s (%s)"
#define STR_EVT_INF_ENV_PWR_SUBSYS_MISCONFIGURED_LOC \
   "%s Power Subsystem Misconfigured: %s (%s, %s)"
   
#define STR_EVT_POWER_INF_ENV_PWR_SUBSYS_LOAD_BAL_WIRE_MISSING \
   "Load Balancing Wire Missing"
#define STR_EVT_POWER_INF_ENV_PWR_SUBSYS_TOO_MANY_PWR_CHASSIS \
   "Too Many Power Enclosures"
#define STR_EVT_POWER_INF_ENV_PWR_SUBSYS_BADLY_POPULATED_PWR_BANK \
   "Improperly Populated Power Bank"
#define STR_EVT_POWER_INF_ENV_PWR_SUBSYS_DC_TO_DC_INVALID \
   "DC-to-DC Configuration Invalid"
#define STR_EVT_POWER_INF_ENV_PWR_SUBSYS_UNKNOWN_PROBLEM \
   "Unknown Power Configuration Problem"

#define STR_EVT_INF_ENV_ENCL_MGR_STATUS \
   "%s Status Change (%s)"

#define STR_EVT_INF_ENV_BLOWER_FAULT \
   "%s Blower Fault (%s, Blower %s, %s)"

#define STR_EVT_INF_ENV_BLOWER_REMOVED \
   "%s Blower Removed (%s, Blower %s, %s)"

#define STR_EVT_INF_ENV_ETH_SW_ERR \
   "%s Ethernet Switch Error - %s (%s, %s)"

#define STR_EVT_INF_ENV_INP_SENSE_ERROR \
   "%s Power Feed Missing (%s, %s)"

#define STR_EVT_INF_ENV_BLADE_INS \
   "%s Server Blade Inserted (Slot %s, %s)"
#define STR_EVT_INF_ENV_BLADE_REM \
   "%s Server Blade Removed (Slot %s, %s)"
#define STR_EVT_INF_ENV_NET_INS \
   "%s Network Component Inserted (%s, %s)"
#define STR_EVT_INF_ENV_NET_REM \
   "%s Network Component Removed (%s, %s)"

#define STR_EVT_INF_ENV_INVALID_TOPOLOGY \
   "%s Invalid Topology - Check Cabling"

/* substitution strings for EVT_ENCL_CHASSIS_ERROR */
#define STR_CHASSIS_SLOT1 \
   "Chassis Slot 1"
#define STR_CHASSIS_SLOT2 \
   "Chassis Slot 2"
#define STR_CHASSIS_SLOT3 \
   "Chassis Slot 3"
#define STR_CHASSIS_SLOT4 \
   "Chassis Slot 4"
#define STR_CHASSIS_SLOT5 \
   "Chassis Slot 5"
#define STR_CHASSIS_SLOT6 \
   "Chassis Slot 6"
#define STR_CHASSIS_SLOT7 \
   "Chassis Slot 7"
#define STR_CHASSIS_SLOT8 \
   "Chassis Slot 8"
#define STR_SLIME_BOARD  \
   "Server Blade Management Module"
#define STR_SIGNAL_BACKPLANE \
   "Signal Backplane"
#define STR_POWER_BACKPLANE_A \
   "Power Backplane A"
#define STR_POWER_BACKPLANE_B \
   "Power Backplane B"
#define STR_ICE_MAKER_EAST \
   "Interconnect Blade A"
#define STR_ICE_MAKER_WEST \
   "Interconnect Blade B"
#define STR_RJ45_10_EAST \
   "RJ45 10 East"
#define STR_RJ45_10_WEST \
   "RJ45 10 West"
#define STR_RJ45_6_EAST \
   "RJ45 6 East"
#define STR_RJ45_6_WEST \
   "RJ45 6 West"
/* STR_UNKNOWN already defined above */


#define STR_GROMIT \
   "iLO Management Controller"
#define STR_FRU_EEPROM \
   "FRU EEPROM"
#define STR_MEMORY \
   "Memory"
#define STR_ICMB_UART \
   "ICMB UART"
#define STR_ROM \
   "ROM"
#define STR_LM75 \
   "LM75"
#define STR_I2C_BUS_0 \
   "I2C Bus 0"
#define STR_I2C_BUS_1 \
   "I2C Bus 1"
#define STR_I2C_BUS_2 \
   "I2C Bus 2"
#define STR_SOFTWARE \
   "Software"
#define STR_I2C_BUS \
   "I2C Bus"
#define STR_9544_FUSE_MUX \
   "9544 Fuse Mux"
#define STR_9555_QUICK_SWITCH \
   "9555 Quick Switch"
#define STR_9555_SENSE \
   "9555 Sense"
#define STR_9555_ENABLE \
   "9555 Enable"
#define STR_9555_IO_EXPANDER \
   "9555 IO Expander"
#define STR_9555_MUX \
   "9555 Mux"

/* Error Strings */

#define STR_I2C_ERROR \
   "I2C Error"
#define STR_INTERRUPT_ERROR \
   "Interrupt Error"
#define STR_INVALID_FRUDATA \
   "Invalid FRU Data"
#define STR_POST_FAILURE \
   "POST Failure"
#define STR_BACKUP_ROM_BOOTED \
   "Backup ROM Booted"
#define STR_BUS_ERROR \
   "Bus Error"
#define STR_STACK_OVERFLOW \
   "Stack Overflow"
#define STR_I2C_BUS_TIMEOUT \
   "I2C Bus Timeout"
#define STR_UNKNOWN_I2C_ERROR \
   "Unknown I2C Error"

/* Main String for EVT_ENCL_CHASSIS_ERROR */

#define STR_EVT_BLADE_INF_ENV_ENCL_CHASSIS_ERROR \
   "Infrastructure Fault, %s at %s, %s"

#define STR_EVT_BLADE_INF_ENV_FIRMWARE_MISMATCH \
   "Chassis %s requires minimum firmware revision %s.%s. It is currently %s.%s."


#ifdef __cplusplus
}
#endif

#endif /* imltext_eventstr_h */
